var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Shared/Resources", "../../_generated/BladeReferences"], function (require, exports, Resources, BladeReferences) {
    "use strict";
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var ArmHelpers = Common.Helpers;
    var InvoiceDetailBladeViewModel = (function (_super) {
        __extends(InvoiceDetailBladeViewModel, _super);
        function InvoiceDetailBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.adminSubscriptionId = ko.observable();
            this.invoiceId = ko.observable();
            this.location = ko.observable("local");
            this.invoiceData = ko.observable();
            this.title("Invoice");
            this._container = container;
            this._dataContext = dataContext;
            this._invoiceEntityView = this._dataContext.sharedContext.invoicesDataManager.invoiceEntity.createView(container, {
                interceptNotFound: false
            });
            this._setupCommandBar();
            ko.reactor(container, function () {
                if (_this._invoiceEntityView.item()) {
                    var x = _this._invoiceEntityView.item();
                    MsPortalFx.extend(x, {
                        Logo1Image: ko.observable(Resources.Icon.InvoiceLogo1Image),
                    });
                    _this.invoiceData(x);
                    _this.title("Invoice ({0})".format(x.BillingPeriodString()));
                    _this.subtitle(x.SubscriptionId());
                }
            });
        }
        InvoiceDetailBladeViewModel.prototype._setupCommandBar = function () {
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this._editInvoiceButton = this._createEditInvoiceButton();
            this.commandBar.setItems([this._editInvoiceButton]);
        };
        InvoiceDetailBladeViewModel.prototype._createEditInvoiceButton = function () {
            var _this = this;
            var editButton = new FxToolbars.CommandButton({
                label: "Edit",
                icon: MsPortalFx.Base.Images.Edit(),
                command: {
                    execute: function () {
                        return _this._container.openBlade(new BladeReferences.InvoiceEditBladeReference({
                            adminSubscriptionId: _this.adminSubscriptionId(),
                            location: _this.location(),
                            invoiceId: _this.invoiceId(),
                        }));
                    },
                    canExecute: ko.observable(true),
                }
            });
            return editButton;
        };
        InvoiceDetailBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.adminSubscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            this.invoiceId(inputs.invoiceId);
            var args = {
                subscriptionId: this.adminSubscriptionId(),
                location: this.location(),
                invoiceId: this.invoiceId()
            };
            return this._invoiceEntityView.fetch(args).then(function () {
            });
        };
        InvoiceDetailBladeViewModel.prototype._getBillingPeriod = function (invoice) {
            var st = new Date(invoice.InvoiceStartTime());
            var et = new Date(invoice.InvoiceEndTime());
            var startTimeString = this._getUtcDateString(st);
            var endTimeString = this._getUtcDateString(et);
            var period = "{0}-{1}".format(startTimeString, endTimeString);
            return period;
        };
        InvoiceDetailBladeViewModel.prototype._getUtcDate = function (date) {
            var dateUtc = new Date(date.getUTCFullYear(), date.getUTCMonth(), date.getUTCDate(), date.getUTCHours(), date.getUTCMinutes(), date.getUTCSeconds());
            return dateUtc;
        };
        InvoiceDetailBladeViewModel.prototype._getUtcDateString = function (date) {
            return "{0}/{1}/{2}".format(date.getUTCMonth() + 1, date.getUTCDate(), date.getUTCFullYear());
        };
        return InvoiceDetailBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.InvoiceDetailBladeViewModel = InvoiceDetailBladeViewModel;
});
