var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Shared/Helpers"], function (require, exports, Helpers) {
    "use strict";
    var FxForms = MsPortalFx.ViewModels.Forms;
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var Dialogs = MsPortalFx.ViewModels.Dialogs;
    var FxDropDown = MsPortalFx.ViewModels.Obsolete.Forms.DropDown;
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var FileDownload = MsPortalFx.ViewModels.Controls.FileDownload;
    var FileDownloadButton = MsPortalFx.ViewModels.Controls.FileDownloadButton;
    var ArmHelpers = Common.Helpers;
    var InvoicesCollectionBladeViewModel = (function (_super) {
        __extends(InvoicesCollectionBladeViewModel, _super);
        function InvoicesCollectionBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.isShowGrid = ko.observable(true);
            this.adminSubscriptionId = ko.observable();
            this.location = ko.observable("local");
            this.selectedInvoices = ko.observableArray([]);
            this.selectedBillingPeriod = ko.observable();
            this.title("Invoices");
            this._container = container;
            this._dataContext = dataContext;
            this._dataQueryView = dataContext.sharedContext.invoicesDataManager.invoicesQuery.createView(container, {
                interceptNotFound: false
            });
            this.gridOrChartOptionPicker = new MsPortalFx.ViewModels.Forms.OptionsGroup.ViewModel(container, {
                options: ko.observableArray([
                    { text: ko.observable("Grid"), value: "Grid" },
                    { text: ko.observable("Chart"), value: "Chart" },
                ]),
                defaultValue: ko.observable("Grid")
            });
            var billingPeriodDropDownOptions = {
                label: ko.observable("Billing Period"),
                labelPosition: ko.observable(FxForms.LabelPosition.Left),
                infoBalloonContent: ko.observable("Choose the Billing Period to list Subscription Summary"),
                options: ko.observableArray([{ text: ko.observable("Loading.."), value: "" }])
            };
            this.billingPeriodsDropDown = new FxDropDown.ViewModel(container, billingPeriodDropDownOptions);
            this.billingPeriodsDropDown.value.subscribe(container, function (newPeriod) {
                _this.selectedBillingPeriod(newPeriod);
            });
            this.formSection = new FxForms.Section.ViewModel(container, {
                style: ko.observable(3),
                children: ko.observableArray([
                    this.billingPeriodsDropDown
                ])
            });
            var gridExtensions = FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                selectableRow: {
                    selectionMode: 1,
                    activateOnSelected: ko.observable(false)
                }
            };
            this.invoicesGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "Id",
                    name: ko.observable("Invoice Id"),
                    width: ko.observable("70px")
                },
                {
                    itemKey: "UserId",
                    name: ko.observable("User"),
                    width: ko.observable("150px"),
                    activatable: ko.observable(true),
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: Helpers.getGridNameActivatableTemplate(),
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    }
                },
                {
                    itemKey: "SubscriptionId",
                    name: ko.observable("Subscription"),
                    width: ko.observable("170px")
                },
                {
                    itemKey: "PaymentStatusString",
                    name: ko.observable("Payment Status"),
                    width: ko.observable("100px"),
                },
                {
                    itemKey: "FinalBillableAmountString",
                    name: ko.observable("Amount"),
                    width: ko.observable("60px"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
                {
                    itemKey: "DownloadInvoiceButton",
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: "<div data-bind='pcControl: value'></div>",
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    },
                    width: ko.observable("150px")
                },
            ];
            this.invoicesGrid.columns = ko.observableArray(basicColumns);
            this.invoicesGrid.showHeader = true;
            this.invoicesGrid.summary = ko.observable("Summary");
            this.invoicesGrid.noRowsMessage("No items found");
            this.invoicesGrid.selectableData.selectedItems.subscribe(container, function (selectedItems) {
                if (!selectedItems || selectedItems.length === 0) {
                    _this.selectedInvoices([]);
                    return;
                }
                _this.selectedInvoices(selectedItems);
                if (_this.selectedInvoices() && (_this.selectedInvoices().first().PaymentStatus() != 30)) {
                    _this._markAsPaidButton.disabled(false);
                }
                else {
                    _this._markAsPaidButton.disabled(true);
                }
            });
            this._dataQueryView.items.subscribe(container, function (invoices) {
                var transformedItems = invoices.map(function (invoice) {
                    var args = {
                        subscriptionId: _this.adminSubscriptionId(),
                        location: _this.location(),
                        invoiceId: invoice.Id(),
                    };
                    var downloadUri = _this._dataContext.sharedContext.invoicesDataManager.downloadInvoiceUriFormat(args);
                    var invoiceFileDownloadContext = new FileDownload.Context({
                        targetUri: ko.observable(downloadUri),
                        httpMethod: ko.observable("GET"),
                        downloadType: ko.observable(2),
                        addDefaultAuthorizationToken: true,
                        showDownloadProgressDialog: ko.observable(true)
                    });
                    var invoiceDownloadLink = new FileDownloadButton.ViewModel(container, {
                        context: ko.observable(invoiceFileDownloadContext),
                        label: ko.observable("Download Invoice"),
                        disabled: ko.observable(false),
                        asLink: true
                    });
                    return $.extend({}, invoice, {
                        DownloadInvoiceButton: invoiceDownloadLink,
                    });
                });
                _this.invoicesGrid.items(transformedItems);
            });
            this.billingPeriodsDropDown.value.subscribe(container, function (selectedPeriod) {
                if (!selectedPeriod) {
                    _this.invoicesGrid.items([]);
                    return;
                }
                _this.selectedBillingPeriod(selectedPeriod);
                _this._dataQueryView.fetch({
                    subscriptionId: _this.adminSubscriptionId(),
                    location: _this.location(),
                    month: selectedPeriod.StartDate,
                });
            });
            this.gridOrChartOptionPicker.value.subscribe(this._container, function (newValue) {
                _this.isShowGrid(newValue === 'Grid');
            });
            this._dataQueryView.loading.subscribe(container, function (isLoading) {
                _this.invoicesGrid.loading(isLoading);
            });
            this._setupCommandBar();
            this._initBarChart(container);
        }
        InvoicesCollectionBladeViewModel.prototype._setupCommandBar = function () {
            this._markAsPaidButton = this._createMarkAsPaidButton();
            this._downloadAllInvoiceAsCsvButton = this._createDownloadInvoicesAsCsvButton();
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([this._downloadAllInvoiceAsCsvButton, this._markAsPaidButton]);
            this._markAsPaidButton.disabled(true);
        };
        InvoicesCollectionBladeViewModel.prototype._createMarkAsPaidButton = function () {
            var _this = this;
            var markInvoiceAsPaidButton = new FxToolbars.DialogButton({
                label: "Mark As Paid",
                icon: MsPortalFx.Base.Images.Check(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to mark the selected invoice as paid ?", 4),
                command: {
                    canExecute: ko.observable(true),
                    execute: function (result) {
                        if (result === 6) {
                            _this.invoicesGrid.loading(true);
                            var q = _this._dataContext.sharedContext.invoicesDataManager.markInvoiceAsPaid(_this.adminSubscriptionId(), _this.selectedInvoices().first().Id())
                                .then(function () {
                                _this.invoicesGrid.loading(false);
                            });
                            return q;
                        }
                    }
                }
            });
            return markInvoiceAsPaidButton;
        };
        InvoicesCollectionBladeViewModel.prototype._createDownloadInvoicesAsCsvButton = function () {
            var _this = this;
            var downloadInvoicesAsCsvButton = new MsPortalFx.ViewModels.Toolbars.FileDownloadButton({
                label: "Download Invoices As Csv",
                targetUriCallback: ko.observable(function () {
                    var args = _this._getDownloadCSVArgs();
                    var downloadUri = _this._dataContext.sharedContext.invoicesDataManager.downloadInvoicesAsCsvUriFormat(args);
                    return Q(downloadUri);
                }),
                addDefaultAuthorizationToken: true,
            });
            return downloadInvoicesAsCsvButton;
        };
        InvoicesCollectionBladeViewModel.prototype._getDownloadCSVArgs = function () {
            var st = this.selectedBillingPeriod() != undefined ? new Date(this.selectedBillingPeriod().StartDate) : new Date();
            var month = st.getMonth() + 1;
            var year = st.getFullYear();
            return {
                subscriptionId: this.adminSubscriptionId(),
                location: this.location(),
                year: year,
                month: month,
                isUserLevel: false,
            };
        };
        InvoicesCollectionBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            var _this = this;
            this.adminSubscriptionId(inputs.adminSubscriptionId);
            this.location(inputs.location);
            return this._dataContext.sharedContext.billingOverviewManager.getBillingPeriods(inputs.adminSubscriptionId, inputs.location).then(function (billingPeriods) {
                var eligibleBillingPeriod = billingPeriods.filter(function (bp) { return !bp.IsCurrent; });
                var billingPeriodDropdownValues = eligibleBillingPeriod.map(function (bp) {
                    return {
                        text: ko.observable(bp.Label),
                        value: bp,
                        disabled: ko.observable(false),
                    };
                });
                _this.billingPeriodsDropDown.options(billingPeriodDropdownValues);
                _this.billingPeriodsDropDown.value(eligibleBillingPeriod.first());
                _this.billingPeriodsDropDown.disabled(false);
            });
        };
        InvoicesCollectionBladeViewModel.prototype._initBarChart = function (container) {
            var _this = this;
            this.barChartVM = new MsPortalFx.ViewModels.Controls.Visualization.Chart.ViewModel(container);
            var view = new MsPortalFx.ViewModels.Controls.Visualization.Chart.BarChartView(1);
            this.barChartVM.views([view]);
            this.barChartVM.xAxis.rotateLabel(-45);
            this.barChartVM.xAxis.labelPadding(200);
            this.barChartVM.yAxis.showGridLines(true);
            this.barChartVM.legendPosition(2);
            var invoiceAmountSeries = new MsPortalFx.ViewModels.Controls.Visualization.Chart.Series();
            invoiceAmountSeries.name("Amount");
            this._dataQueryView.items.mapInto(container, function (itemLifetime, invoice) {
                var st = new Date(invoice.InvoiceStartTime());
                var startTimeString = _this._getUtcDateString(st);
                return {
                    xValue: startTimeString,
                    yValue: invoice.FinalBillableAmount()
                };
            }, invoiceAmountSeries.values);
            this.barChartVM.series([invoiceAmountSeries]);
        };
        InvoicesCollectionBladeViewModel.prototype._getBillingPeriod = function (invoice) {
            var st = new Date(invoice.InvoiceStartTime());
            var et = new Date(invoice.InvoiceEndTime());
            var startTimeString = this._getUtcDateString(st);
            var endTimeString = this._getUtcDateString(et);
            var period = "{0}-{1}".format(startTimeString, endTimeString);
            return period;
        };
        InvoicesCollectionBladeViewModel.prototype._getUtcDate = function (date) {
            var dateUtc = new Date(date.getUTCFullYear(), date.getUTCMonth(), date.getUTCDate(), date.getUTCHours(), date.getUTCMinutes(), date.getUTCSeconds());
            return dateUtc;
        };
        InvoicesCollectionBladeViewModel.prototype._getUtcDateString = function (date) {
            return "{0}/{1}/{2}".format(date.getUTCMonth() + 1, date.getUTCDate(), date.getUTCFullYear());
        };
        return InvoicesCollectionBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.InvoicesCollectionBladeViewModel = InvoicesCollectionBladeViewModel;
});
