var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Shared/Helpers"], function (require, exports, Helpers) {
    "use strict";
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var Dialogs = MsPortalFx.ViewModels.Dialogs;
    var Images = MsPortalFx.Base.Images;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var CspCustomerProfileRequestGridViewModel = (function (_super) {
        __extends(CspCustomerProfileRequestGridViewModel, _super);
        function CspCustomerProfileRequestGridViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.selectedCustomerProfile = ko.pureComputed(function () {
                return _this.cspCustomerProfilesGrid.selectableData.selectedItems().first();
            });
            this.subscriptionId = ko.observable("");
            this.location = ko.observable("");
            this.customerProfileProfileId = ko.observable("");
            this.title("Customer Profile Requests");
            this.description("Customer Profile Requests");
            this.icon(Images.Customize());
            this._container = container;
            this._dataContext = dataContext;
            this._cspProfileRequestsEntityView = dataContext.cspDataManager.getCustomerProfileList.createView(container);
            this.formSection = new FxForms.Section.ViewModel(container, {
                style: ko.observable(3),
                children: ko.observableArray([])
            });
            var gridExtensions = FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                selectableRow: {
                    selectionMode: 1,
                    activateOnSelected: ko.observable(false)
                }
            };
            this.cspCustomerProfilesGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "WapUserId",
                    name: ko.observable("User ID"),
                    activatable: ko.observable(true),
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: Helpers.getGridNameActivatableTemplate(),
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    }
                },
                {
                    itemKey: "SubscriptionId",
                    name: ko.observable("Azure Stack Subscription ID"),
                },
                {
                    itemKey: "TenantId",
                    name: ko.observable("Microsoft ID"),
                },
                {
                    itemKey: "SignupStateString",
                    name: ko.observable("Approval Status"),
                },
            ];
            this.cspCustomerProfilesGrid.columns = ko.observableArray(basicColumns);
            this.cspCustomerProfilesGrid.showHeader = true;
            this.cspCustomerProfilesGrid.summary = ko.observable("Summary");
            this.cspCustomerProfilesGrid.noRowsMessage("No Customer profiles found");
            this._cspProfileRequestsEntityView.item.subscribe(container, function (customerProfiles) {
                var transformedItems = customerProfiles.map(function (customerProfile) {
                    return $.extend({}, customerProfile, {});
                });
                _this.cspCustomerProfilesGrid.items(transformedItems);
            });
            this._cspProfileRequestsEntityView.loading.subscribe(container, function (isLoading) {
                _this.cspCustomerProfilesGrid.loading(isLoading);
            });
            this._setupCommandBar();
        }
        CspCustomerProfileRequestGridViewModel.prototype._setupCommandBar = function () {
            this._approveCspCustoomerProfileButton = this._createApproveProfileButton();
            this._rejectCspCustomerProfileButton = this._createRejectProfileButton();
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([
                this._approveCspCustoomerProfileButton,
                this._rejectCspCustomerProfileButton,
            ]);
        };
        CspCustomerProfileRequestGridViewModel.prototype._createApproveProfileButton = function () {
            var _this = this;
            var approveButton = new FxToolbars.DialogButton({
                label: "Approve",
                icon: MsPortalFx.Base.Images.Commit(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to approve the selected customer profile ?", 4),
            });
            approveButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedCustomerProfile() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.cspDataManager.approveCustomerProfileQuery(_this.subscriptionId(), _this.location(), _this.selectedCustomerProfile().SubscriptionId(), _this.selectedCustomerProfile().TenantId());
                    }
                    return null;
                }
            };
            return approveButton;
        };
        CspCustomerProfileRequestGridViewModel.prototype._createRejectProfileButton = function () {
            var _this = this;
            var rejectButton = new FxToolbars.DialogButton({
                label: "Reject",
                icon: MsPortalFx.Base.Images.Discard(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to reject the selected customer profile ?", 4),
            });
            rejectButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedCustomerProfile() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.cspDataManager.rejectCustomerProfileQuery(_this.subscriptionId(), _this.location(), _this.selectedCustomerProfile().SubscriptionId(), _this.selectedCustomerProfile().TenantId());
                    }
                    return null;
                }
            };
            return rejectButton;
        };
        CspCustomerProfileRequestGridViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            var args = {
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            };
            return this._cspProfileRequestsEntityView.fetch({
                subscriptionId: inputs.subscriptionId,
                location: inputs.location,
            });
        };
        return CspCustomerProfileRequestGridViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.CspCustomerProfileRequestGridViewModel = CspCustomerProfileRequestGridViewModel;
});
