var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports"], function (require, exports) {
    "use strict";
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var CspOffersGridBladeViewModel = (function (_super) {
        __extends(CspOffersGridBladeViewModel, _super);
        function CspOffersGridBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable();
            this.location = ko.observable();
            this.selectedCspOffers = ko.observableArray([]);
            this.title("Cloud Csps");
            this._container = container;
            this._dataContext = dataContext;
            this._dataQueryView = dataContext.cspDataManager.cspOffersQuery.createView(container);
            var gridExtensions = FxGridExtensions.Filterable | FxGridExtensions.SortableColumn | FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                filterable: {
                    searchBoxCloseButtonVisible: ko.observable(false),
                    searchBoxPlaceholder: ko.observable("Search to filter items..."),
                    searchBoxVisible: ko.observable(true),
                    searchableColumns: ko.observableArray(["Name", "CategoryName", "ProductName"])
                },
                selectableRow: {
                    selectionMode: 2
                }
            };
            this.cspOffersGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "Id",
                    name: ko.observable("Id"),
                },
                {
                    itemKey: "Name",
                    name: ko.observable("Name")
                },
                {
                    itemKey: "ProductName",
                    name: ko.observable("Produt"),
                },
                {
                    itemKey: "CategoryName",
                    name: ko.observable("Category"),
                },
            ];
            this.cspOffersGrid.columns = ko.observableArray(basicColumns);
            this.cspOffersGrid.showHeader = true;
            this.cspOffersGrid.summary = ko.observable("Summary");
            this.cspOffersGrid.noRowsMessage("No items found");
            this.cspOffersGrid.selectableData.selectedItems.subscribe(container, function (selectedItems) {
                if (!selectedItems || selectedItems.length === 0) {
                    _this.selectedCspOffers([]);
                    return;
                }
                _this.selectedCspOffers(selectedItems);
            });
            this._dataQueryView.items.subscribe(container, function (cspOffers) {
                var transformedCspOffer = cspOffers.map(function (c) {
                    return $.extend({}, c, {
                        ProductName: c.Product().Name,
                        CategoryName: c.Category().Name,
                    });
                });
                _this.cspOffersGrid.items(transformedCspOffer);
            });
            this._setupCommandBar();
        }
        CspOffersGridBladeViewModel.prototype._setupCommandBar = function () {
            var _this = this;
            this.publishButton = new MsPortalFx.ViewModels.Toolbars.CommandButton();
            this.publishButton.label("Publish to Gallery");
            this.publishButton.icon(MsPortalFx.Base.Images.Publish());
            this.publishButton.commandContext = ko.observable({
                subscriptionId: this.subscriptionId,
                location: this.location,
                cspDataManager: this._dataContext.cspDataManager,
                selectedCspOffers: this.selectedCspOffers
            });
            this.publishButton.command = {
                canExecute: ko.pureComputed(function () { return _this.selectedCspOffers && _this.selectedCspOffers() && _this.selectedCspOffers().length > 0; }),
                execute: function (context) {
                    var cspOffers = context.selectedCspOffers();
                    console.log("Publishing the CSP Offers ", cspOffers, "to gallery ...");
                    var cspOfferIds = cspOffers.map(function (t) { return t.Id; });
                    return context.cspDataManager.publishToGallery(context.subscriptionId(), context.location(), cspOfferIds);
                }
            };
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([this.publishButton]);
        };
        CspOffersGridBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            var args = {
                subscriptionId: inputs.subscriptionId,
                location: inputs.location
            };
            return this._dataQueryView.fetch(args);
        };
        return CspOffersGridBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.CspOffersGridBladeViewModel = CspOffersGridBladeViewModel;
});
