var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Shared/Resources", "../../_generated/BladeReferences", "Fx/Controls/Essentials"], function (require, exports, Resources, BladeReferences, Essentials_1) {
    "use strict";
    var FxControls = MsPortalFx.ViewModels.Controls;
    var LicenseOverviewBladeViewModel = (function (_super) {
        __extends(LicenseOverviewBladeViewModel, _super);
        function LicenseOverviewBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable();
            this.location = ko.observable();
            this.remainingDays = ko.observable();
            this.isShowExtendTrialLicense = ko.observable();
            this.licenseFeatures = ko.observableArray();
            this.featureQuotas = ko.observableArray();
            this.productInfo = ko.observable();
            this.productFeatures = ko.observable();
            this.isVisibleExpiryBox = ko.observable(false);
            this.cloudAssertLogoImage = ko.observable(Resources.Icon.LicenseLogoImage);
            this.title("Usage and Billing License");
            this._container = container;
            this._dataContext = dataContext;
            this.dataEntityView = dataContext.licenseDataManager.enabledFeaturesEntity.createView(container);
            this._activationTextEntityView = dataContext.licenseDataManager.getActivationTextEntity.createView(container);
            this.currentLicenseEssential = ko.observable(null);
            this.activationText = new FxControls.Forms.CopyableLabel.ViewModel(container);
            this.expiryInfoBox = new FxControls.InfoBox.ViewModel(container, false);
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.dataEntityView.item.subscribe(container, function (productInfo) {
                _this.productInfo(productInfo);
                _this.productFeatures(_this.productInfo().EnabledFeatures());
                _this.remainingDays(_this.productInfo().LicenseRemainingDays());
                _this.isShowExtendTrialLicense(_this.remainingDays() <= 7 && _this.remainingDays() > 0);
                _this.productInfo().EnabledFeatures().forEach(function (x) {
                    if (x.Quotas().length != 0) {
                        _this.featureQuotas.push(x);
                    }
                });
                if (_this.licenseFeatures().length == 0)
                    _this.productInfo().EnabledFeatures().forEach(function (x) { return _this.licenseFeatures.push(_this._getFeatureData(x)); });
                _this._initializeControl(_this._container);
                _this._initializeExpiryInfoBox(_this._container);
                _this._setupCommandBar();
            });
            this._activationTextEntityView.item.subscribe(container, function (activationText) {
                _this.activationText.value(activationText.ActivationKey());
            });
        }
        LicenseOverviewBladeViewModel.prototype._getFeatureData = function (input) {
            return {
                Name: input.Name(),
                Expiry: new Date(input.License().Expiration()).toDateString().substr(4),
            };
        };
        LicenseOverviewBladeViewModel.prototype._setupCommandBar = function () {
            var _this = this;
            var toolbarItems = [];
            var extendTrialButton = new MsPortalFx.ViewModels.Toolbars.CommandButton({
                label: "Extend Trial License",
                icon: MsPortalFx.Base.Images.Expand(),
                command: {
                    execute: function () {
                        return _this._container.openBlade(new BladeReferences.ActivateLicenseFormBladeReference({
                            subscriptionId: _this.subscriptionId(),
                            location: _this.location(),
                            isExtendLicense: true,
                        }));
                    },
                    canExecute: ko.observable(false)
                }
            });
            if (this.isShowExtendTrialLicense())
                toolbarItems.push(extendTrialButton);
            this.commandBar.setItems(toolbarItems);
        };
        LicenseOverviewBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            var _this = this;
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            var args = {
                subscriptionId: inputs.subscriptionId,
                location: inputs.location,
            };
            return this.dataEntityView.fetch(args).then(function () { return _this._activationTextEntityView.fetch(args); });
        };
        LicenseOverviewBladeViewModel.prototype._initializeControl = function (container) {
            var expiryDate = new Date(this.productFeatures().first().License().Expiration()).toDateString().substr(4);
            var essential = new Essentials_1.ViewModel(container, {
                left: [
                    {
                        label: "Product Name",
                        value: this.productInfo().ProductName()
                    },
                    {
                        label: "Product Id",
                        value: this.productInfo().ProductId()
                    },
                    {
                        label: "Product Edition",
                        value: this.productInfo().ProductEdition()
                    }
                ],
                right: [
                    {
                        label: "Product Version",
                        value: this.productInfo().LicensedVersion()
                    },
                    {
                        label: "Installed Version",
                        value: this.productInfo().InstalledVersion()
                    },
                    {
                        label: "Expiration",
                        value: expiryDate == 'Dec 31 9999' ? "-" : expiryDate
                    }
                ],
                expanded: ko.observable(true),
            });
            this.currentLicenseEssential(essential);
            this.activationText.disabled(true);
        };
        LicenseOverviewBladeViewModel.prototype._initializeExpiryInfoBox = function (container) {
            this.expiryInfoBox.size(FxControls.InfoBox.Size.Normal);
            var isLicenseExpired = this.productInfo().IsLicenseExpired();
            var warningString = "Your license will expire in {0} day(s)!";
            var expiredString = "Your License has expired!";
            if (isLicenseExpired) {
                this.expiryInfoBox.image(MsPortalFx.Base.Images.StatusBadge.Error());
                this.expiryInfoBox.text(expiredString);
                this.isVisibleExpiryBox(true);
                return;
            }
            if (this.isShowExtendTrialLicense()) {
                this.expiryInfoBox.image(MsPortalFx.Base.Images.StatusBadge.Warning());
                this.expiryInfoBox.text(warningString.format(this.remainingDays()));
                this.isVisibleExpiryBox(true);
                return;
            }
            this.isVisibleExpiryBox(false);
        };
        return LicenseOverviewBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.LicenseOverviewBladeViewModel = LicenseOverviewBladeViewModel;
});
