var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Shared/Helpers", "../../_generated/BladeReferences"], function (require, exports, Helpers, BladeReferences) {
    "use strict";
    var FxForms = MsPortalFx.ViewModels.Forms;
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var Dialogs = MsPortalFx.ViewModels.Dialogs;
    var ArmHelpers = Common.Helpers;
    var MeteredResourceCollectionBladeViewModel = (function (_super) {
        __extends(MeteredResourceCollectionBladeViewModel, _super);
        function MeteredResourceCollectionBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.adminSubscriptionId = ko.observable();
            this.pricingProfileId = ko.observable();
            this.location = ko.observable("local");
            this.selectedMeteredResource = ko.pureComputed(function () {
                return _this.meteredResourcesGrid.selectableData.selectedItems().first();
            });
            this.title("Metered Resources");
            this._container = container;
            this._dataContext = dataContext;
            this._dataQueryView = dataContext.meteredResourcePricingDataManager.listMeteredResourcesQuery.createView(container, {
                interceptNotFound: false
            });
            this.formSection = new FxForms.Section.ViewModel(container, {
                style: ko.observable(3),
                children: ko.observableArray([])
            });
            var gridExtensions = FxGridExtensions.Filterable | FxGridExtensions.SortableColumn | FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                filterable: {
                    searchBoxCloseButtonVisible: ko.observable(false),
                    searchBoxPlaceholder: ko.observable("Search to filter items..."),
                    searchBoxVisible: ko.observable(true),
                    searchableColumns: ko.observableArray(["Id", "MeteredResourceDisplayName", "MeteredResourceName", "ServiceType"])
                },
                selectableRow: {
                    selectionMode: 1,
                    activateOnSelected: ko.observable(false)
                }
            };
            this.meteredResourcesGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "Id",
                    name: ko.observable("Id"),
                    width: ko.observable("50px"),
                },
                {
                    itemKey: "MeteredResourceDisplayName",
                    name: ko.observable("Metered Resource Name"),
                    width: ko.observable("120px"),
                    activatable: ko.observable(true),
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: Helpers.getGridNameActivatableTemplate(),
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    }
                },
                {
                    itemKey: "MeteredResourceName",
                    name: ko.observable("Meter Id"),
                    width: ko.observable("140px"),
                },
                {
                    itemKey: "ServiceType",
                    name: ko.observable("Service Type"),
                    width: ko.observable("100px"),
                },
                {
                    itemKey: "MonthlyUnitPrice",
                    name: ko.observable("Monthly Unit Price"),
                    width: ko.observable("50px"),
                },
                {
                    itemKey: "IsCollectionEnabled",
                    name: ko.observable("Is Enabled"),
                    width: ko.observable("50px"),
                },
            ];
            this.meteredResourcesGrid.columns = ko.observableArray(basicColumns);
            this.meteredResourcesGrid.showHeader = true;
            this.meteredResourcesGrid.summary = ko.observable("Summary");
            this.meteredResourcesGrid.noRowsMessage("No items found");
            this._dataQueryView.items.subscribe(container, function (meteredResources) {
                _this.meteredResourcesGrid.items(meteredResources);
            });
            this._dataQueryView.loading.subscribe(container, function (isLoading) {
                _this.meteredResourcesGrid.loading(isLoading);
            });
            this._setupCommandBar();
        }
        MeteredResourceCollectionBladeViewModel.prototype._setupCommandBar = function () {
            this._cloneMeteredResourceButton = this._createCloneMeteredResourceButton();
            this._deleteMeteredResourceButton = this._createDeleteMeteredResourceButton();
            this._updateMetersOnlineButton = this._createUpdateMetersOnlineButton();
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([
                this._cloneMeteredResourceButton,
                this._deleteMeteredResourceButton,
            ]);
        };
        MeteredResourceCollectionBladeViewModel.prototype._createCloneMeteredResourceButton = function () {
            var _this = this;
            var cloneButton = new FxToolbars.DialogButton({
                label: "Clone",
                icon: MsPortalFx.Base.Images.Clone(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to clone the selected meter ?", 4),
            });
            cloneButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedMeteredResource() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.meteredResourcePricingDataManager.cloneMeteredResourceQuery(_this.adminSubscriptionId(), _this.location(), _this.selectedMeteredResource().Id())
                            .finally(function () {
                            _this._dataContext.meteredResourcePricingDataManager.listMeteredResourcesQuery.refreshAll();
                        });
                    }
                    return null;
                }
            };
            return cloneButton;
        };
        MeteredResourceCollectionBladeViewModel.prototype._createDeleteMeteredResourceButton = function () {
            var _this = this;
            var cloneButton = new FxToolbars.DialogButton({
                label: "Delete",
                icon: MsPortalFx.Base.Images.Delete(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to delete the selected meter ?", 4),
            });
            cloneButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedMeteredResource() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.meteredResourcePricingDataManager.deleteMeteredResourceQuery(_this.adminSubscriptionId(), _this.location(), _this.selectedMeteredResource().Id())
                            .finally(function () {
                            _this._dataContext.meteredResourcePricingDataManager.listMeteredResourcesQuery.refreshAll();
                        });
                    }
                    return null;
                }
            };
            return cloneButton;
        };
        MeteredResourceCollectionBladeViewModel.prototype._createUpdateMetersOnlineButton = function () {
            var _this = this;
            var updateMetersButton = new FxToolbars.CommandButton({
                label: "Update Meters Online",
                icon: MsPortalFx.Base.Images.Upload(),
                command: {
                    execute: function () {
                        return _this._container.openBlade(new BladeReferences.AvailablePricingProfileBladeReference({
                            adminSubscriptionId: _this.adminSubscriptionId(),
                            location: _this.location(),
                            pricingProfileId: _this.pricingProfileId(),
                        }));
                    },
                    canExecute: ko.computed(this._container, function () {
                        return true;
                    }),
                }
            });
            return updateMetersButton;
        };
        MeteredResourceCollectionBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.adminSubscriptionId(inputs.adminSubscriptionId);
            this.location(inputs.location);
            this.pricingProfileId(inputs.pricingProfileId);
            return this._dataQueryView.fetch({
                subscriptionId: this.adminSubscriptionId(),
                location: this.location(),
                pricingProfileId: this.pricingProfileId(),
            });
        };
        return MeteredResourceCollectionBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.MeteredResourceCollectionBladeViewModel = MeteredResourceCollectionBladeViewModel;
});
