var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Models/NotificationsModel"], function (require, exports, NotificationsModel) {
    "use strict";
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var Dialogs = MsPortalFx.ViewModels.Dialogs;
    var Images = MsPortalFx.Base.Images;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var NotificationAddEditBladeViewModel = (function (_super) {
        __extends(NotificationAddEditBladeViewModel, _super);
        function NotificationAddEditBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this._selectedEvent = ko.observable();
            this.isAdd = ko.observable(true);
            this.subscriptionId = ko.observable("");
            this.selectedRule = ko.observable();
            this.location = ko.observable("");
            this.icon(Images.Customize());
            this._container = container;
            this._dataContext = dataContext;
            this._initializeFormFields(container);
            this.eventsDdownField.value.subscribe(container, function (selectedEvent) {
                if (selectedEvent != null) {
                    _this._selectedEvent(selectedEvent);
                }
            });
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(container);
            this._setupCommandBar();
        }
        NotificationAddEditBladeViewModel.prototype._setupCommandBar = function () {
            this._saveButton = this._createSaveButton();
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([
                this._saveButton,
            ]);
        };
        NotificationAddEditBladeViewModel.prototype._createSaveButton = function () {
            var _this = this;
            var saveButton = new FxToolbars.DialogButton({
                label: "Save",
                icon: MsPortalFx.Base.Images.Commit(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to save ?", 4),
            });
            saveButton.command = {
                canExecute: ko.observable(true),
                execute: function (context) {
                    if (context === 6) {
                        return _this._container.form.triggerValidation().then(function (validationPassed) {
                            if (validationPassed) {
                                return _this._onSaveChanges();
                            }
                            return null;
                        });
                    }
                },
            };
            return saveButton;
        };
        NotificationAddEditBladeViewModel.prototype._onSaveChanges = function () {
            var _this = this;
            var notificationRuleIn = {
                Id: this.selectedRule().Id.toString(),
                DisplayName: this.displayNameTxField.value(),
                RuleProviderId: this._selectedEvent(),
                NotificationEmails: this.emailIdsTxField.value(),
                IsEnabled: this.isRuleEnabledOptionField.value(),
                RuleParams: this._getRuleParams(),
            };
            var dataManager = this._dataContext.notificationsDataManager;
            var op;
            if (this.isAdd()) {
                notificationRuleIn.Id = '0';
                op = dataManager.addNotificationRuleQuery(this.subscriptionId(), this.location(), notificationRuleIn);
            }
            else {
                op = dataManager.updateNotificationRuleQuery(this.subscriptionId(), this.location(), notificationRuleIn);
            }
            this._container.operations.add(op, { blockUi: true });
            return op.then(function () {
                return {
                    action: MsPortalFx.Data.AcceptEditScopeChangesAction.AcceptClientChanges
                };
            }).finally(function () {
                dataManager.listNotificationRulesEntity.refreshAll();
                _this._container.closeCurrentBlade();
            });
        };
        NotificationAddEditBladeViewModel.prototype._getRuleParams = function () {
            var ruleParams = {};
            var creditGreaterThan = this.creditGreaterThanTxField.value();
            var creditLessThan = this.creditLessThanTxField.value();
            ruleParams['CreditBalanceGreaterThan'] = creditGreaterThan;
            ruleParams['CreditBalanceLessThan'] = creditLessThan;
            return ruleParams;
        };
        NotificationAddEditBladeViewModel.prototype._initializeFormFields = function (container) {
            var displayNameTxFieldOptions = {
                label: ko.observable("Display Name"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.displayNameTxField = new MsPortalFx.ViewModels.Forms.TextBox.ViewModel(container, displayNameTxFieldOptions);
            var emailIdsTxFieldOptions = {
                label: ko.observable("Email Ids"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RegExMatchValidation("^$|^\\b[A-Za-z0-9._%-]+@[A-Za-z0-9.-]+\\.[A-Za-z]{2,4}\\b", "Invalid Email Address")
                ]),
            };
            this.emailIdsTxField = new MsPortalFx.ViewModels.Forms.TextBox.ViewModel(container, emailIdsTxFieldOptions);
            var eventsDdownFieldOptions = {
                label: ko.observable('Event'),
                options: ko.observableArray([
                    { text: ko.observable("Credit Checker"), value: "LowCreditValue" }
                ]),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.eventsDdownField = new MsPortalFx.ViewModels.Obsolete.Forms.DropDown.ViewModel(container, eventsDdownFieldOptions);
            var isRuleEnabledOption = {
                label: ko.observable("Enable Rule ?"),
                options: ko.observableArray([
                    { text: ko.observable("Yes"), value: true },
                    { text: ko.observable("No"), value: false }
                ]),
            };
            this.isRuleEnabledOptionField = new FxForms.OptionsGroup.ViewModel(container, isRuleEnabledOption);
            var creditGreaterThanTxFieldOptions = {
                label: ko.observable("Credit Greater Than"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
                decimalPoint: ko.observable(10),
            };
            this.creditGreaterThanTxField = new MsPortalFx.ViewModels.Forms.TextBox.ViewModel(container, creditGreaterThanTxFieldOptions);
            var creditLessThanTxFieldOptions = {
                label: ko.observable("Credit Less Than"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
                decimalPoint: ko.observable(10),
            };
            this.creditLessThanTxField = new MsPortalFx.ViewModels.Forms.TextBox.ViewModel(container, creditLessThanTxFieldOptions);
            this.formSection = new FxForms.Section.ViewModel(container, {
                children: ko.observableArray([
                    this.displayNameTxField,
                    this.emailIdsTxField,
                    this.eventsDdownField,
                    this.isRuleEnabledOptionField,
                    this.creditGreaterThanTxField,
                    this.creditLessThanTxField,
                ])
            });
        };
        NotificationAddEditBladeViewModel.prototype._setFormFields = function (data) {
            this.displayNameTxField.value(data.DisplayName.toString());
            this.emailIdsTxField.value(data.NotificationEmails.toString());
            this.eventsDdownField.value(data.RuleProviderId.toString());
            this.isRuleEnabledOptionField.value(data.IsEnabled);
            this.creditGreaterThanTxField.value(data.RuleParams.CreditBalanceGreaterThan);
            this.creditLessThanTxField.value(data.RuleParams.CreditBalanceLessThan);
        };
        NotificationAddEditBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.isAdd(inputs.isAdd);
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            this.selectedRule(inputs.selectedRule);
            var title = this.isAdd() ? "Create new Rule" : "Edit Rule";
            this.title(title);
            this.description(title);
            if (!this.isAdd()) {
                this.eventsDdownField.disabled(true);
            }
            var data = NotificationsModel.NotificationRulesOutModel.getNotificationRulesOutData(this.selectedRule());
            this._setFormFields(data);
            return Q();
        };
        return NotificationAddEditBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.NotificationAddEditBladeViewModel = NotificationAddEditBladeViewModel;
});
