var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Shared/Helpers"], function (require, exports, Helpers) {
    "use strict";
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var Dialogs = MsPortalFx.ViewModels.Dialogs;
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    "use strict";
    var NotificationMessagesBladeViewModel = (function (_super) {
        __extends(NotificationMessagesBladeViewModel, _super);
        function NotificationMessagesBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable();
            this.location = ko.observable();
            this._userOverview = ko.observable();
            this.selectedMessage = ko.pureComputed(function () {
                return _this.notificationsGrid.selectableData.selectedItems().first();
            });
            this.title("Messages");
            this._container = container;
            this._dataContext = dataContext;
            this._dataEntityView = dataContext.notificationsDataManager.listNotificationsEntity.createView(container, {
                interceptNotFound: false
            });
            ko.reactor(container, function () {
            });
            var gridExtensions = FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                selectableRow: {
                    selectionMode: 1,
                    activateOnSelected: ko.observable(false)
                }
            };
            this.notificationsGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var dateTimeFormat = Helpers.getTimeFormat(false, true);
            var basicColumns = [
                {
                    itemKey: "Title",
                    name: ko.observable("Title"),
                    width: ko.observable("120px"),
                    activatable: ko.observable(true),
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: Helpers.getGridNameActivatableTemplate(),
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    }
                },
                {
                    itemKey: "Description",
                    name: ko.observable("Description"),
                    width: ko.observable("120px"),
                },
                {
                    itemKey: "IsDismissed",
                    name: ko.observable("Is Active"),
                    width: ko.observable("50px"),
                },
                {
                    itemKey: "LevelString",
                    name: ko.observable("Level"),
                    width: ko.observable("50px"),
                },
                {
                    itemKey: "TimestampString",
                    name: ko.observable("Time Stamp"),
                    width: ko.observable("50px"),
                    format: MsPortalFx.ViewModels.Controls.Lists.Grid.Format.CustomDate,
                    formatOptions: {
                        dateFormat: dateTimeFormat
                    }
                },
            ];
            this.notificationsGrid.columns = ko.observableArray(basicColumns);
            this.notificationsGrid.showHeader = true;
            this.notificationsGrid.summary = ko.observable("Summary");
            this.notificationsGrid.noRowsMessage("No items found");
            this._dataEntityView.item.subscribe(container, function (notifications) {
                _this.notificationsGrid.items(notifications);
            });
            this._dataEntityView.loading.subscribe(container, function (isLoading) {
                _this.notificationsGrid.loading(isLoading);
            });
            this._setupCommandBar();
        }
        NotificationMessagesBladeViewModel.prototype._setupCommandBar = function () {
            this._dismissNotificationButton = this._createDismissNotificationButton();
            this._deleteNotificationButton = this._createDeleteNotificationButton();
            this._clearAllNotificationButton = this._createClearAllNotificationButton();
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([
                this._dismissNotificationButton,
                this._deleteNotificationButton,
                this._clearAllNotificationButton,
            ]);
        };
        NotificationMessagesBladeViewModel.prototype._createDismissNotificationButton = function () {
            var _this = this;
            var dismissButton = new FxToolbars.DialogButton({
                label: "Dismiss",
                icon: MsPortalFx.Base.Images.Disable(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to dismiss the selected notification message ?", 4),
            });
            dismissButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedMessage() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.notificationsDataManager.dismissNotificationQuery(_this.subscriptionId(), _this.location(), _this.selectedMessage().Id());
                    }
                    return null;
                }
            };
            return dismissButton;
        };
        NotificationMessagesBladeViewModel.prototype._createDeleteNotificationButton = function () {
            var _this = this;
            var deleteButton = new FxToolbars.DialogButton({
                label: "Delete",
                icon: MsPortalFx.Base.Images.Delete(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to delete the selected notification message ?", 4),
            });
            deleteButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedMessage() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.notificationsDataManager.deleteNotificationQuery(_this.subscriptionId(), _this.location(), _this.selectedMessage().Id());
                    }
                    return null;
                }
            };
            return deleteButton;
        };
        NotificationMessagesBladeViewModel.prototype._createClearAllNotificationButton = function () {
            var _this = this;
            var clearButton = new FxToolbars.DialogButton({
                label: "Clear All",
                icon: MsPortalFx.Base.Images.Clock(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to clear all notification message ?", 4),
            });
            clearButton.command = {
                canExecute: ko.observable(true),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.notificationsDataManager.clearAllNotificationsQuery(_this.subscriptionId(), _this.location());
                    }
                    return null;
                }
            };
            return clearButton;
        };
        NotificationMessagesBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            return this._dataEntityView.fetch({
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            });
        };
        return NotificationMessagesBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.NotificationMessagesBladeViewModel = NotificationMessagesBladeViewModel;
});
