var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../_generated/BladeReferences"], function (require, exports, BladeReferences) {
    "use strict";
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var Images = MsPortalFx.Base.Images;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var PricingProfileMappingBladeViewModel = (function (_super) {
        __extends(PricingProfileMappingBladeViewModel, _super);
        function PricingProfileMappingBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.selectedProfileMapping = ko.pureComputed(function () {
                return _this.mappedProfilesGrid.selectableData.selectedItems().first();
            });
            this.subscriptionId = ko.observable("");
            this.location = ko.observable("");
            this.title("Link/Unlink Base Profiles");
            this.description("Link/Unlink Base Profiles");
            this.icon(Images.Customize());
            this._container = container;
            this._dataContext = dataContext;
            this._mappedProfilesEntityView = dataContext.pricingProfilesDataManager.mappedProfilesQuery.createView(container);
            this.formSection = new FxForms.Section.ViewModel(container, {
                style: ko.observable(3),
                children: ko.observableArray([])
            });
            var gridExtensions = FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                selectableRow: {
                    selectionMode: 1,
                    activateOnSelected: ko.observable(false)
                }
            };
            this.mappedProfilesGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "ProfileId",
                    name: ko.observable("Profile Id"),
                    activatable: ko.observable(true),
                },
                {
                    itemKey: "ProfileName",
                    name: ko.observable("Profile Name"),
                    activatable: ko.observable(true),
                },
                {
                    itemKey: "MarkupPercent",
                    name: ko.observable("Markup Percent"),
                },
                {
                    itemKey: "LinkedProfiles",
                    name: ko.observable("Linked Base Profile(s)"),
                },
            ];
            this.mappedProfilesGrid.columns = ko.observableArray(basicColumns);
            this.mappedProfilesGrid.showHeader = true;
            this.mappedProfilesGrid.summary = ko.observable("Summary");
            this.mappedProfilesGrid.noRowsMessage("No profile mappings found");
            this._mappedProfilesEntityView.item.subscribe(container, function (mappedProfiles) {
                var transformedItems = mappedProfiles.map(function (mappedProfile) {
                    return $.extend({}, mappedProfile, {});
                });
                _this.mappedProfilesGrid.items(transformedItems);
            });
            this._mappedProfilesEntityView.loading.subscribe(container, function (isLoading) {
                _this.mappedProfilesGrid.loading(isLoading);
            });
            this._setupCommandBar();
        }
        PricingProfileMappingBladeViewModel.prototype._setupCommandBar = function () {
            this._linkBaseProfileButton = this._createLinkProfileButton();
            this._unlinkBaseProfileButton = this._createUnlinkProfileButton();
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([
                this._linkBaseProfileButton,
                this._unlinkBaseProfileButton,
            ]);
        };
        PricingProfileMappingBladeViewModel.prototype._createLinkProfileButton = function () {
            var _this = this;
            var linkButton = new FxToolbars.CommandButton({
                label: "Link",
                icon: MsPortalFx.Base.Images.Connect(),
                command: {
                    execute: function () {
                        return _this._container.openBlade(new BladeReferences.PricingProfileLinkUnlinkBladeReference({
                            isLink: true,
                            subscriptionId: _this.subscriptionId(),
                            location: _this.location(),
                            selectedPricingProfile: _this.selectedProfileMapping().ProfileName(),
                            selectedPricingProfileId: _this.selectedProfileMapping().ProfileId(),
                            linkedBaseProfiles: _this.selectedProfileMapping().BaseProfiles(),
                        }));
                    },
                    canExecute: ko.computed(this._container, function () {
                        return _this.selectedProfileMapping() != null && _this.selectedProfileMapping().BaseProfiles().length < _this.selectedProfileMapping().MaxBaseProfileLinkCount();
                    }),
                }
            });
            return linkButton;
        };
        PricingProfileMappingBladeViewModel.prototype._createUnlinkProfileButton = function () {
            var _this = this;
            var unlinkButton = new FxToolbars.CommandButton({
                label: "Unlink",
                icon: MsPortalFx.Base.Images.Disconnect(),
                command: {
                    execute: function () {
                        return _this._container.openBlade(new BladeReferences.PricingProfileLinkUnlinkBladeReference({
                            isLink: false,
                            subscriptionId: _this.subscriptionId(),
                            location: _this.location(),
                            selectedPricingProfile: _this.selectedProfileMapping().ProfileName(),
                            selectedPricingProfileId: _this.selectedProfileMapping().ProfileId(),
                            linkedBaseProfiles: _this.selectedProfileMapping().BaseProfiles(),
                        }));
                    },
                    canExecute: ko.computed(this._container, function () {
                        return _this.selectedProfileMapping() != null && _this.selectedProfileMapping().BaseProfiles().length > 0;
                    }),
                }
            });
            return unlinkButton;
        };
        PricingProfileMappingBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            var args = {
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            };
            return this._mappedProfilesEntityView.fetch({
                subscriptionId: inputs.subscriptionId,
                location: inputs.location,
            });
        };
        return PricingProfileMappingBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.PricingProfileMappingBladeViewModel = PricingProfileMappingBladeViewModel;
});
