var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "ClientResources", "../../Shared/Helpers", "../../_generated/BladeReferences"], function (require, exports, ClientResources, Helpers, BladeReferences) {
    "use strict";
    var FxForms = MsPortalFx.ViewModels.Forms;
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var Dialogs = MsPortalFx.ViewModels.Dialogs;
    var FileDownload = MsPortalFx.ViewModels.Controls.FileDownload;
    var FileDownloadButton = MsPortalFx.ViewModels.Controls.FileDownloadButton;
    var ArmHelpers = Common.Helpers;
    var PricingProfilesCollectionBladeViewModel = (function (_super) {
        __extends(PricingProfilesCollectionBladeViewModel, _super);
        function PricingProfilesCollectionBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.adminSubscriptionId = ko.observable();
            this.location = ko.observable("local");
            this.selectedProfile = ko.pureComputed(function () {
                return _this.pricingProfilesGrid.selectableData.selectedItems().first();
            });
            this.title("Pricing Profiles");
            this._container = container;
            this._dataContext = dataContext;
            this._dataQueryView = dataContext.pricingProfilesDataManager.pricingProfilesQuery.createView(container, {
                interceptNotFound: false
            });
            this.formSection = new FxForms.Section.ViewModel(container, {
                style: ko.observable(3),
                children: ko.observableArray([])
            });
            var gridExtensions = FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                selectableRow: {
                    selectionMode: 1,
                    activateOnSelected: ko.observable(false)
                }
            };
            this.pricingProfilesGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "Id",
                    name: ko.observable("Profile Id"),
                    width: ko.observable("60px"),
                },
                {
                    itemKey: "ProfileName",
                    name: ko.observable("Profile Name"),
                    width: ko.observable("120px"),
                    activatable: ko.observable(true),
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: Helpers.getGridNameActivatableTemplate(),
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    }
                },
                {
                    itemKey: "ISOCurrencySymbol",
                    name: ko.observable("Currency"),
                    width: ko.observable("50px"),
                },
                {
                    itemKey: "ExportProfileButton",
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: "<div data-bind='pcControl: value'></div>",
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    },
                    width: ko.observable("150px")
                },
            ];
            this.pricingProfilesGrid.columns = ko.observableArray(basicColumns);
            this.pricingProfilesGrid.showHeader = true;
            this.pricingProfilesGrid.summary = ko.observable("Summary");
            this.pricingProfilesGrid.noRowsMessage("No items found");
            this._dataQueryView.items.subscribe(container, function (pricingProfiles) {
                var transformedItems = pricingProfiles.map(function (pricingProfile) {
                    var args = {
                        subscriptionId: _this.adminSubscriptionId(),
                        location: _this.location(),
                        pricingProfileId: pricingProfile.Id(),
                    };
                    var downloadUri = _this._dataContext.pricingProfilesDataManager.exportPricingProfileUriFormat(args);
                    var pricingProfileFileDownloadContext = new FileDownload.Context({
                        targetUri: ko.observable(downloadUri),
                        httpMethod: ko.observable("GET"),
                        downloadType: ko.observable(2),
                        addDefaultAuthorizationToken: true,
                        showDownloadProgressDialog: ko.observable(true)
                    });
                    var pricingProfileDownloadLink = new FileDownloadButton.ViewModel(container, {
                        context: ko.observable(pricingProfileFileDownloadContext),
                        label: ko.observable("Export Profile"),
                        disabled: ko.observable(false),
                        asLink: true
                    });
                    return $.extend({}, pricingProfile, {
                        ExportProfileButton: pricingProfileDownloadLink,
                    });
                });
                _this.pricingProfilesGrid.items(transformedItems);
            });
            this._dataQueryView.loading.subscribe(container, function (isLoading) {
                _this.pricingProfilesGrid.loading(isLoading);
            });
            this._setupCommandBar();
        }
        PricingProfilesCollectionBladeViewModel.prototype._setupCommandBar = function () {
            this._openProfileButton = this._createOpenProfileButton();
            this._importProfileButton = this._createImportProfileButton();
            this._cloneProfileButton = this._createCloneProfileButton();
            this._deleteProfileButton = this._createDeleteProfileButton();
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([
                this._openProfileButton,
                this._importProfileButton,
                this._cloneProfileButton,
                this._deleteProfileButton,
            ]);
        };
        PricingProfilesCollectionBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.adminSubscriptionId(inputs.adminSubscriptionId);
            this.location(inputs.location);
            return this._dataQueryView.fetch({
                subscriptionId: this.adminSubscriptionId(),
                location: this.location(),
            });
        };
        PricingProfilesCollectionBladeViewModel.prototype._createOpenProfileButton = function () {
            var _this = this;
            var button = new FxToolbars.CommandButton({
                label: "Open",
                icon: MsPortalFx.Base.Images.Expand(),
                command: {
                    execute: function () {
                        return _this._container.openBlade(new BladeReferences.MeteredResourceCollectionBladeReference({
                            adminSubscriptionId: _this.adminSubscriptionId(),
                            location: _this.location(),
                            pricingProfileId: _this.selectedProfile().id(),
                        }));
                    },
                    canExecute: ko.computed(this._container, function () {
                        return _this.selectedProfile() != null;
                    }),
                }
            });
            return button;
        };
        PricingProfilesCollectionBladeViewModel.prototype._createCloneProfileButton = function () {
            var _this = this;
            var cloneButton = new FxToolbars.DialogButton({
                label: "Clone",
                icon: MsPortalFx.Base.Images.Clone(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to clone the selected pricing profile ?", 4),
            });
            cloneButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedProfile() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.pricingProfilesDataManager.clonePricingProfile(_this.adminSubscriptionId(), _this.location(), _this.selectedProfile().id());
                    }
                    return null;
                }
            };
            return cloneButton;
        };
        PricingProfilesCollectionBladeViewModel.prototype._createImportProfileButton = function () {
            var _this = this;
            var button = new FxToolbars.CommandButton({
                label: "Import",
                icon: MsPortalFx.Base.Images.Upload(),
                command: {
                    execute: function () {
                        return _this._container.openBlade(new BladeReferences.PricingProfileImportBladeReference({
                            adminSubscriptionId: _this.adminSubscriptionId(),
                            location: _this.location(),
                        }));
                    },
                    canExecute: ko.observable(true)
                }
            });
            return button;
        };
        PricingProfilesCollectionBladeViewModel.prototype._createDeleteProfileButton = function () {
            var _this = this;
            var deleteButton = new FxToolbars.DialogButton({
                label: ClientResources.Commands.delete,
                icon: MsPortalFx.Base.Images.Delete(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to delete the selected pricing profile ?", 4),
            });
            deleteButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedProfile() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.pricingProfilesDataManager.deletePricingProfile(_this.adminSubscriptionId(), _this.location(), _this.selectedProfile().id());
                    }
                    return null;
                }
            };
            return deleteButton;
        };
        return PricingProfilesCollectionBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.PricingProfilesCollectionBladeViewModel = PricingProfilesCollectionBladeViewModel;
});
