var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Shared/Helpers"], function (require, exports, Helpers) {
    "use strict";
    var FxForms = MsPortalFx.ViewModels.Forms;
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var Dialogs = MsPortalFx.ViewModels.Dialogs;
    var ArmHelpers = Common.Helpers;
    var QuotaCollectionBladeViewModel = (function (_super) {
        __extends(QuotaCollectionBladeViewModel, _super);
        function QuotaCollectionBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.adminSubscriptionId = ko.observable();
            this.location = ko.observable("local");
            this.selectedQuota = ko.pureComputed(function () {
                return _this.quotaGrid.selectableData.selectedItems().first();
            });
            this.title("Quotas");
            this._container = container;
            this._dataContext = dataContext;
            this._dataQueryView = dataContext.billingQuotaManager.listBillingQuotasQuery.createView(container, {
                interceptNotFound: false
            });
            this.formSection = new FxForms.Section.ViewModel(container, {
                style: ko.observable(3),
                children: ko.observableArray([])
            });
            var gridExtensions = FxGridExtensions.Filterable | FxGridExtensions.SortableColumn | FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                filterable: {
                    searchBoxCloseButtonVisible: ko.observable(false),
                    searchBoxPlaceholder: ko.observable("Search to filter items..."),
                    searchBoxVisible: ko.observable(true),
                    searchableColumns: ko.observableArray(["QuotaId", "Name"])
                },
                selectableRow: {
                    selectionMode: 1,
                    activateOnSelected: ko.observable(false)
                }
            };
            this.quotaGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "QuotaId",
                    name: ko.observable("Id"),
                    width: ko.observable("50px"),
                    activatable: ko.observable(false),
                },
                {
                    itemKey: "Name",
                    name: ko.observable("Quota Name"),
                    width: ko.observable("120px"),
                    activatable: ko.observable(true),
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: Helpers.getGridNameActivatableTemplate(),
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    }
                },
            ];
            this.quotaGrid.columns = ko.observableArray(basicColumns);
            this.quotaGrid.showHeader = true;
            this.quotaGrid.summary = ko.observable("Summary");
            this.quotaGrid.noRowsMessage("No items found");
            this._dataQueryView.items.subscribe(container, function (quotas) {
                _this.quotaGrid.items(quotas);
            });
            this._dataQueryView.loading.subscribe(container, function (isLoading) {
                _this.quotaGrid.loading(isLoading);
            });
            this._setupCommandBar();
        }
        QuotaCollectionBladeViewModel.prototype._setupCommandBar = function () {
            this._cloneQuotaButton = this._createCloneQuotaButton();
            this._deleteQuotaButton = this._createDeleteQuotaButton();
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([
                this._cloneQuotaButton,
                this._deleteQuotaButton,
            ]);
        };
        QuotaCollectionBladeViewModel.prototype._createCloneQuotaButton = function () {
            var _this = this;
            var cloneButton = new FxToolbars.DialogButton({
                label: "Clone",
                icon: MsPortalFx.Base.Images.Clone(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to clone the selected quota ?", 4),
            });
            cloneButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedQuota() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.billingQuotaManager.cloneBillingQuota(_this.adminSubscriptionId(), _this.location(), _this.selectedQuota().QuotaId())
                            .finally(function () {
                            _this._dataContext.billingQuotaManager.listBillingQuotasQuery.refreshAll();
                        });
                    }
                    return null;
                }
            };
            return cloneButton;
        };
        QuotaCollectionBladeViewModel.prototype._createDeleteQuotaButton = function () {
            var _this = this;
            var cloneButton = new FxToolbars.DialogButton({
                label: "Delete",
                icon: MsPortalFx.Base.Images.Delete(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to delete the selected quota ?", 4),
            });
            cloneButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedQuota() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.billingQuotaManager.deleteBillingQuota(_this.adminSubscriptionId(), _this.location(), _this.selectedQuota().QuotaId())
                            .finally(function () {
                            _this._dataContext.billingQuotaManager.listBillingQuotasQuery.refreshAll();
                        });
                    }
                    return null;
                }
            };
            return cloneButton;
        };
        QuotaCollectionBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.adminSubscriptionId(inputs.adminSubscriptionId);
            this.location(inputs.location);
            return this._dataQueryView.fetch({
                subscriptionId: this.adminSubscriptionId(),
                locationName: this.location(),
            });
        };
        return QuotaCollectionBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.QuotaCollectionBladeViewModel = QuotaCollectionBladeViewModel;
});
