var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports"], function (require, exports) {
    "use strict";
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var Dialogs = MsPortalFx.ViewModels.Dialogs;
    var Images = MsPortalFx.Base.Images;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var QuotaDetailsBladeViewModel = (function (_super) {
        __extends(QuotaDetailsBladeViewModel, _super);
        function QuotaDetailsBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this._selectedProfileId = ko.observable();
            this.isLink = ko.observable(true);
            this.subscriptionId = ko.observable("");
            this.selectedQuota = ko.observable("");
            this.selectedQuotaId = ko.observable("");
            this.location = ko.observable("");
            this.icon(Images.Customize());
            this._container = container;
            this._dataContext = dataContext;
            this._pricingProfileQueryView = dataContext.sharedContext.pricingProfilesDataManager.pricingProfilesQuery.createView(container, {
                interceptNotFound: false
            });
            this._enabledFeaturesEntityView = dataContext.sharedContext.licenseDataManager.enabledFeaturesEntity.createView(container, {
                interceptNotFound: false
            });
            this._quotaEntityView = dataContext.billingQuotaManager.billingQuotaEntity.createView(container);
            this._initializeFormFields(container);
            this.pricingProfilesDdownField.value.subscribe(container, function (selectedProfile) {
                if (selectedProfile != null) {
                    _this._selectedProfileId(selectedProfile);
                }
            });
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(container);
            this._setupCommandBar();
        }
        QuotaDetailsBladeViewModel.prototype._setupCommandBar = function () {
            this._saveButton = this._createSaveButton();
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([
                this._saveButton,
            ]);
        };
        QuotaDetailsBladeViewModel.prototype._createSaveButton = function () {
            var _this = this;
            var saveButton = new FxToolbars.DialogButton({
                label: "Save",
                icon: MsPortalFx.Base.Images.Save(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to save ?", 4),
            });
            saveButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this._selectedProfileId() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        var billingQuotaIn = {
                            QuotaId: _this.selectedQuotaId(),
                            Name: _this.quotaNameTxField.value(),
                            BillingQuotaSettings: {
                                PricingProfileId: _this._selectedProfileId(),
                                EnableEmailNotification: _this.isEmailNotificationEnabledOptionField.value(),
                                IsCspEnabledForTenant: _this.isCSPEnabledForTenantOptionField.value()
                            },
                        };
                        _this._dataContext.billingQuotaManager.updateBillingQuotaQuery(_this.subscriptionId(), _this.location(), billingQuotaIn)
                            .finally(function () {
                            _this._container.closeCurrentBlade();
                        });
                    }
                    return null;
                }
            };
            return saveButton;
        };
        QuotaDetailsBladeViewModel.prototype._initializeFormFields = function (container) {
            var quotaNameTxFieldOptions = {
                label: ko.observable("Quota Name"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.quotaNameTxField = new MsPortalFx.ViewModels.Forms.TextBox.ViewModel(container, quotaNameTxFieldOptions);
            var pricingProfilesDdownFieldOptions = {
                label: ko.observable('Pricing Profile'),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.pricingProfilesDdownField = new MsPortalFx.ViewModels.Obsolete.Forms.DropDown.ViewModel(container, pricingProfilesDdownFieldOptions);
            var isEmailNotificationEnabledOptions = {
                label: ko.observable("Enable Email Notifications ?"),
                options: ko.observableArray([
                    { text: ko.observable("Yes"), value: true },
                    { text: ko.observable("No"), value: false }
                ]),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required"),
                ]),
            };
            this.isEmailNotificationEnabledOptionField = new FxForms.OptionsGroup.ViewModel(container, isEmailNotificationEnabledOptions);
            var isCSPEnabledForTenantOptions = {
                label: ko.observable("Enable CSP for Tenants ?"),
                options: ko.observableArray([
                    { text: ko.observable("Yes"), value: true },
                    { text: ko.observable("No"), value: false }
                ]),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required"),
                ]),
            };
            this.isCSPEnabledForTenantOptionField = new FxForms.OptionsGroup.ViewModel(container, isCSPEnabledForTenantOptions);
            this.formSection = new FxForms.Section.ViewModel(container, {
                children: ko.observableArray([
                    this.quotaNameTxField,
                    this.pricingProfilesDdownField,
                    this.isEmailNotificationEnabledOptionField,
                    this.isCSPEnabledForTenantOptionField
                ])
            });
        };
        QuotaDetailsBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            var _this = this;
            var isFeatureEnabled;
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            this.selectedQuota(inputs.selectedQuota);
            this.selectedQuotaId(inputs.selectedQuotaId);
            var title = "Quota Details";
            this.title(title);
            this.description(title);
            this.quotaNameTxField.value(this.selectedQuota().toString());
            var args = {
                subscriptionId: this.subscriptionId(),
                quotaId: this.selectedQuotaId(),
                locationName: this.location(),
            };
            this._enabledFeaturesEntityView.fetch({
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            }).then(function () {
                var dataEntity = _this._enabledFeaturesEntityView.item();
                isFeatureEnabled = dataEntity.EnabledFeatures().filter(function (a) { return a.Name() == 'CSPIntegration'; });
            }).finally(function () {
                if (isFeatureEnabled.length == 0) {
                    _this.formSection.children.remove(_this.isCSPEnabledForTenantOptionField);
                }
            });
            ;
            return this._quotaEntityView.fetch(args).then(function () {
                var dataEntity = _this._quotaEntityView.item();
                _this.isEmailNotificationEnabledOptionField.value(dataEntity.EnableEmailNotification());
                _this.isCSPEnabledForTenantOptionField.value(dataEntity.IsCspEnabledForTenant());
                _this._pricingProfileQueryView.fetch({
                    subscriptionId: _this.subscriptionId(),
                    location: _this.location(),
                }).then(function () {
                    var profileSet = _this._pricingProfileQueryView.items();
                    _this._updatePricingProfilesDdown(profileSet, dataEntity.PricingProfileId().toString());
                });
            });
        };
        QuotaDetailsBladeViewModel.prototype._updatePricingProfilesDdown = function (pricingProfiles, profileId) {
            var dropdownValues = pricingProfiles.map(function (s) {
                return {
                    text: ko.observable(s.Id() + " - " + s.ProfileName()),
                    value: s.Id().toString(),
                };
            });
            dropdownValues.push({
                text: ko.observable("Please select a Pricing Profile"),
                value: null,
            });
            this.pricingProfilesDdownField.options(dropdownValues);
            this.pricingProfilesDdownField.value(profileId);
        };
        return QuotaDetailsBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.QuotaDetailsBladeViewModel = QuotaDetailsBladeViewModel;
});
