var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "ClientResources", "../Models/QuotaForm"], function (require, exports, ClientResources, QuotaForm) {
    "use strict";
    var FxDropDown = MsPortalFx.ViewModels.Obsolete.Forms.DropDown;
    "use strict";
    var QuotaFormPartViewModel = (function (_super) {
        __extends(QuotaFormPartViewModel, _super);
        function QuotaFormPartViewModel(container, initialState, dataContext) {
            _super.call(this, container);
            this._quotaForm = new QuotaForm.QuotaForm();
            this._unlimitedQuota = "-1";
            this._editable = ko.observable(true);
            this.connectionsDropDownValues = ko.observableArray();
            this._initializeParameterProvider(container);
            this._initializeFormFields(container);
        }
        QuotaFormPartViewModel.prototype._initializeFormFields = function (container) {
            var _this = this;
            var connectionsDropDownOptions = {
                label: ko.observable("Connection"),
                infoBalloonContent: ko.observable("Please select the Billing connection to be used by Subscriptions for this plan"),
                options: this.connectionsDropDownValues
            };
            this.connectionsDropDown = new FxDropDown.ViewModel(container, this, this.createEditScopeAccessor(function (data) {
                return _this._quotaForm.connectionIds;
            }), connectionsDropDownOptions);
            var vmTextBoxOptions = {
                label: ko.observable(ClientResources.Quota.maxNumberBillingOverviews),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.NumericValidation(ClientResources.Quota.validationMustBeANumber),
                    new MsPortalFx.ViewModels.MinValueValidation(0, ClientResources.Quota.validationGreaterThanZero)
                ])
            };
            this.txBillingOverviews = new MsPortalFx.ViewModels.Forms.TextBox.ViewModel(container, this, this.createEditScopeAccessor(function (data) {
                return _this._quotaForm.maxBillingOverview;
            }), vmTextBoxOptions);
            this.txBillingOverviews.valueUpdateTrigger = 3;
            this.cbBillingOverviewsUnlimited = new MsPortalFx.ViewModels.Forms.CheckBox.ViewModel(container, this, this.createEditScopeAccessor(function (data) {
                return _this._quotaForm.isUnlimitedBillingOverview;
            }), {
                label: ko.observable(ClientResources.Quota.unlimited)
            });
            var cpuCoresTextBoxOptions = {
                label: ko.observable("MAX CPU Cores"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.NumericValidation(ClientResources.Quota.validationMustBeANumber),
                    new MsPortalFx.ViewModels.MinValueValidation(0, ClientResources.Quota.validationGreaterThanZero)
                ])
            };
            this.txCpuCores = new MsPortalFx.ViewModels.Forms.TextBox.ViewModel(container, this, this.createEditScopeAccessor(function (data) {
                return _this._quotaForm.maxCpuCores;
            }), cpuCoresTextBoxOptions);
            this.txCpuCores.valueUpdateTrigger = 3;
            var ramMemoryTextBoxOptions = {
                label: ko.observable("MAX RAM (in GB)"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.NumericValidation(ClientResources.Quota.validationMustBeANumber),
                    new MsPortalFx.ViewModels.MinValueValidation(0, ClientResources.Quota.validationGreaterThanZero)
                ])
            };
            this.txRamMemory = new MsPortalFx.ViewModels.Forms.TextBox.ViewModel(container, this, this.createEditScopeAccessor(function (data) {
                return _this._quotaForm.maxRamMemoryGB;
            }), ramMemoryTextBoxOptions);
            this.txRamMemory.valueUpdateTrigger = 3;
            var sectionOptions = {
                children: ko.observableArray([
                    this.connectionsDropDown,
                    this.txBillingOverviews,
                    this.cbBillingOverviewsUnlimited,
                    this.txCpuCores,
                    this.txRamMemory
                ])
            };
            this.generalSection = new MsPortalFx.ViewModels.Forms.Section.ViewModel(container, sectionOptions);
            this.sections.push(this.generalSection);
            this.cbBillingOverviewsUnlimited.value.subscribe(container, function (unlimited) {
                if (_this._editable()) {
                    _this.txBillingOverviews.enabled(!unlimited);
                }
            });
        };
        QuotaFormPartViewModel.prototype._initializeParameterProvider = function (container) {
            var _this = this;
            this.parameterProvider = new MsPortalFx.ViewModels.ParameterProvider(container, {
                mapIncomingDataForEditScope: function (incoming) {
                    var configFromCollector = _this.parameterProvider.configFromCollector();
                    if (configFromCollector.editable === 'undefined') {
                        throw new Error("Need to supply editable as part of collector config");
                    }
                    _this._editable(configFromCollector.editable);
                    var formDataModel = new QuotaForm.QuotaForm();
                    if (!jQuery.isEmptyObject(incoming)) {
                        var rpQuota = incoming.BillingResourceProviderQuota;
                        if (rpQuota.connectionIds)
                            _this._quotaForm.connectionIds(rpQuota.connectionIds.join(";"));
                        else
                            _this._quotaForm.connectionIds("");
                        _this._quotaForm.maxBillingOverview(rpQuota.billingOverviewsCount);
                        _this._quotaForm.isUnlimitedBillingOverview(rpQuota.billingOverviewsCount === _this._unlimitedQuota);
                        _this._quotaForm.maxCpuCores(rpQuota.cpuCoresCount);
                        _this._quotaForm.maxRamMemoryGB(rpQuota.ramMemoryGB);
                    }
                    return _this._quotaForm;
                },
                mapOutgoingDataForCollector: function (outgoing) {
                    return _this._mapOutgoingDataForCollector();
                }
            });
            this.editScope = this.parameterProvider.editScope;
            this.actionBar = new MsPortalFx.ViewModels.ActionBars.GenericActionBar.ViewModel(container);
            this.actionBar.actionButtonLabel(ClientResources.ok);
            this.valid.subscribe(container, this.actionBar.valid);
        };
        QuotaFormPartViewModel.prototype._setFieldsToReadOnly = function () {
            this.txBillingOverviews.disabled(true);
            this.cbBillingOverviewsUnlimited.disabled(true);
        };
        QuotaFormPartViewModel.prototype._mapOutgoingDataForCollector = function () {
            var rpQuota = {
                connectionIds: this._quotaForm.connectionIds().split(";"),
                billingOverviewsCount: this._quotaForm.isUnlimitedBillingOverview() ? this._unlimitedQuota : this._quotaForm.maxBillingOverview(),
                cpuCoresCount: this._quotaForm.maxCpuCores(),
                ramMemoryGB: this._quotaForm.maxRamMemoryGB()
            };
            var quotas = {
                BillingResourceProviderQuota: rpQuota
            };
            return quotas;
        };
        return QuotaFormPartViewModel;
    }(MsPortalFx.ViewModels.Forms.Form.ViewModel));
    exports.QuotaFormPartViewModel = QuotaFormPartViewModel;
});
