var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "MsPortalFx/Globalization"], function (require, exports, Globalization) {
    "use strict";
    var Chart = MsPortalFx.ViewModels.Controls.Visualization.Chart;
    var CostComparisonTrendViewModel = (function (_super) {
        __extends(CostComparisonTrendViewModel, _super);
        function CostComparisonTrendViewModel(container, initialState, dataContext) {
            _super.call(this);
            this.location = ko.observable("local");
            this.isoCurrencySymbol = ko.observable();
            this._dailyCostList = ko.observableArray([]);
            this.previousMonthCostSeries = ko.observable();
            this.currentMonthCostSeries = ko.observable();
            container.partTitle("Daily Charges Trend (Includes Flat Fee + Tax)");
            this._container = container;
            this._dataContext = dataContext;
            this.trendChartCost = new Chart.ViewModel(container);
            var view = new Chart.LineChartView();
            this.trendChartCost.views([view]);
            this.trendChartCost.legendPosition(3);
            this.trendChartCost.xAxis.scale(1);
            this.trendChartCost.xAxis.unit(MsPortalFx.UnitConversion.Unit.Days);
            this.trendChartCost.xAxis.formatOptions(Globalization.NumberFormat);
            this.trendChartCost.xAxis.labelPadding(100);
            this.trendChartCost.yAxis.unit(MsPortalFx.UnitConversion.Unit.None);
            this.trendChartCost.yAxis.showGridLines(true);
            this.trendChartCost.yAxis.scale(1);
        }
        CostComparisonTrendViewModel.prototype._constructChartSeriesList = function () {
            var allChartSeries = [];
            if (this.previousMonthCostSeries()) {
                var chartSeries = new Chart.Series();
                chartSeries.name(this.previousMonthCostSeries().Month);
                var previousMonthValues = this.previousMonthCostSeries().DailyCostList.map(function (dailyCost) {
                    return new Chart.ChartItem(dailyCost.Day, dailyCost.DailyCost);
                });
                chartSeries.values(previousMonthValues);
                allChartSeries.push(chartSeries);
            }
            if (this.currentMonthCostSeries()) {
                var currentMonthValues = new Chart.Series();
                currentMonthValues.name(this.currentMonthCostSeries().Month);
                var memorySeriesValues = this.currentMonthCostSeries().DailyCostList.map(function (dailyCost) {
                    return new Chart.ChartItem(dailyCost.Day, dailyCost.DailyCost);
                });
                currentMonthValues.values(memorySeriesValues);
                allChartSeries.push(currentMonthValues);
            }
            return allChartSeries;
        };
        CostComparisonTrendViewModel.prototype.onInputsSet = function (inputs) {
            var _this = this;
            this._dataContext.selectedIsoCurrencySymbol.subscribe(this._container, this._onIsoCurrencySymbolChanged.bind(this));
            var q = this._dataContext.subscriptionsManager.adminSubscriptionsPromise.then(function (subscriptions) {
                if (subscriptions.length === 0)
                    return Q();
                var firstSubscriptionId = subscriptions.first().subscriptionId;
                var isoCurrency = _this._dataContext.selectedIsoCurrencySymbol();
                _this._dataContext.sharedContext.pricingProfilesDataManager.getAvailableIsoCurrencyList(firstSubscriptionId, _this.location()).then(function (isoCurrencySymbols) {
                    if (!isoCurrency) {
                        isoCurrency = isoCurrencySymbols.first();
                    }
                    return _this._onIsoCurrencySymbolChanged(isoCurrency);
                });
            });
            return q;
        };
        CostComparisonTrendViewModel.prototype._onIsoCurrencySymbolChanged = function (selectedIsoCurrencySymbol) {
            var _this = this;
            this.isoCurrencySymbol(selectedIsoCurrencySymbol);
            this._dataContext.selectedIsoCurrencySymbol(selectedIsoCurrencySymbol);
            if (!selectedIsoCurrencySymbol)
                return Q();
            var q = this._dataContext.subscriptionsManager.adminSubscriptionsPromise.then(function (subscriptions) {
                var firstSubscriptionId = subscriptions.first().subscriptionId;
                return _this._dataContext.sharedContext.billingOverviewManager.getDailyCostList(firstSubscriptionId, _this.location(), _this.isoCurrencySymbol())
                    .then(function (dailyCostList) {
                    if (dailyCostList.length === 0) {
                        _this._container.noDataMessage("Data points are not available");
                        return;
                    }
                    if (dailyCostList.length === 2)
                        _this.previousMonthCostSeries(dailyCostList[1]);
                    _this.currentMonthCostSeries(dailyCostList[0]);
                    var allSeries = _this._constructChartSeriesList();
                    _this.trendChartCost.series(allSeries);
                });
            });
            return q;
        };
        return CostComparisonTrendViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.CostComparisonTrendViewModel = CostComparisonTrendViewModel;
});
