define(["require", "exports"], function (require, exports) {
    "use strict";
    var CostPerResourceChartPartViewModel = (function () {
        function CostPerResourceChartPartViewModel(container, initialState, dataContext) {
            this._resourceWiseCostList = ko.observableArray([]);
            this.isoCurrencySymbol = ko.observable();
            this._container = container;
            this._dataContext = dataContext;
            container.partTitle("Resource Wise Usage Charges");
            this.barChartResource = new MsPortalFx.ViewModels.Controls.Visualization.Chart.ViewModel(container);
            var view = new MsPortalFx.ViewModels.Controls.Visualization.Chart.BarChartView(1);
            this.barChartResource.views([view]);
            this.barChartResource.yAxis.showGridLines(true);
            this.barChartResource.legendPosition(0);
            var resourceWiseCostSeries = new MsPortalFx.ViewModels.Controls.Visualization.Chart.Series();
            resourceWiseCostSeries.name("Amount");
            this._resourceWiseCostList.mapInto(container, function (itemLifetime, usageRecord) {
                return {
                    xValue: usageRecord.MeteredResourceDisplayName,
                    yValue: usageRecord.BillableCost
                };
            }, resourceWiseCostSeries.values);
            this.barChartResource.series([resourceWiseCostSeries]);
        }
        CostPerResourceChartPartViewModel.prototype.onInputsSet = function (inputs) {
            var _this = this;
            this._dataContext.selectedIsoCurrencySymbol.subscribe(this._container, this._onIsoCurrencySymbolChanged.bind(this));
            var q = this._dataContext.subscriptionsManager.adminSubscriptionsPromise.then(function (subscriptions) {
                if (subscriptions.length === 0)
                    return Q();
                var firstSubscriptionId = subscriptions.first().subscriptionId;
                var isoCurrency = _this._dataContext.selectedIsoCurrencySymbol();
                _this._dataContext.sharedContext.pricingProfilesDataManager.getAvailableIsoCurrencyList(firstSubscriptionId, "local").then(function (isoCurrencySymbols) {
                    if (!isoCurrency) {
                        isoCurrency = isoCurrencySymbols.first();
                    }
                    return _this._onIsoCurrencySymbolChanged(isoCurrency);
                });
            });
            return q;
        };
        CostPerResourceChartPartViewModel.prototype._onIsoCurrencySymbolChanged = function (selectedIsoCurrencySymbol) {
            var _this = this;
            this.isoCurrencySymbol(selectedIsoCurrencySymbol);
            this._dataContext.selectedIsoCurrencySymbol(selectedIsoCurrencySymbol);
            if (!selectedIsoCurrencySymbol)
                return Q();
            var q = this._dataContext.subscriptionsManager.adminSubscriptionsPromise.then(function (subscriptions) {
                var firstSubscriptionId = subscriptions.first().subscriptionId;
                return _this._dataContext.sharedContext.billingOverviewManager.getTotalCostPerServiceType(firstSubscriptionId, "local", _this.isoCurrencySymbol())
                    .then(function (usageRecords) {
                    _this._resourceWiseCostList(usageRecords);
                });
            });
            return q;
        };
        return CostPerResourceChartPartViewModel;
    }());
    exports.CostPerResourceChartPartViewModel = CostPerResourceChartPartViewModel;
});
