define(["require", "exports"], function (require, exports) {
    "use strict";
    var SimpleChart = MsPortalFx.ViewModels.Controls.Visualization.SimpleChart;
    var Chart = MsPortalFx.ViewModels.Controls.Visualization.Chart;
    var ResourceCountPerSubscriptionChartPartViewModel = (function () {
        function ResourceCountPerSubscriptionChartPartViewModel(container, initialState, dataContext) {
            this.isoCurrencySymbol = ko.observable();
            this._container = container;
            this._dataContext = dataContext;
            container.partTitle("Resource Count for Subscriptions");
            this.barChartResource = new SimpleChart.ViewModel(container);
            this.barChartResource = new SimpleChart.ViewModel(this._container, {
                chartType: ko.observable(4),
                xAxis: {
                    scale: 0,
                    labelPadding: 100,
                },
                legendPosition: 2
            });
        }
        ResourceCountPerSubscriptionChartPartViewModel.prototype.onInputsSet = function (inputs) {
            var _this = this;
            this._dataContext.selectedIsoCurrencySymbol.subscribe(this._container, this._onIsoCurrencySymbolChanged.bind(this));
            var q = this._dataContext.subscriptionsManager.adminSubscriptionsPromise.then(function (subscriptions) {
                if (subscriptions.length === 0)
                    return Q();
                var firstSubscriptionId = subscriptions.first().subscriptionId;
                var isoCurrency = _this._dataContext.selectedIsoCurrencySymbol();
                _this._dataContext.sharedContext.pricingProfilesDataManager.getAvailableIsoCurrencyList(firstSubscriptionId, "local").then(function (isoCurrencySymbols) {
                    if (!isoCurrency) {
                        isoCurrency = isoCurrencySymbols.first();
                    }
                    return _this._onIsoCurrencySymbolChanged(isoCurrency);
                });
            });
            return q;
        };
        ResourceCountPerSubscriptionChartPartViewModel.prototype._onIsoCurrencySymbolChanged = function (selectedIsoCurrencySymbol) {
            var _this = this;
            this.isoCurrencySymbol(selectedIsoCurrencySymbol);
            this._dataContext.selectedIsoCurrencySymbol(selectedIsoCurrencySymbol);
            if (!selectedIsoCurrencySymbol)
                return Q();
            var q = this._dataContext.subscriptionsManager.adminSubscriptionsPromise.then(function (subscriptions) {
                var firstSubscriptionId = subscriptions.first().subscriptionId;
                return _this._dataContext.sharedContext.billingOverviewManager.getResourceCountForSubscriptions(firstSubscriptionId, "local", _this.isoCurrencySymbol())
                    .then(function (usageRecords) {
                    _this._renderChart(usageRecords);
                });
            });
            return q;
        };
        ResourceCountPerSubscriptionChartPartViewModel.prototype._renderChart = function (usageRecords) {
            var meterNamesList = usageRecords.map(function (m) { return m.MeteredResourceDisplayName; });
            var uniqueMeterNames = meterNamesList.filter(function (x, i, a) { return x && a.indexOf(x) === i; });
            var chartSeries = [];
            for (var i = 0; i < uniqueMeterNames.length; ++i) {
                chartSeries[i] = new SimpleChart.Series({
                    name: uniqueMeterNames[i]
                });
            }
            ;
            usageRecords.forEach(function (record) {
                var index = uniqueMeterNames.indexOf(record.MeteredResourceDisplayName);
                var xAxisValue = record.AdminId.toString() + ' ' + '(' + record.SubscriptionId.toString() + ')';
                var value = { xValue: xAxisValue, yValue: record.ResourceCount };
                chartSeries[index].values.push(value);
            });
            this.barChartResource.series(chartSeries);
        };
        return ResourceCountPerSubscriptionChartPartViewModel;
    }());
    exports.ResourceCountPerSubscriptionChartPartViewModel = ResourceCountPerSubscriptionChartPartViewModel;
});
