define(["require", "exports"], function (require, exports) {
    "use strict";
    var TopUsersByCostChartPartViewModel = (function () {
        function TopUsersByCostChartPartViewModel(container, initialState, dataContext) {
            this.location = ko.observable("local");
            this.isoCurrencySymbol = ko.observable();
            this._userCostList = ko.observableArray([]);
            container.partTitle("Users With Highest Usage Charges");
            this._container = container;
            this._dataContext = dataContext;
            this.barChartUser = new MsPortalFx.ViewModels.Controls.Visualization.Chart.ViewModel(container);
            var view = new MsPortalFx.ViewModels.Controls.Visualization.Chart.BarChartView(1);
            this.barChartUser.views([view]);
            this.barChartUser.yAxis.showGridLines(true);
            this.barChartUser.legendPosition(0);
            var userCostSeries = new MsPortalFx.ViewModels.Controls.Visualization.Chart.Series();
            userCostSeries.name("Amount");
            this._userCostList.mapInto(container, function (itemLifetime, userCost) {
                return {
                    xValue: userCost.UserId,
                    yValue: userCost.UsageCost
                };
            }, userCostSeries.values);
            this.barChartUser.series([userCostSeries]);
        }
        TopUsersByCostChartPartViewModel.prototype.onInputsSet = function (inputs) {
            var _this = this;
            this._dataContext.selectedIsoCurrencySymbol.subscribe(this._container, this._onIsoCurrencySymbolChanged.bind(this));
            var q = this._dataContext.subscriptionsManager.adminSubscriptionsPromise.then(function (subscriptions) {
                if (subscriptions.length === 0)
                    return Q();
                var firstSubscriptionId = subscriptions.first().subscriptionId;
                var isoCurrency = _this._dataContext.selectedIsoCurrencySymbol();
                _this._dataContext.sharedContext.pricingProfilesDataManager.getAvailableIsoCurrencyList(firstSubscriptionId, _this.location()).then(function (isoCurrencySymbols) {
                    if (!isoCurrency) {
                        isoCurrency = isoCurrencySymbols.first();
                    }
                    return _this._onIsoCurrencySymbolChanged(isoCurrency);
                });
            });
            return q;
        };
        TopUsersByCostChartPartViewModel.prototype._onIsoCurrencySymbolChanged = function (selectedIsoCurrencySymbol) {
            var _this = this;
            this.isoCurrencySymbol(selectedIsoCurrencySymbol);
            this._dataContext.selectedIsoCurrencySymbol(selectedIsoCurrencySymbol);
            if (!selectedIsoCurrencySymbol)
                return Q();
            var q = this._dataContext.subscriptionsManager.adminSubscriptionsPromise.then(function (subscriptions) {
                var firstSubscriptionId = subscriptions.first().subscriptionId;
                return _this._dataContext.sharedContext.billingOverviewManager.getTopUsersByCost(firstSubscriptionId, _this.location(), _this.isoCurrencySymbol())
                    .then(function (userCostList) {
                    _this._userCostList(userCostList);
                });
            });
            return q;
        };
        return TopUsersByCostChartPartViewModel;
    }());
    exports.TopUsersByCostChartPartViewModel = TopUsersByCostChartPartViewModel;
});
