var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Models/SettingsModel"], function (require, exports, SettingsModel) {
    "use strict";
    var Images = MsPortalFx.Base.Images;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var CspSettingsViewModel = (function (_super) {
        __extends(CspSettingsViewModel, _super);
        function CspSettingsViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable("");
            this.location = ko.observable("");
            this._actionBarButtonLabel = ko.observable("");
            this.title("CSP Settings");
            this.description("CSP Details");
            this.icon(Images.Customize());
            this._container = container;
            this._dataContext = dataContext;
            this._settingEntityView = dataContext.settingsGroupManager.settingsGroupQuery.createView(container);
            this._initializeEditScope();
            this._initializeActionBar(container);
            this._initializeFormFields(container);
            this.actionBar.saveButtonClick = function () {
                return _this._editScopeView.editScope().saveChanges().then(function () {
                    _this._container.closeCurrentBlade();
                });
            };
            this.actionBar.discardButtonClick = function () {
                if (_this._form.editScope()) {
                    _this._form.editScope().revertAll();
                }
            };
        }
        CspSettingsViewModel.prototype._initializeEditScope = function () {
            var _this = this;
            var editScopeCache = MsPortalFx.Data.EditScopeCache.createNew({
                supplyExistingData: function (key, lifetime) {
                    var args = {
                        subscriptionId: _this.subscriptionId(),
                    };
                    return _this._settingEntityView.fetch(args).then(function () {
                        var dataEntity = _this._settingEntityView.item();
                        var data = SettingsModel.CspSettingsModel.getCspSettingsData(dataEntity.CspSettings());
                        return data;
                    });
                },
                saveEditScopeChanges: function (commandId, editScope, edits, lifetime, dataToUpdate) {
                    var command = editScope.root;
                    var dataManager = _this._dataContext.settingsGroupManager;
                    var op = dataManager.updateCspSettingsQuery(_this.subscriptionId(), _this.location(), command);
                    _this._container.operations.add(op, { blockUi: true });
                    return op.then(function () {
                        return {
                            action: MsPortalFx.Data.AcceptEditScopeChangesAction.AcceptClientChanges
                        };
                    }).finally(function () {
                    });
                }
            });
            this._editScopeView = editScopeCache.createView(this._container);
            this._form = new FxForms.Form.ViewModel(this._container);
            this._form.editScope = this._editScopeView.editScope;
        };
        CspSettingsViewModel.prototype._initializeActionBar = function (container) {
            var _this = this;
            this.actionBar = new MsPortalFx.ViewModels.ActionBars.FormActionBar.ViewModel(container);
            ko.reactor(container, function () {
                var es1 = _this._form.editScope;
                var isClean1 = ko.observable(!(es1() && es1().dirty()));
                var mustDisable1 = ko.observable(!es1() || es1().saving());
                _this.actionBar.disabled((mustDisable1()) || (isClean1()));
            });
        };
        CspSettingsViewModel.prototype._initializeFormFields = function (container) {
            var partnerServiceApiEndpointTxFieldOptions = {
                label: ko.observable("Partner Service Api Endpoint"),
                infoBalloonContent: ko.observable("Like: https://api.partnercenter.microsoft.com"),
                validations: ko.observableArray([]),
            };
            this.partnerServiceApiEndpointTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.PartnerServiceApiEndpoint; }), partnerServiceApiEndpointTxFieldOptions);
            var authenticationTypeDdownFieldOptions = {
                label: ko.observable('Authentication Type'),
                options: ko.observableArray([
                    { text: ko.observable("User"), value: "USER" },
                ]),
            };
            this.authenticationTypeDdownField = new MsPortalFx.ViewModels.Obsolete.Forms.DropDown.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.AuthenticationType; }), authenticationTypeDdownFieldOptions);
            var authenticationAuthorityEndpointTxFieldOptions = {
                label: ko.observable("Authentication Authority Endpoint"),
                infoBalloonContent: ko.observable("Like: https://login.windows.net"),
                validations: ko.observableArray([]),
            };
            this.authenticationAuthorityEndpointTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.AuthenticationAuthorityEndpoint; }), authenticationAuthorityEndpointTxFieldOptions);
            var authenticationApplicationIdTxFieldOptions = {
                label: ko.observable("Authentication Application Id"),
                validations: ko.observableArray([]),
            };
            this.authenticationApplicationIdTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.AuthenticationApplicationId; }), authenticationApplicationIdTxFieldOptions);
            var domainTxFieldOptions = {
                label: ko.observable("Domain"),
                validations: ko.observableArray([]),
            };
            this.domainTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.Domain; }), domainTxFieldOptions);
            var userNameTxFieldOptions = {
                label: ko.observable("UserName"),
                validations: ko.observableArray([]),
            };
            this.userNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.UserName; }), userNameTxFieldOptions);
            var passwordTxFieldOptions = {
                label: ko.observable("Password"),
                validations: ko.observableArray([]),
            };
            this.passwordTxField = new FxForms.PasswordBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.Password; }), passwordTxFieldOptions);
            var resourceUrlTxFieldOptions = {
                label: ko.observable("Resource Url"),
                infoBalloonContent: ko.observable("Like: https://api.partnercenter.microsoft.com"),
                validations: ko.observableArray([]),
            };
            this.resourceUrlTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.ResourceUrl; }), resourceUrlTxFieldOptions);
            var redirectUrlTxFieldOptions = {
                label: ko.observable("Redirect Url"),
                infoBalloonContent: ko.observable("Like: http://localhost"),
                validations: ko.observableArray([]),
            };
            this.redirectUrlTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.RedirectUrl; }), redirectUrlTxFieldOptions);
            var marketTxFieldOptions = {
                label: ko.observable("Market"),
                infoBalloonContent: ko.observable("Provide the same Market used to create CSP account (Like: US)"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RegExMatchValidation(/^[A-Z]{2}$/.source, "Only two characters allowed. Like US")
                ]),
            };
            this.marketTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.Market; }), marketTxFieldOptions);
            var languageTxFieldOptions = {
                label: ko.observable("Language"),
                infoBalloonContent: ko.observable("Like: En"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RegExMatchValidation(/^[A-Z]{1}[a-z]{1}$/.source, "Only two characters allowed. Like En")
                ]),
            };
            this.languageTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.Language; }), languageTxFieldOptions);
            var cultureTxFieldOptions = {
                label: ko.observable("Culture"),
                infoBalloonContent: ko.observable("Like: en-US"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RegExMatchValidation(/^[a-z]{2}[-]{1}[A-Z]{2}$/.source, "Only five character allowed. Like en-US")
                ]),
            };
            this.cultureTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.Culture; }), cultureTxFieldOptions);
            this.formSection = new FxForms.Section.ViewModel(container, {
                children: ko.observableArray([
                    this.partnerServiceApiEndpointTxField,
                    this.authenticationTypeDdownField,
                    this.authenticationAuthorityEndpointTxField,
                    this.authenticationApplicationIdTxField,
                    this.domainTxField,
                    this.userNameTxField,
                    this.passwordTxField,
                    this.resourceUrlTxField,
                    this.redirectUrlTxField,
                    this.marketTxField,
                    this.languageTxField,
                    this.cultureTxField,
                ])
            });
        };
        CspSettingsViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            var args = {
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            };
            return this._editScopeView.fetchForExistingData(inputs.editScopeId, null);
        };
        return CspSettingsViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.CspSettingsViewModel = CspSettingsViewModel;
});
