var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Models/SettingsModel"], function (require, exports, SettingsModel) {
    "use strict";
    var Images = MsPortalFx.Base.Images;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var DomainUserSettingsViewModel = (function (_super) {
        __extends(DomainUserSettingsViewModel, _super);
        function DomainUserSettingsViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable("");
            this.location = ko.observable("");
            this.title("Domain User Settings");
            this.description("Domain User Details");
            this.icon(Images.Customize());
            this._container = container;
            this._dataContext = dataContext;
            this._settingEntityView = dataContext.settingsGroupManager.settingsGroupQuery.createView(container);
            this._initializeEditScope();
            this._initializeActionBar(container);
            this._initializeFormFields(container);
            this.actionBar.saveButtonClick = function () {
                return _this._editScopeView.editScope().saveChanges().then(function () {
                    _this._container.closeCurrentBlade();
                });
            };
            this.actionBar.discardButtonClick = function () {
                if (_this._form.editScope()) {
                    _this._form.editScope().revertAll();
                }
            };
        }
        DomainUserSettingsViewModel.prototype._initializeEditScope = function () {
            var _this = this;
            var editScopeCache = MsPortalFx.Data.EditScopeCache.createNew({
                supplyExistingData: function (key, lifetime) {
                    var args = {
                        subscriptionId: _this.subscriptionId(),
                    };
                    return _this._settingEntityView.fetch(args).then(function () {
                        var dataEntity = _this._settingEntityView.item();
                        var data = SettingsModel.DomainUserSettingsModel.getDomainUserSettingsData(dataEntity.DomainUserSettings());
                        return data;
                    });
                },
                saveEditScopeChanges: function (commandId, editScope, edits, lifetime, dataToUpdate) {
                    var command = editScope.root;
                    var dataManager = _this._dataContext.settingsGroupManager;
                    var op = dataManager.updateDomainUserSettingsQuery(_this.subscriptionId(), _this.location(), command);
                    _this._container.operations.add(op, { blockUi: true });
                    return op.then(function () {
                        return {
                            action: MsPortalFx.Data.AcceptEditScopeChangesAction.AcceptClientChanges
                        };
                    }).finally(function () {
                    });
                }
            });
            this._editScopeView = editScopeCache.createView(this._container);
            this._form = new FxForms.Form.ViewModel(this._container);
            this._form.editScope = this._editScopeView.editScope;
        };
        DomainUserSettingsViewModel.prototype._initializeActionBar = function (container) {
            var _this = this;
            this.actionBar = new MsPortalFx.ViewModels.ActionBars.FormActionBar.ViewModel(container);
            ko.reactor(container, function () {
                var es1 = _this._form.editScope;
                var isClean1 = ko.observable(!(es1() && es1().dirty()));
                var mustDisable1 = ko.observable(!es1() || es1().saving());
                _this.actionBar.disabled((mustDisable1()) || (isClean1()));
            });
        };
        DomainUserSettingsViewModel.prototype._initializeFormFields = function (container) {
            var DomainNameTxFieldOptions = {
                label: ko.observable("Domain Name"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.DomainNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.DomainName; }), DomainNameTxFieldOptions);
            var DomainUserNameTxFieldOptions = {
                label: ko.observable("Domain User Name"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.DomainUserNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.DomainUserName; }), DomainUserNameTxFieldOptions);
            var DomainUserPasswordTxFieldOptions = {
                label: ko.observable("Password"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.DomainUserPasswordTxField = new FxForms.PasswordBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.DomainUserPassword; }), DomainUserPasswordTxFieldOptions);
            this.formSection = new FxForms.Section.ViewModel(container, {
                children: ko.observableArray([
                    this.DomainNameTxField,
                    this.DomainUserNameTxField,
                    this.DomainUserPasswordTxField,
                ])
            });
        };
        DomainUserSettingsViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            var args = {
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            };
            return this._editScopeView.fetchForExistingData(inputs.editScopeId, null);
        };
        return DomainUserSettingsViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.DomainUserSettingsViewModel = DomainUserSettingsViewModel;
});
