var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Models/SettingsModel"], function (require, exports, SettingsModel) {
    "use strict";
    var Images = MsPortalFx.Base.Images;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var EmailNotificationSettingsViewModel = (function (_super) {
        __extends(EmailNotificationSettingsViewModel, _super);
        function EmailNotificationSettingsViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable("");
            this.location = ko.observable("");
            this._actionBarButtonLabel = ko.observable("");
            this.title("Email Settings");
            this.description("Email Details");
            this.icon(Images.Customize());
            this._container = container;
            this._dataContext = dataContext;
            this._settingEntityView = dataContext.settingsGroupManager.settingsGroupQuery.createView(container);
            this._initializeEditScope();
            this._initializeActionBar(container);
            this._initializeFormFields(container);
            this.actionBar.saveButtonClick = function () {
                return _this._editScopeView.editScope().saveChanges().then(function () {
                    _this._container.closeCurrentBlade();
                });
            };
            this.actionBar.discardButtonClick = function () {
                if (_this._form.editScope()) {
                    _this._form.editScope().revertAll();
                }
            };
        }
        EmailNotificationSettingsViewModel.prototype._initializeEditScope = function () {
            var _this = this;
            var editScopeCache = MsPortalFx.Data.EditScopeCache.createNew({
                supplyExistingData: function (key, lifetime) {
                    var args = {
                        subscriptionId: _this.subscriptionId(),
                    };
                    return _this._settingEntityView.fetch(args).then(function () {
                        var dataEntity = _this._settingEntityView.item();
                        var data = SettingsModel.EmailNotificationSettingsModel.getEmailSettingsData(dataEntity.EmailNotificationSettings());
                        return data;
                    });
                },
                saveEditScopeChanges: function (commandId, editScope, edits, lifetime, dataToUpdate) {
                    var command = editScope.root;
                    var dataManager = _this._dataContext.settingsGroupManager;
                    var op = dataManager.updateEmailNotificationSettingsQuery(_this.subscriptionId(), _this.location(), command);
                    _this._container.operations.add(op, { blockUi: true });
                    return op.then(function () {
                        return {
                            action: MsPortalFx.Data.AcceptEditScopeChangesAction.AcceptClientChanges
                        };
                    }).finally(function () {
                    });
                }
            });
            this._editScopeView = editScopeCache.createView(this._container);
            this._form = new FxForms.Form.ViewModel(this._container);
            this._form.editScope = this._editScopeView.editScope;
        };
        EmailNotificationSettingsViewModel.prototype._initializeActionBar = function (container) {
            var _this = this;
            this.actionBar = new MsPortalFx.ViewModels.ActionBars.FormActionBar.ViewModel(container);
            ko.reactor(container, function () {
                var es1 = _this._form.editScope;
                var isClean1 = ko.observable(!(es1() && es1().dirty()));
                var mustDisable1 = ko.observable(!es1() || es1().saving());
                _this.actionBar.disabled((mustDisable1()) || (isClean1()));
            });
        };
        EmailNotificationSettingsViewModel.prototype._initializeFormFields = function (container) {
            var SMTPHostTxFieldOptions = {
                label: ko.observable("SMTP Host"),
                infoBalloonContent: ko.observable("Like: smtp.cloudassert.com"),
                validations: ko.observableArray([]),
            };
            this.SMTPHostTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.SMTPHost; }), SMTPHostTxFieldOptions);
            var SMTPPortTxFieldOptions = {
                label: ko.observable("SMTP Port"),
                infoBalloonContent: ko.observable("Like: 587"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RegExMatchValidation(/^[0-9]{3,5}$/.source, "Only numbers allowed. Like 587")
                ]),
            };
            this.SMTPPortTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.SMTPPort; }), SMTPPortTxFieldOptions);
            var SMTPIsAuthenticateOgroupFieldOptions = {
                label: ko.observable("Should Authenticate With SMTP Server?"),
                options: ko.observableArray([
                    { text: ko.observable("Yes"), value: "True" },
                    { text: ko.observable("No"), value: "False" },
                ]),
                defaultValue: ko.observable("No"),
                validations: ko.observableArray([]),
            };
            this.SMTPIsAuthenticateOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.SMTPIsAuthenticate; }), SMTPIsAuthenticateOgroupFieldOptions);
            var SMTPUserTxFieldOptions = {
                label: ko.observable("SMTP User"),
                infoBalloonContent: ko.observable("Like: alert@cloudassert.com"),
                validations: ko.observableArray([]),
            };
            this.SMTPUserTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.SMTPUser; }), SMTPUserTxFieldOptions);
            var SMTPPasswordTxFieldOptions = {
                label: ko.observable("SMTP Password"),
                validations: ko.observableArray([]),
            };
            this.SMTPPasswordTxField = new FxForms.PasswordBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.SMTPPassword; }), SMTPPasswordTxFieldOptions);
            var AdminEmailIdsTxFieldOptions = {
                label: ko.observable("Admin Email Ids"),
                infoBalloonContent: ko.observable("Like: admin1@cloudassert.com, admin2@cloudassert.com"),
                validations: ko.observableArray([]),
            };
            this.AdminEmailIdsTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.AdminEmailIds; }), AdminEmailIdsTxFieldOptions);
            var SMTPIsSSLTOgroupFieldOptions = {
                label: ko.observable("Use SSL To Talk To SMTP Server?"),
                options: ko.observableArray([
                    { text: ko.observable("Yes"), value: "True" },
                    { text: ko.observable("No"), value: "False" },
                ]),
                defaultValue: ko.observable("No"),
                validations: ko.observableArray([]),
            };
            this.SMTPIsSSLTOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.SMTPIsSSL; }), SMTPIsSSLTOgroupFieldOptions);
            this.formSection = new FxForms.Section.ViewModel(container, {
                children: ko.observableArray([
                    this.SMTPHostTxField,
                    this.SMTPPortTxField,
                    this.SMTPIsAuthenticateOgroupField,
                    this.SMTPUserTxField,
                    this.SMTPPasswordTxField,
                    this.AdminEmailIdsTxField,
                    this.SMTPIsSSLTOgroupField,
                ])
            });
        };
        EmailNotificationSettingsViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            var args = {
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            };
            return this._editScopeView.fetchForExistingData(inputs.editScopeId, null);
        };
        return EmailNotificationSettingsViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.EmailNotificationSettingsViewModel = EmailNotificationSettingsViewModel;
});
