var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Models/SettingsModel"], function (require, exports, SettingsModel) {
    "use strict";
    var Images = MsPortalFx.Base.Images;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var InvoicePdfSettingsViewModel = (function (_super) {
        __extends(InvoicePdfSettingsViewModel, _super);
        function InvoicePdfSettingsViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable("");
            this.location = ko.observable("");
            this._actionBarButtonLabel = ko.observable("");
            this.title("Invoice Settings");
            this.description("Invoice Details");
            this.icon(Images.Customize());
            this._container = container;
            this._dataContext = dataContext;
            this._settingEntityView = dataContext.settingsGroupManager.settingsGroupQuery.createView(container);
            this._initializeEditScope();
            this._initializeActionBar(container);
            this._initializeFormFields(container);
            this.actionBar.saveButtonClick = function () {
                return _this._editScopeView.editScope().saveChanges().then(function () {
                    _this._container.closeCurrentBlade();
                });
            };
            this.actionBar.discardButtonClick = function () {
                if (_this._form.editScope()) {
                    _this._form.editScope().revertAll();
                }
            };
        }
        InvoicePdfSettingsViewModel.prototype._initializeEditScope = function () {
            var _this = this;
            var editScopeCache = MsPortalFx.Data.EditScopeCache.createNew({
                supplyExistingData: function (key, lifetime) {
                    var args = {
                        subscriptionId: _this.subscriptionId(),
                    };
                    return _this._settingEntityView.fetch(args).then(function () {
                        var dataEntity = _this._settingEntityView.item();
                        var data = SettingsModel.InvoicePdfSettingsModel.getInvoicePdfSettingsData(dataEntity.InvoicePdfSettings());
                        _this.updateDateTimeFormatDdownField(data.DateTimeFormatCsv);
                        return data;
                    });
                },
                saveEditScopeChanges: function (commandId, editScope, edits, lifetime, dataToUpdate) {
                    var command = editScope.root;
                    var dataManager = _this._dataContext.settingsGroupManager;
                    var op = dataManager.updateInvoicePdfSettingsQuery(_this.subscriptionId(), _this.location(), command);
                    _this._container.operations.add(op, { blockUi: true });
                    return op.then(function () {
                        return {
                            action: MsPortalFx.Data.AcceptEditScopeChangesAction.AcceptClientChanges
                        };
                    }).finally(function () {
                    });
                }
            });
            this._editScopeView = editScopeCache.createView(this._container);
            this._form = new FxForms.Form.ViewModel(this._container);
            this._form.editScope = this._editScopeView.editScope;
        };
        InvoicePdfSettingsViewModel.prototype.updateDateTimeFormatDdownField = function (dateTimeFormatCsv) {
            var dateFormatList = dateTimeFormatCsv().toString().split(",");
            var dropdownValues = dateFormatList.map(function (i) {
                return {
                    text: ko.observable(i),
                    value: i.toString(),
                };
            });
            dropdownValues.push({
                text: ko.observable("Please select a Date format"),
                value: null,
            });
            this.dateTimeFormatDdownField.options(dropdownValues);
        };
        InvoicePdfSettingsViewModel.prototype._initializeActionBar = function (container) {
            var _this = this;
            this.actionBar = new MsPortalFx.ViewModels.ActionBars.FormActionBar.ViewModel(container);
            ko.reactor(container, function () {
                var es1 = _this._form.editScope;
                var isClean1 = ko.observable(!(es1() && es1().dirty()));
                var mustDisable1 = ko.observable(!es1() || es1().saving());
                _this.actionBar.disabled((mustDisable1()) || (isClean1()));
            });
        };
        InvoicePdfSettingsViewModel.prototype._initializeFormFields = function (container) {
            var headerContentTxFieldOptions = {
                label: ko.observable("Header Content"),
                validations: ko.observableArray([]),
            };
            this.headerContentTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.HeaderContent; }), headerContentTxFieldOptions);
            var footerContentTxFieldOptions = {
                label: ko.observable("Footer Content"),
                validations: ko.observableArray([]),
            };
            var dateTimeFormatDdownFieldOptions = {
                label: ko.observable("Date Format"),
                validations: ko.observableArray([
                    new MsPortalFx.ViewModels.RequiredValidation("Required")
                ]),
            };
            this.dateTimeFormatDdownField = new MsPortalFx.ViewModels.Obsolete.Forms.DropDown.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.DefaultDateFormatInCsv; }), dateTimeFormatDdownFieldOptions);
            this.footerContentTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.FooterContent; }), footerContentTxFieldOptions);
            var invoiceDueDateTxFieldOptions = {
                label: ko.observable("Invoice Due Date"),
                validations: ko.observableArray([]),
            };
            this.invoiceDueDateTxField = new FxForms.NumericTextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.InvoiceDueDate; }), invoiceDueDateTxFieldOptions);
            var notificationEmailDateTxFieldOptions = {
                label: ko.observable("Notification Email Date"),
                validations: ko.observableArray([]),
            };
            this.notificationEmailDateTxField = new FxForms.NumericTextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.NotificationEmailDate; }), notificationEmailDateTxFieldOptions);
            var companyLogoPathTxFieldOptions = {
                label: ko.observable("Company Logo Path"),
                validations: ko.observableArray([]),
            };
            this.companyLogoPathTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.CompanyLogoPath; }), companyLogoPathTxFieldOptions);
            var companyLogoPositionOgroupFieldOptions = {
                label: ko.observable("Company Logo Position"),
                options: ko.observableArray([
                    { text: ko.observable("Right"), value: "Right" },
                    { text: ko.observable("Left"), value: "Left" },
                ]),
                defaultValue: ko.observable("Right"),
                validations: ko.observableArray([]),
            };
            this.companyLogoPositionOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.CompanyLogoPosition; }), companyLogoPositionOgroupFieldOptions);
            var invoiceDisplayNameTxFieldOptions = {
                label: ko.observable("Invoice Display Name"),
                validations: ko.observableArray([]),
            };
            var companyNameTxFieldOptions = {
                label: ko.observable("Company Name"),
                validations: ko.observableArray([]),
            };
            this.companyNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.CompanyName; }), companyNameTxFieldOptions);
            this.invoiceDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.InvoiceDisplayName; }), invoiceDisplayNameTxFieldOptions);
            var invoicePeriodDisplayNameTxFieldOptions = {
                label: ko.observable("Invoice Period Display Name"),
                validations: ko.observableArray([]),
            };
            this.invoicePeriodDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.InvoicePeriodDisplayName; }), invoicePeriodDisplayNameTxFieldOptions);
            var lineItemsTableDisplayNameTxFieldOptions = {
                label: ko.observable("Line Items Table Display Name"),
                validations: ko.observableArray([]),
            };
            this.lineItemsTableDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.LineItemsTableDisplayName; }), lineItemsTableDisplayNameTxFieldOptions);
            var lineItemsTableDescriptionColumnNameTxFieldOptions = {
                label: ko.observable("Line Items Table Description Column Name"),
                validations: ko.observableArray([]),
            };
            this.lineItemsTableDescriptionColumnNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.LineItemsTableDescriptionColumnName; }), lineItemsTableDescriptionColumnNameTxFieldOptions);
            var lineItemsTableQuantityColumnNameTxFieldOptions = {
                label: ko.observable("Line Items Table Quantity Column Name"),
                validations: ko.observableArray([]),
            };
            this.lineItemsTableQuantityColumnNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.LineItemsTableQuantityColumnName; }), lineItemsTableQuantityColumnNameTxFieldOptions);
            var lineitemsTableUnitPriceColumnNameTxFieldOptions = {
                label: ko.observable("Line Items Table Unit Price Column Name"),
                validations: ko.observableArray([]),
            };
            this.lineitemsTableUnitPriceColumnNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.LineitemsTableUnitPriceColumnName; }), lineitemsTableUnitPriceColumnNameTxFieldOptions);
            var lineItemsTableAmountColumnNameTxFieldOptions = {
                label: ko.observable("Line Items Table Amount Column Name"),
                validations: ko.observableArray([]),
            };
            this.lineItemsTableAmountColumnNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.LineItemsTableAmountColumnName; }), lineItemsTableAmountColumnNameTxFieldOptions);
            var lineItemsSumDisplayNameTxFieldOptions = {
                label: ko.observable("Line Items Sum Display Name"),
                validations: ko.observableArray([]),
            };
            this.lineItemsSumDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.LineItemsSumDisplayName; }), lineItemsSumDisplayNameTxFieldOptions);
            var userDisplayNameTxFieldOptions = {
                label: ko.observable("User Display Name"),
                validations: ko.observableArray([]),
            };
            this.userDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.UserDisplayName; }), userDisplayNameTxFieldOptions);
            var subscriptionDisplayNameTxFieldOptions = {
                label: ko.observable("Subscription Display Name"),
                validations: ko.observableArray([]),
            };
            this.subscriptionDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.SubscriptionDisplayName; }), subscriptionDisplayNameTxFieldOptions);
            var notesDisplayNameTxFieldOptions = {
                label: ko.observable("Notes Display Name"),
                validations: ko.observableArray([]),
            };
            this.notesDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.NotesDisplayName; }), notesDisplayNameTxFieldOptions);
            var notesTxFieldOptions = {
                label: ko.observable("Notes"),
                validations: ko.observableArray([]),
            };
            this.notesTxField = new FxForms.MultiLineTextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.Notes; }), notesTxFieldOptions);
            var standardTaxRateTxFieldOptions = {
                label: ko.observable("Standard Tax Rate (In %)"),
                validations: ko.observableArray([]),
                decimalPoint: ko.observable(10),
            };
            this.standardTaxRateTxField = new FxForms.NumericTextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.StandardTaxRate; }), standardTaxRateTxFieldOptions);
            var applyTaxOgroupFieldOptions = {
                label: ko.observable("Apply Tax ?"),
                options: ko.observableArray([
                    { text: ko.observable("Yes"), value: true },
                    { text: ko.observable("No"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.applyTaxOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.ApplyTax; }), applyTaxOgroupFieldOptions);
            var defaultCurrencyCodeTxFieldOptions = {
                label: ko.observable("Default Currency Code"),
                infoBalloonContent: ko.observable("Like: USD, INR, EUR"),
                validations: ko.observableArray([]),
            };
            this.defaultCurrencyCodeTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.DefaultCurrencyCode; }), defaultCurrencyCodeTxFieldOptions);
            var applyCurrencyCodeOgroupFieldOptions = {
                label: ko.observable("Apply Currency Code For User Profiles ?"),
                options: ko.observableArray([
                    { text: ko.observable("Yes"), value: true },
                    { text: ko.observable("No"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.applyCurrencyCodeOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.ApplyCurrencyCode; }), applyCurrencyCodeOgroupFieldOptions);
            var prorateMonthlyFeeInPricingProfilesOgroupFieldOptions = {
                label: ko.observable("Prorate Monthly Fee In Pricing Profiles ?"),
                options: ko.observableArray([
                    { text: ko.observable("Yes"), value: true },
                    { text: ko.observable("No"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.prorateMonthlyFeeInPricingProfilesOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.ProrateMonthlyFeeInPricingProfiles; }), prorateMonthlyFeeInPricingProfilesOgroupFieldOptions);
            var prorateFixedFeeAddOnsOgroupFieldOptions = {
                label: ko.observable("Prorate Fixed Fee Add-Ons ?"),
                options: ko.observableArray([
                    { text: ko.observable("Yes"), value: true },
                    { text: ko.observable("No"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.prorateFixedFeeAddOnsOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.ProrateFixedFeeAddOns; }), prorateFixedFeeAddOnsOgroupFieldOptions);
            var monthlyFeeDisplayNameTxFieldOptions = {
                label: ko.observable("Montlhy Fee Display Name"),
                validations: ko.observableArray([]),
            };
            this.monthlyFeeDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.MinimumMonthlyFeeDisplayName; }), monthlyFeeDisplayNameTxFieldOptions);
            var onetimeFeeDisplayNameTxFieldOptions = {
                label: ko.observable("One-Time Fee Display Name"),
                validations: ko.observableArray([]),
            };
            this.onetimeFeeDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.OneTimeFeeDisplayName; }), onetimeFeeDisplayNameTxFieldOptions);
            var unitCreditsDisplayNameTxFieldOptions = {
                label: ko.observable("Unit Credits Display Name"),
                validations: ko.observableArray([]),
            };
            this.unitCreditsDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.UnitCreditsDisplayName; }), unitCreditsDisplayNameTxFieldOptions);
            var promoCreditsDisplayNameTxFieldOptions = {
                label: ko.observable("Promotion Credits Display Name"),
                validations: ko.observableArray([]),
            };
            this.promoCreditsDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.PromotionCreditsDisplayName; }), promoCreditsDisplayNameTxFieldOptions);
            var userCreditsDisplayNameTxFieldOptions = {
                label: ko.observable("User Credits Display Name"),
                validations: ko.observableArray([]),
            };
            this.userCreditsDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.UserCreditsDisplayName; }), userCreditsDisplayNameTxFieldOptions);
            var unitsDisplayNameTxFieldOptions = {
                label: ko.observable("Units Display Name"),
                validations: ko.observableArray([]),
            };
            this.unitsDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.UnitsDisplayName; }), unitsDisplayNameTxFieldOptions);
            var periodDisplayNameTxFieldOptions = {
                label: ko.observable("Period Display Name"),
                validations: ko.observableArray([]),
            };
            this.periodDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.PeriodDisplayName; }), periodDisplayNameTxFieldOptions);
            var forSubscriptionDisplayNameTxFieldOptions = {
                label: ko.observable("For Subscription Display Name"),
                validations: ko.observableArray([]),
            };
            this.forSubscriptionDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.ForSubscriptionDisplayName; }), forSubscriptionDisplayNameTxFieldOptions);
            var standardTxDisplayNameTxFieldOptions = {
                label: ko.observable("Standard Tax Display Name"),
                validations: ko.observableArray([]),
            };
            this.standardTxDisplayNameTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.StandardTaxDisplayName; }), standardTxDisplayNameTxFieldOptions);
            this.formSection = new FxForms.Section.ViewModel(container, {
                children: ko.observableArray([
                    this.headerContentTxField,
                    this.footerContentTxField,
                    this.dateTimeFormatDdownField,
                    this.invoiceDueDateTxField,
                    this.notificationEmailDateTxField,
                    this.companyLogoPathTxField,
                    this.companyNameTxField,
                    this.companyLogoPositionOgroupField,
                    this.invoiceDisplayNameTxField,
                    this.invoicePeriodDisplayNameTxField,
                    this.lineItemsTableDisplayNameTxField,
                    this.lineItemsTableDescriptionColumnNameTxField,
                    this.lineItemsTableAmountColumnNameTxField,
                    this.lineItemsSumDisplayNameTxField,
                    this.userDisplayNameTxField,
                    this.subscriptionDisplayNameTxField,
                    this.notesDisplayNameTxField,
                    this.notesTxField,
                    this.standardTaxRateTxField,
                    this.applyTaxOgroupField,
                    this.monthlyFeeDisplayNameTxField,
                    this.onetimeFeeDisplayNameTxField,
                    this.promoCreditsDisplayNameTxField,
                    this.unitCreditsDisplayNameTxField,
                    this.userCreditsDisplayNameTxField,
                    this.standardTxDisplayNameTxField,
                    this.unitsDisplayNameTxField,
                    this.periodDisplayNameTxField,
                    this.forSubscriptionDisplayNameTxField
                ])
            });
        };
        InvoicePdfSettingsViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            var args = {
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            };
            return this._editScopeView.fetchForExistingData(inputs.editScopeId, null);
        };
        return InvoicePdfSettingsViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.InvoicePdfSettingsViewModel = InvoicePdfSettingsViewModel;
});
