var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Models/SettingsModel"], function (require, exports, SettingsModel) {
    "use strict";
    var Images = MsPortalFx.Base.Images;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var MiscSettingsViewModel = (function (_super) {
        __extends(MiscSettingsViewModel, _super);
        function MiscSettingsViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable("");
            this.location = ko.observable("");
            this.title("Misc Settings");
            this.description("Misc Settings Details");
            this.icon(Images.Customize());
            this._container = container;
            this._dataContext = dataContext;
            this._settingEntityView = dataContext.settingsGroupManager.settingsGroupQuery.createView(container);
            this._initializeEditScope();
            this._initializeActionBar(container);
            this._initializeFormFields(container);
            this.actionBar.saveButtonClick = function () {
                return _this._editScopeView.editScope().saveChanges().then(function () {
                    _this._container.closeCurrentBlade();
                });
            };
            this.actionBar.discardButtonClick = function () {
                if (_this._form.editScope()) {
                    _this._form.editScope().revertAll();
                }
            };
        }
        MiscSettingsViewModel.prototype._initializeEditScope = function () {
            var _this = this;
            var editScopeCache = MsPortalFx.Data.EditScopeCache.createNew({
                supplyExistingData: function (key, lifetime) {
                    var args = {
                        subscriptionId: _this.subscriptionId(),
                    };
                    return _this._settingEntityView.fetch(args).then(function () {
                        var dataEntity = _this._settingEntityView.item();
                        var data = SettingsModel.MiscSettingsModel.getMiscSettingsData(dataEntity.MiscSettings());
                        return data;
                    });
                },
                saveEditScopeChanges: function (commandId, editScope, edits, lifetime, dataToUpdate) {
                    var command = editScope.root;
                    var dataManager = _this._dataContext.settingsGroupManager;
                    var op = dataManager.updateMiscSettingsQuery(_this.subscriptionId(), _this.location(), command);
                    _this._container.operations.add(op, { blockUi: true });
                    return op.then(function () {
                        return {
                            action: MsPortalFx.Data.AcceptEditScopeChangesAction.AcceptClientChanges
                        };
                    }).finally(function () {
                    });
                }
            });
            this._editScopeView = editScopeCache.createView(this._container);
            this._form = new FxForms.Form.ViewModel(this._container);
            this._form.editScope = this._editScopeView.editScope;
        };
        MiscSettingsViewModel.prototype._initializeActionBar = function (container) {
            var _this = this;
            this.actionBar = new MsPortalFx.ViewModels.ActionBars.FormActionBar.ViewModel(container);
            ko.reactor(container, function () {
                var es1 = _this._form.editScope;
                var isClean1 = ko.observable(!(es1() && es1().dirty()));
                var mustDisable1 = ko.observable(!es1() || es1().saving());
                _this.actionBar.disabled((mustDisable1()) || (isClean1()));
            });
        };
        MiscSettingsViewModel.prototype._initializeFormFields = function (container) {
            var IsEmailNotificationEnabledForInvoicesOgroupFieldOptions = {
                label: ko.observable("Send Invoice PDF Via Email For Tenants ?"),
                options: ko.observableArray([
                    { text: ko.observable("Yes"), value: true },
                    { text: ko.observable("No"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.IsEmailNotificationEnabledForInvoicesOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.IsEmailNotificationEnabledForInvoices; }), IsEmailNotificationEnabledForInvoicesOgroupFieldOptions);
            var ShouldSendEmailAlertForAgentServiceHealthStatusOgroupFieldOptions = {
                label: ko.observable("Send Email Alert When Agent Service Stops ?"),
                options: ko.observableArray([
                    { text: ko.observable("Yes"), value: true },
                    { text: ko.observable("No"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.ShouldSendEmailAlertForAgentServiceHealthStatusOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.ShouldSendEmailAlertForAgentServiceHealthStatus; }), ShouldSendEmailAlertForAgentServiceHealthStatusOgroupFieldOptions);
            var ShouldSendEmailAlertForJobProcessorHealthStatusOgroupFieldOptions = {
                label: ko.observable("Send Email Alerts When Jobs stop In Agent Service ?"),
                options: ko.observableArray([
                    { text: ko.observable("Yes"), value: true },
                    { text: ko.observable("No"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.ShouldSendEmailAlertForJobProcessorHealthStatusOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.ShouldSendEmailAlertForJobProcessorHealthStatus; }), ShouldSendEmailAlertForJobProcessorHealthStatusOgroupFieldOptions);
            this.formSection = new FxForms.Section.ViewModel(container, {
                children: ko.observableArray([
                    this.IsEmailNotificationEnabledForInvoicesOgroupField,
                    this.ShouldSendEmailAlertForAgentServiceHealthStatusOgroupField,
                ])
            });
        };
        MiscSettingsViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            var args = {
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            };
            return this._editScopeView.fetchForExistingData(inputs.editScopeId, null);
        };
        return MiscSettingsViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.MiscSettingsViewModel = MiscSettingsViewModel;
});
