var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Models/SettingsModel"], function (require, exports, SettingsModel) {
    "use strict";
    var Images = MsPortalFx.Base.Images;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var ProductFeaturesSettingsViewModel = (function (_super) {
        __extends(ProductFeaturesSettingsViewModel, _super);
        function ProductFeaturesSettingsViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable("");
            this.location = ko.observable("");
            this.title("Product Feature Settings");
            this.description("Product Feature Details");
            this.icon(Images.Customize());
            this._container = container;
            this._dataContext = dataContext;
            this._settingEntityView = dataContext.settingsGroupManager.settingsGroupQuery.createView(container);
            this._initializeEditScope();
            this._initializeActionBar(container);
            this._initializeFormFields(container);
            this.actionBar.saveButtonClick = function () {
                return _this._editScopeView.editScope().saveChanges().then(function () {
                    _this._container.closeCurrentBlade();
                });
            };
            this.actionBar.discardButtonClick = function () {
                if (_this._form.editScope()) {
                    _this._form.editScope().revertAll();
                }
            };
        }
        ProductFeaturesSettingsViewModel.prototype._initializeEditScope = function () {
            var _this = this;
            var editScopeCache = MsPortalFx.Data.EditScopeCache.createNew({
                supplyExistingData: function (key, lifetime) {
                    var args = {
                        subscriptionId: _this.subscriptionId(),
                    };
                    return _this._settingEntityView.fetch(args).then(function () {
                        var dataEntity = _this._settingEntityView.item();
                        var data = SettingsModel.ProductFeaturesSettingsModel.getProductFeaturesSettingsData(dataEntity.ProductFeaturesSettings());
                        return data;
                    });
                },
                saveEditScopeChanges: function (commandId, editScope, edits, lifetime, dataToUpdate) {
                    var command = editScope.root;
                    var dataManager = _this._dataContext.settingsGroupManager;
                    var op = dataManager.updateProductFeaturesSettingsQuery(_this.subscriptionId(), _this.location(), command);
                    _this._container.operations.add(op, { blockUi: true });
                    return op.then(function () {
                        return {
                            action: MsPortalFx.Data.AcceptEditScopeChangesAction.AcceptClientChanges
                        };
                    }).finally(function () {
                    });
                }
            });
            this._editScopeView = editScopeCache.createView(this._container);
            this._form = new FxForms.Form.ViewModel(this._container);
            this._form.editScope = this._editScopeView.editScope;
        };
        ProductFeaturesSettingsViewModel.prototype._initializeActionBar = function (container) {
            var _this = this;
            this.actionBar = new MsPortalFx.ViewModels.ActionBars.FormActionBar.ViewModel(container);
            ko.reactor(container, function () {
                var es1 = _this._form.editScope;
                var isClean1 = ko.observable(!(es1() && es1().dirty()));
                var mustDisable1 = ko.observable(!es1() || es1().saving());
                _this.actionBar.disabled((mustDisable1()) || (isClean1()));
            });
        };
        ProductFeaturesSettingsViewModel.prototype._initializeFormFields = function (container) {
            var isPromotionsFeatureEnabledOgroupFieldOptions = {
                label: ko.observable("Is Promotions Feature Enabled ?"),
                options: ko.observableArray([
                    { text: ko.observable("Enable"), value: true },
                    { text: ko.observable("Disable"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.isPromotionsFeatureEnabledOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.IsPromotionsFeatureEnabled; }), isPromotionsFeatureEnabledOgroupFieldOptions);
            var isNotificationsFeatureEnabledForTenantOgroupFieldOptions = {
                label: ko.observable("Is Notifications Feature Enabled For Tenants?"),
                options: ko.observableArray([
                    { text: ko.observable("Enable"), value: true },
                    { text: ko.observable("Disable"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.isNotificationsFeatureEnabledForTenantOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.IsNotificationsFeatureEnabledForTenant; }), isNotificationsFeatureEnabledForTenantOgroupFieldOptions);
            var isInvoicesFeatureEnabledForTenantOgroupFieldOptions = {
                label: ko.observable("Show Invoices To Tenants ?"),
                options: ko.observableArray([
                    { text: ko.observable("Enable"), value: true },
                    { text: ko.observable("Disable"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.isInvoicesFeatureEnabledForTenantOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.IsInvoicesFeatureEnabledForTenant; }), isInvoicesFeatureEnabledForTenantOgroupFieldOptions);
            var canTenantDownloadInvoicePDFOgroupFieldOptions = {
                label: ko.observable("Can Tenants Download Invoice PDF ?"),
                options: ko.observableArray([
                    { text: ko.observable("Enable"), value: true },
                    { text: ko.observable("Disable"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.canTenantDownloadInvoicePDFOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.CanTenantDownloadInvoicePDF; }), canTenantDownloadInvoicePDFOgroupFieldOptions);
            var shouldShowCoAdminSubscriptionsToTenantsOgroupFieldOptions = {
                label: ko.observable("Should Show Co-Admin Subscriptions To Tenants ?"),
                options: ko.observableArray([
                    { text: ko.observable("Enable"), value: true },
                    { text: ko.observable("Disable"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.shouldShowCoAdminSubscriptionsToTenantsOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.ShouldShowCoAdminSubscriptionsToTenants; }), shouldShowCoAdminSubscriptionsToTenantsOgroupFieldOptions);
            var isPricingCatalogFeatureEnabledOgroupFieldOptions = {
                label: ko.observable("Is Pricing Catalog Feature Enabled ?"),
                options: ko.observableArray([
                    { text: ko.observable("Enable"), value: true },
                    { text: ko.observable("Disable"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.isPricingCatalogFeatureEnabledOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.IsPricingCatalogFeatureEnabled; }), isPricingCatalogFeatureEnabledOgroupFieldOptions);
            var isInvokeSubscriptionCrudTemplatesOgroupFieldOptions = {
                label: ko.observable("Should invoke Subscription Template Operations ?"),
                options: ko.observableArray([
                    { text: ko.observable("Enable"), value: true },
                    { text: ko.observable("Disable"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.isInvokeSubscriptionCrudTemplatesOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.IsInvokeSubscriptionCrudTemplates; }), isInvokeSubscriptionCrudTemplatesOgroupFieldOptions);
            var isPaymentGatewayFeatureEnabledOgroupFieldOptions = {
                label: ko.observable("Is Payment Gateway Feature Enabled ?"),
                options: ko.observableArray([
                    { text: ko.observable("Enable"), value: true },
                    { text: ko.observable("Disable"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.isPaymentGatewayFeatureEnabledOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.IsPaymentGatewayFeatureEnabled; }), isPaymentGatewayFeatureEnabledOgroupFieldOptions);
            var isUserProfileFeatureEnabledOgroupFieldOptions = {
                label: ko.observable("Is User Profile Feature Enabled ?"),
                options: ko.observableArray([
                    { text: ko.observable("Enable"), value: true },
                    { text: ko.observable("Disable"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.isUserProfileFeatureEnabledOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.IsUserProfileFeatureEnabled; }), isUserProfileFeatureEnabledOgroupFieldOptions);
            var isCSPFeatureEnabledOgroupFieldOptions = {
                label: ko.observable("Is CSP Feature Enabled ?"),
                options: ko.observableArray([
                    { text: ko.observable("Enable"), value: true },
                    { text: ko.observable("Disable"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.isCSPFeatureEnabledOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.IsCSPFeatureEnabled; }), isCSPFeatureEnabledOgroupFieldOptions);
            var shouldShowOnlyAzureStackQuotaBladesOptions = {
                label: ko.observable("Should Show Only AzureStack Quota Blades to Tenant ?"),
                options: ko.observableArray([
                    { text: ko.observable("Enable"), value: true },
                    { text: ko.observable("Disable"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.shouldShowOnlyAzureStackQuotaBladesOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.ShowOnlyAzureStackQuotaBlades; }), shouldShowOnlyAzureStackQuotaBladesOptions);
            var allowTenantsToPayViaStripeOgroupFieldOptions = {
                label: ko.observable("Allow Tenants To Pay Invoice Via Stripe ?"),
                options: ko.observableArray([
                    { text: ko.observable("Enable"), value: true },
                    { text: ko.observable("Disable"), value: false }
                ]),
                validations: ko.observableArray([]),
            };
            this.allowTenantsToPayViaStripeOgroupField = new FxForms.OptionsGroup.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.AllowTenantsToPayViaStripe; }), allowTenantsToPayViaStripeOgroupFieldOptions);
            this.formSection = new FxForms.Section.ViewModel(container, {
                children: ko.observableArray([
                    this.isPromotionsFeatureEnabledOgroupField,
                    this.isNotificationsFeatureEnabledForTenantOgroupField,
                    this.isInvoicesFeatureEnabledForTenantOgroupField,
                    this.canTenantDownloadInvoicePDFOgroupField,
                    this.allowTenantsToPayViaStripeOgroupField,
                    this.isCSPFeatureEnabledOgroupField,
                    this.shouldShowOnlyAzureStackQuotaBladesOgroupField,
                ])
            });
        };
        ProductFeaturesSettingsViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            var args = {
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            };
            return this._editScopeView.fetchForExistingData(inputs.editScopeId, null);
        };
        return ProductFeaturesSettingsViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.ProductFeaturesSettingsViewModel = ProductFeaturesSettingsViewModel;
});
