var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Models/SettingsModel"], function (require, exports, SettingsModel) {
    "use strict";
    var Images = MsPortalFx.Base.Images;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var StripeSettingsViewModel = (function (_super) {
        __extends(StripeSettingsViewModel, _super);
        function StripeSettingsViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable("");
            this.location = ko.observable("");
            this._actionBarButtonLabel = ko.observable("");
            this.title("Stripe Settings");
            this.description("Stripe Details");
            this.icon(Images.Customize());
            this._container = container;
            this._dataContext = dataContext;
            this._settingEntityView = dataContext.settingsGroupManager.settingsGroupQuery.createView(container);
            this._initializeEditScope();
            this._initializeActionBar(container);
            this._initializeFormFields(container);
            this.actionBar.saveButtonClick = function () {
                return _this._editScopeView.editScope().saveChanges().then(function () {
                    _this._container.closeCurrentBlade();
                });
            };
            this.actionBar.discardButtonClick = function () {
                if (_this._form.editScope()) {
                    _this._form.editScope().revertAll();
                }
            };
        }
        StripeSettingsViewModel.prototype._initializeEditScope = function () {
            var _this = this;
            var editScopeCache = MsPortalFx.Data.EditScopeCache.createNew({
                supplyExistingData: function (key, lifetime) {
                    var args = {
                        subscriptionId: _this.subscriptionId(),
                    };
                    return _this._settingEntityView.fetch(args).then(function () {
                        var dataEntity = _this._settingEntityView.item();
                        var data = SettingsModel.StripeSettingsModel.getStripeSettingsData(dataEntity.StripeSettings());
                        return data;
                    });
                },
                saveEditScopeChanges: function (commandId, editScope, edits, lifetime, dataToUpdate) {
                    var command = editScope.root;
                    var dataManager = _this._dataContext.settingsGroupManager;
                    var op = dataManager.updateStripeSettingsQuery(_this.subscriptionId(), _this.location(), command);
                    _this._container.operations.add(op, { blockUi: true });
                    return op.then(function () {
                        return {
                            action: MsPortalFx.Data.AcceptEditScopeChangesAction.AcceptClientChanges
                        };
                    }).finally(function () {
                    });
                }
            });
            this._editScopeView = editScopeCache.createView(this._container);
            this._form = new FxForms.Form.ViewModel(this._container);
            this._form.editScope = this._editScopeView.editScope;
        };
        StripeSettingsViewModel.prototype._initializeActionBar = function (container) {
            var _this = this;
            this.actionBar = new MsPortalFx.ViewModels.ActionBars.FormActionBar.ViewModel(container);
            ko.reactor(container, function () {
                var es1 = _this._form.editScope;
                var isClean1 = ko.observable(!(es1() && es1().dirty()));
                var mustDisable1 = ko.observable(!es1() || es1().saving());
                _this.actionBar.disabled((mustDisable1()) || (isClean1()));
            });
        };
        StripeSettingsViewModel.prototype._initializeFormFields = function (container) {
            var StripePublishableKeyFieldOptions = {
                label: ko.observable("Public Key"),
                validations: ko.observableArray([]),
            };
            this.StripePublishableKeyTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.StripePublishableKey; }), StripePublishableKeyFieldOptions);
            var StripeSecretKeyTxFieldOptions = {
                label: ko.observable("Secret Key"),
                validations: ko.observableArray([]),
            };
            this.StripeSecretKeyTxField = new FxForms.PasswordBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.StripeSecretKey; }), StripeSecretKeyTxFieldOptions);
            var StripeZeroDecimalCurrenciesTxFieldOptions = {
                label: ko.observable("Zero Decimal Currencies"),
                infoBalloonContent: ko.observable("These currencies are not expected to be specified in the smallest currency unit in Stripe. E.g.$10 USD is converted to 1000 cents before processing in Stripe where as ¥500 is sent as 500."),
                validations: ko.observableArray([]),
            };
            this.StripeZeroDecimalCurrenciesTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.StripeZeroDecimalCurrencies; }), StripeZeroDecimalCurrenciesTxFieldOptions);
            var BillingTenantExtUrlTxFieldOptions = {
                label: ko.observable("Billing Tenant Extension URL"),
                infoBalloonContent: ko.observable("Azure Stack Billing Tenant Extension Url, E.g: https://billing.cloudassert.location.azurestack.mas:44303"),
                validations: ko.observableArray([]),
            };
            this.BillingTenantExtUrlTxField = new FxForms.TextBox.ViewModel(container, this._form, this._form.createEditScopeAccessor(function (data) { return data.BillingTenantExtUrl; }), BillingTenantExtUrlTxFieldOptions);
            this.formSection = new FxForms.Section.ViewModel(container, {
                children: ko.observableArray([
                    this.StripePublishableKeyTxField,
                    this.StripeSecretKeyTxField,
                ])
            });
        };
        StripeSettingsViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            var args = {
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            };
            return this._editScopeView.fetchForExistingData(inputs.editScopeId, null);
        };
        return StripeSettingsViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.StripeSettingsViewModel = StripeSettingsViewModel;
});
