define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    var DataModels = BillingExtension.DataModels;
    var ArmHelpers = Common.Helpers;
    var fxEnv = window.fx.environment;
    var billingRpApiVersion = fxEnv.billingRpApiVersion;
    "use strict";
    var UserProfileDataManager = (function () {
        function UserProfileDataManager() {
            this.userProfileQueryUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminUserProfiles", billingRpApiVersion);
            this.approveUserProfileQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminUserProfiles/{userProfileId}/approveSignupRequest";
            this.rejectUserProfileQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminUserProfiles/{userProfileId}/rejectSignupRequest";
            this.deleteUserProfileQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminUserProfiles/{userProfileId}/deleteUserProfile";
            this.userProfileQuery = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.TenantBasicProfileModelType,
                sourceUri: this.userProfileQueryUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
        }
        UserProfileDataManager.prototype.approveUserProfileQuery = function (subscriptionId, location, userProfileId) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                userProfileId: userProfileId
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.approveUserProfileQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "PUT");
            var notificationSettings = {
                success: {
                    title: "Successfully approved User Profile",
                    description: "Success"
                },
                inProgress: {
                    title: "Approving User Profile...",
                    description: "..."
                },
                error: {
                    title: "Failure approving User Profile",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "User Profile");
            return promise.then(function () {
                return _this.userProfileQuery.refreshAll();
            });
        };
        UserProfileDataManager.prototype.rejectUserProfileQuery = function (subscriptionId, location, userProfileId) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                userProfileId: userProfileId
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.rejectUserProfileQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "PUT");
            var notificationSettings = {
                success: {
                    title: "Successfully rejected User Profile",
                    description: "Success"
                },
                inProgress: {
                    title: "Rejecting User Profile...",
                    description: "..."
                },
                error: {
                    title: "Failure rejecting User Profile",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "User Profile");
            return promise.then(function () {
                return _this.userProfileQuery.refreshAll();
            });
        };
        UserProfileDataManager.prototype.deleteUserProfileQuery = function (subscriptionId, location, userProfileId) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                userProfileId: userProfileId
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.deleteUserProfileQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "DELETE");
            var notificationSettings = {
                success: {
                    title: "Successfully deleted User Profile",
                    description: "Success"
                },
                inProgress: {
                    title: "Deleting User Profile...",
                    description: "..."
                },
                error: {
                    title: "Failure deleting User Profile",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "User Profile");
            return promise.then(function () {
                return _this.userProfileQuery.refreshAll();
            });
        };
        return UserProfileDataManager;
    }());
    exports.UserProfileDataManager = UserProfileDataManager;
});
