define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    var DataModels = BillingExtension.DataModels;
    var ArmHelpers = Common.Helpers;
    var fxEnv = window.fx.environment;
    var billingRpApiVersion = fxEnv.billingRpApiVersion;
    "use strict";
    var BillingQuotaDataManager = (function () {
        function BillingQuotaDataManager() {
            this.listBillingQuotasQueryUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{locationName}/quotas/ListBillingQuotas", billingRpApiVersion);
            this.billingQuotaEntityUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{locationName}/quotas/GetBillingQuotaById/{quotaId}", billingRpApiVersion);
            this.addBillingQuotaQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{locationName}/quotas/AddBillingQuota/{name}";
            this.cloneBillingQuotaQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{locationName}/quotas/CloneBillingQuota/{quotaId}";
            this.updateBillingQuotaQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{locationName}/quotas/UpdateBillingQuotaAsync";
            this.deleteBillingQuotaUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{locationName}/quotas/{quotaId}";
            this.listBillingQuotasQuery = new MsPortalFx.Data.QueryCache({
                entityTypeName: DataModels.BillingQuotaOutModelType,
                sourceUri: this.listBillingQuotasQueryUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
            this.billingQuotaEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.BillingQuotaSettingsModelType,
                sourceUri: this.billingQuotaEntityUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: false
            });
        }
        BillingQuotaDataManager.prototype.addBillingQuotaQuery = function (subscriptionId, location, name, billingQuotaSettings) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                name: name,
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.addBillingQuotaQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(billingQuotaSettings);
            var promise = Helpers.callArm(uriSegment, "PUT", billingRpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully added Billing Quota",
                    description: "Success"
                },
                inProgress: {
                    title: "Adding Billing Quota...",
                    description: "..."
                },
                error: {
                    title: "Failure adding Billing Quota",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Billing Quota");
            return promise.then(function () {
                return _this.listBillingQuotasQuery.refreshAll();
            });
        };
        BillingQuotaDataManager.prototype.cloneBillingQuota = function (subscriptionId, locationName, quotaId) {
            var _this = this;
            var uri = MsPortalFx.Data.uriFormatter(this.cloneBillingQuotaQueryUriFormat, false)({
                subscriptionId: subscriptionId,
                locationName: locationName,
                quotaId: quotaId
            });
            var urlSegmentWithApiVersion = uri + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            var notificationSettings = {
                success: {
                    title: "Successfully cloned Billing Quota",
                    description: "Success"
                },
                inProgress: {
                    title: "Cloning Billing Quota...",
                    description: "..."
                },
                error: {
                    title: "Failure cloning Billing Quota",
                    description: "Failure"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Pricing Profile");
            return promise.then(function () {
                return _this.listBillingQuotasQuery.refreshAll();
            });
        };
        BillingQuotaDataManager.prototype.updateBillingQuotaQuery = function (subscriptionId, location, billingQuotaIn) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                locationName: location,
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateBillingQuotaQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(billingQuotaIn);
            var promise = Helpers.callArm(uriSegment, "PUT", billingRpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Billing Quota",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Billing Quota...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Billing Quota",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Billing Quota");
            return promise.then(function () {
                return _this.listBillingQuotasQuery.refreshAll();
            });
        };
        BillingQuotaDataManager.prototype.deleteBillingQuota = function (subscriptionId, locationName, quotaId) {
            var _this = this;
            var uri = MsPortalFx.Data.uriFormatter(this.deleteBillingQuotaUriFormat, false)({
                subscriptionId: subscriptionId,
                locationName: locationName,
                quotaId: quotaId
            });
            var urlSegmentWithApiVersion = uri + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "DELETE");
            var notificationSettings = {
                success: {
                    title: "Successfully deleted the billing quota",
                    description: "Success"
                },
                inProgress: {
                    title: "Deleting billing quota...",
                    description: "..."
                },
                error: {
                    title: "Failure deleting billing quota",
                    description: "Failure"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Pricing Profile");
            return promise.then(function () {
                return _this.listBillingQuotasQuery.refreshAll();
            });
        };
        return BillingQuotaDataManager;
    }());
    exports.BillingQuotaDataManager = BillingQuotaDataManager;
});
