define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    var DataModels = BillingExtension.DataModels;
    var ArmConstants = Common.Constants;
    var ArmHelpers = Common.Helpers;
    var billingRpApiVersion = window.fx.environment.billingRpApiVersion;
    "use strict";
    var CspDataManager = (function () {
        function CspDataManager() {
            this._getCustomerProfileListQueryUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/csp/getCustomerProfiles", billingRpApiVersion);
            this._approveCustomerProfileRequestQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/csp/approve/{tenantSubscriptionId}/cutomerProfileId/{customerTenantId}";
            this._rejectCustomerProfileRequestQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/csp/reject/{tenantSubscriptionId}/cutomerProfileId/{customerTenantId}";
            this.getCustomerProfileList = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.CspCustomerProfileOutModelType,
                sourceUri: this._getCustomerProfileListQueryUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
            this.cspOffersQuery = new MsPortalFx.Data.QueryCache({
                sourceUri: ArmHelpers.getArmUriFormatter(CspDataManager._queryRelativeUriFormat, billingRpApiVersion),
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: true,
                pollInterval: ArmConstants.PollingFrequency.normal
            });
            this.cspOfferEntity = new MsPortalFx.Data.EntityCache({
                sourceUri: ArmHelpers.getArmUriFormatter(CspDataManager._entityRelativeUriFormat, billingRpApiVersion),
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: true,
                pollInterval: ArmConstants.PollingFrequency.normal
            });
        }
        CspDataManager.prototype.approveCustomerProfileQuery = function (subscriptionId, location, tenantSubscriptionId, customerTenantId) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                tenantSubscriptionId: tenantSubscriptionId,
                customerTenantId: customerTenantId
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this._approveCustomerProfileRequestQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            var notificationSettings = {
                success: {
                    title: "Successfully approved Customer Profile",
                    description: "Success"
                },
                inProgress: {
                    title: "Approving Customer Profile...",
                    description: "..."
                },
                error: {
                    title: "Failure approving Customer Profile",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "CSP Customer Profile");
            return promise.then(function () {
                return _this.getCustomerProfileList.refreshAll();
            });
        };
        CspDataManager.prototype.rejectCustomerProfileQuery = function (subscriptionId, location, tenantSubscriptionId, customerTenantId) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                tenantSubscriptionId: tenantSubscriptionId,
                customerTenantId: customerTenantId
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this._rejectCustomerProfileRequestQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            var notificationSettings = {
                success: {
                    title: "Successfully rejected Customer Profile",
                    description: "Success"
                },
                inProgress: {
                    title: "Rejecting Customer Profile...",
                    description: "..."
                },
                error: {
                    title: "Failure rejecting Customer Profile",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "CSP Customer Profile");
            return promise.then(function () {
                return _this.getCustomerProfileList.refreshAll();
            });
        };
        CspDataManager.prototype.publishToGallery = function (subscriptionId, location, cspOfferIds) {
            var urlSegment = MsPortalFx.Data.uriFormatter(CspDataManager._publishToGalleryUriViaArmFormat, false)({
                subscriptionId: subscriptionId,
                location: location
            });
            var data = {
                cspOfferIds: cspOfferIds
            };
            var promise = ArmHelpers.callArmUri(urlSegment + "?api-version=" + billingRpApiVersion, "POST", data);
            var notificationSettings = {
                success: {
                    title: "Successfully published CSP Offers to Market Place Gallery",
                    description: "Success"
                },
                inProgress: {
                    title: "Publishing CSP Offers to Market Place Gallery",
                    description: "..."
                },
                error: {
                    title: "Failure publishing CSP Offers to Market Place Gallery",
                    description: "Failure"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "CSP Offers");
            return promise;
        };
        CspDataManager._queryRelativeUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/csp";
        CspDataManager._entityRelativeUriFormat = "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/CloudAssert.Billing.Admin/csp/{cspOfferId}";
        CspDataManager._tenantGetVmTemplateParamDefUriFormat = "/subscriptions/{0}/providers/CloudAssert.Billing/locations/{1}/csp/{2}";
        CspDataManager._publishToGalleryUriViaArmFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/csp/publishToGallery";
        CspDataManager._publishToGalleryUriFormat = "/subscriptions/{0}/providers/CloudAssert.Billing.Admin/locations/{1}/csp/publishToGallery";
        return CspDataManager;
    }());
    exports.CspDataManager = CspDataManager;
});
