define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    var DataModels = BillingExtension.DataModels;
    var ArmHelpers = Common.Helpers;
    var fxEnv = window.fx.environment;
    var billingRpApiVersion = window.fx.environment.billingRpApiVersion;
    "use strict";
    var InvoicesDataManager = (function () {
        function InvoicesDataManager() {
            this.Urls = {
                markInvoiceStatusAsPaid: "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/invoices/{invoiceId}/MarkInvoiceAsPaid",
            };
            this.invoicesQueryUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/invoices?month={month}", billingRpApiVersion);
            this.invoiceEntityUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/invoices/{invoiceId}", billingRpApiVersion);
            this.downloadInvoiceUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/invoices/{invoiceId}/DownloadPdf", billingRpApiVersion);
            this.downloadInvoicesAsCsvUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/year/{year}/month/{month}/isUserLevel/{isUserLevel}DownloadInvoicesAsCsvAsync", billingRpApiVersion);
            this.updateInvoiceQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/invoices";
            this.invoicesQuery = new MsPortalFx.Data.QueryCache({
                entityTypeName: DataModels.InvoiceModelType,
                sourceUri: this.invoicesQueryUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
            this.invoiceEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.InvoiceModelType,
                sourceUri: this.invoiceEntityUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: false
            });
        }
        InvoicesDataManager.prototype.updateInvoiceQuery = function (subscriptionId, location, invoiceDataIn) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateInvoiceQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(invoiceDataIn);
            var promise = Helpers.callArm(uriSegment, "PUT", billingRpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Invoice",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Invoice...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Invoice",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Invoice");
            return promise.then(function () {
                return _this.invoicesQuery.refreshAll();
            });
        };
        InvoicesDataManager.prototype.markInvoiceAsPaid = function (subscriptionId, invoiceId) {
            var _this = this;
            var urlSegment = MsPortalFx.Data.uriFormatter(this.Urls.markInvoiceStatusAsPaid, false)({
                subscriptionId: subscriptionId,
                invoiceId: invoiceId,
            });
            var urlSegmentWithApiVersion = urlSegment + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return promise.then(function () {
                return _this.invoicesQuery.refreshAll();
            });
        };
        return InvoicesDataManager;
    }());
    exports.InvoicesDataManager = InvoicesDataManager;
});
