define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    var DataModels = BillingExtension.DataModels;
    var ArmHelpers = Common.Helpers;
    var fxEnv = window.fx.environment;
    var billingRpApiVersion = fxEnv.billingRpApiVersion;
    "use strict";
    var LicenseDataManager = (function () {
        function LicenseDataManager() {
            this.enabledFeaturesEntityUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminLicense", billingRpApiVersion);
            this.getActivationTextEntityUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminLicense/generateActivationText", billingRpApiVersion);
            this.enabledFeaturesEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.ProductFeaturesDataModelType,
                sourceUri: this.enabledFeaturesEntityUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
            this.getActivationTextEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.ActivationTextModelType,
                sourceUri: this.getActivationTextEntityUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
        }
        LicenseDataManager.prototype.extendLicense = function (subscriptionId, location, input) {
            var urlFormat = LicenseDataManager._queryRelativeUriFormat + "extendLicense";
            var urlSegment = MsPortalFx.Data.uriFormatter(urlFormat, false)({
                subscriptionId: subscriptionId,
                location: location,
            });
            var licenseInfo = ko.toJSON(input);
            var promise = Helpers.callArm(urlSegment, "PUT", billingRpApiVersion, licenseInfo);
            var notificationSettings = {
                success: {
                    title: "Successfully submitted the request to extend the license",
                    description: "Success"
                },
                inProgress: {
                    title: "Submitting the request to extend the license",
                    description: "..."
                },
                error: {
                    title: "Failure requesting to extend the license",
                    description: "Failure"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Usage and Billing License");
            return promise;
        };
        LicenseDataManager._queryRelativeUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.VConnect.Admin/locations/{location}/adminLicense/";
        return LicenseDataManager;
    }());
    exports.LicenseDataManager = LicenseDataManager;
});
