define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    var DataModels = BillingExtension.DataModels;
    var ArmHelpers = Common.Helpers;
    var fxEnv = window.fx.environment;
    var billingRpApiVersion = fxEnv.billingRpApiVersion;
    "use strict";
    var MeteredResourcePricingDataManager = (function () {
        function MeteredResourcePricingDataManager() {
            this.listMeteredResourcesQueryUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/meteredResource/{pricingProfileId}/listMeteredResources", billingRpApiVersion);
            this.cloneMeteredResourceQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/meteredResource/{meterId}/cloneMeter";
            this.getMeteredResourcesEntityUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/meteredResource/{meterId}/getMeteredResource", billingRpApiVersion);
            this.updateMeteredResourceQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/meteredResource/updateMetredResource";
            this.deleteMeteredResourceQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/meteredResource/{meterId}/deleteMeter";
            this.evaluateUnitFormulaQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/meteredResource/evaluateUnitFormula";
            this.evaluateCustomFormulaQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/meteredResource/evaluateCustomFormula";
            this.listMeteredResourcesQuery = new MsPortalFx.Data.QueryCache({
                entityTypeName: DataModels.MeteredResourceModelType,
                sourceUri: this.listMeteredResourcesQueryUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
            this.getMeteredResourcesEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.MeteredResourceModelType,
                sourceUri: this.getMeteredResourcesEntityUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: false
            });
        }
        MeteredResourcePricingDataManager.prototype.cloneMeteredResourceQuery = function (subscriptionId, location, meterId) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                meterId: meterId
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.cloneMeteredResourceQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "PUT");
            var notificationSettings = {
                success: {
                    title: "Successfully cloned Metered Resource",
                    description: "Success"
                },
                inProgress: {
                    title: "Cloning Metered Resource...",
                    description: "..."
                },
                error: {
                    title: "Failure cloning Metered Resource",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Metered Resource");
            return promise.then(function () {
                return _this.listMeteredResourcesQuery.refreshAll();
            });
        };
        MeteredResourcePricingDataManager.prototype.updateMeteredResourceEntity = function (subscriptionId, location, meteredResourceData) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateMeteredResourceQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(meteredResourceData);
            var promise = Helpers.callArm(uriSegment, "PUT", billingRpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Metered Resource",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Metered Resource...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Metered Resource",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Metered Resource");
            return promise.then(function () {
                return _this.listMeteredResourcesQuery.refreshAll();
            });
        };
        MeteredResourcePricingDataManager.prototype.deleteMeteredResourceQuery = function (subscriptionId, location, meterId) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                meterId: meterId
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.deleteMeteredResourceQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "DELETE");
            var notificationSettings = {
                success: {
                    title: "Successfully deleted Metered Resource",
                    description: "Success"
                },
                inProgress: {
                    title: "Deleting Metered Resource...",
                    description: "..."
                },
                error: {
                    title: "Failure deleting Metered Resource",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Metered Resource");
            return promise.then(function () {
                return _this.listMeteredResourcesQuery.refreshAll();
            });
        };
        MeteredResourcePricingDataManager.prototype.evaluateUnitFormulaQuery = function (subscriptionId, location, formula) {
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.evaluateUnitFormulaQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(formula);
            var promise = Helpers.callArm(uriSegment, "PUT", billingRpApiVersion, postData);
            return promise;
        };
        MeteredResourcePricingDataManager.prototype.evaluateCustomFormulaQuery = function (subscriptionId, location, formula) {
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.evaluateCustomFormulaQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(formula);
            var promise = Helpers.callArm(uriSegment, "PUT", billingRpApiVersion, postData);
            return promise;
        };
        return MeteredResourcePricingDataManager;
    }());
    exports.MeteredResourcePricingDataManager = MeteredResourcePricingDataManager;
});
