define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    var DataModels = BillingExtension.DataModels;
    var ArmHelpers = Common.Helpers;
    var fxEnv = window.fx.environment;
    var rpApiVersion = fxEnv.billingRpApiVersion;
    "use strict";
    var NotificationsDataManager = (function () {
        function NotificationsDataManager() {
            this.listNotificationsEntityUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminNotifications", rpApiVersion);
            this.listNotificationRulesEntityUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminNotificationRules", rpApiVersion);
            this.dismissNotificationQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminNotifications/{id}/dismissNotification";
            this.deleteNotificationQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminNotifications/{id}";
            this.clearAllNotificationsQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminNotifications/clearAllNotifications";
            this.addNotificationRuleQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminNotificationRules";
            this.updateNotificationRuleQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminNotificationRules/update";
            this.deleteNotificationRuleQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminNotificationRules/{id}";
            this.clearAllNotificationRuleQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminNotificationRules/clearAllAlertRules";
            this.listNotificationsEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.NotificationEventModelType,
                sourceUri: this.listNotificationsEntityUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: false
            });
            this.listNotificationRulesEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.NotificationRuleOutModelType,
                sourceUri: this.listNotificationRulesEntityUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: false
            });
        }
        NotificationsDataManager.prototype.deleteNotificationQuery = function (subscriptionId, location, id) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                id: id
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.deleteNotificationQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + rpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "DELETE");
            var notificationSettings = {
                success: {
                    title: "Successfully deleted Notification Message",
                    description: "Success"
                },
                inProgress: {
                    title: "Deleting Notification Message...",
                    description: "..."
                },
                error: {
                    title: "Failure deleting Notification Message",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Notification Messages");
            return promise.then(function () {
                return _this.listNotificationsEntity.refreshAll();
            });
        };
        NotificationsDataManager.prototype.dismissNotificationQuery = function (subscriptionId, location, id) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                id: id
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.dismissNotificationQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + rpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            var notificationSettings = {
                success: {
                    title: "Successfully dismissed Notification Message",
                    description: "Success"
                },
                inProgress: {
                    title: "Dismissing Notification Message...",
                    description: "..."
                },
                error: {
                    title: "Failure dismissing Notification Message",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Notification Messages");
            return promise.then(function () {
                return _this.listNotificationsEntity.refreshAll();
            });
        };
        NotificationsDataManager.prototype.clearAllNotificationsQuery = function (subscriptionId, location) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.clearAllNotificationsQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + rpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            var notificationSettings = {
                success: {
                    title: "Successfully cleared all Notification Messages",
                    description: "Success"
                },
                inProgress: {
                    title: "Clearing all Notification Messages...",
                    description: "..."
                },
                error: {
                    title: "Failure clearing Notification Messages",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Notification Messages");
            return promise.then(function () {
                return _this.listNotificationsEntity.refreshAll();
            });
        };
        NotificationsDataManager.prototype.addNotificationRuleQuery = function (subscriptionId, location, input) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.addNotificationRuleQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(input);
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully added Notification rule",
                    description: "Success"
                },
                inProgress: {
                    title: "Adding Notification Rule...",
                    description: "..."
                },
                error: {
                    title: "Failure adding Notification Rule",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Notification Rules");
            return promise.then(function () {
                return _this.listNotificationRulesEntity.refreshAll();
            });
        };
        NotificationsDataManager.prototype.updateNotificationRuleQuery = function (subscriptionId, location, input) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateNotificationRuleQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(input);
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Notification rule",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Notification Rule...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Notification Rule",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Notification Rules");
            return promise.then(function () {
                return _this.listNotificationRulesEntity.refreshAll();
            });
        };
        NotificationsDataManager.prototype.deleteNotificationRuleQuery = function (subscriptionId, location, id) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                id: id
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.deleteNotificationRuleQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + rpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "DELETE");
            var notificationSettings = {
                success: {
                    title: "Successfully deleted Notification Rule",
                    description: "Success"
                },
                inProgress: {
                    title: "Deleting Notification Rule...",
                    description: "..."
                },
                error: {
                    title: "Failure deleting Notification Rule",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Notification Rules");
            return promise.then(function () {
                return _this.listNotificationRulesEntity.refreshAll();
            });
        };
        NotificationsDataManager.prototype.clearAllNotificationRuleQuery = function (subscriptionId, location) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.clearAllNotificationRuleQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + rpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            var notificationSettings = {
                success: {
                    title: "Successfully cleared all Notification Rules",
                    description: "Success"
                },
                inProgress: {
                    title: "Clearing all Notification Rules...",
                    description: "..."
                },
                error: {
                    title: "Failure clearing Notification Rules",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Notification Rules");
            return promise.then(function () {
                return _this.listNotificationRulesEntity.refreshAll();
            });
        };
        return NotificationsDataManager;
    }());
    exports.NotificationsDataManager = NotificationsDataManager;
});
