define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    var DataModels = BillingExtension.DataModels;
    var ArmHelpers = Common.Helpers;
    var fxEnv = window.fx.environment;
    var billingRpApiVersion = fxEnv.billingRpApiVersion;
    "use strict";
    var PricingProfilesDataManager = (function () {
        function PricingProfilesDataManager() {
            this.Urls = {};
            this.pricingProfilesQueryUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles", billingRpApiVersion);
            this.pricingProfileEntityUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/{pricingProfileId}", billingRpApiVersion);
            this.importPricingProfileUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/0/Import?profileName={profileName}", billingRpApiVersion);
            this.exportPricingProfileUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/{pricingProfileId}/ExportToJson", billingRpApiVersion);
            this.editPricingProfileUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/{pricingProfileId}/Edit?profileName={profileName}", billingRpApiVersion);
            this.mappedProfilesQueryUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/mappedProfiles", billingRpApiVersion);
            this.eligibleBaseProfileEntityUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/{pricingProfileId}/mappedProfiles", billingRpApiVersion);
            this.UpdateMeteredResourcesUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/{pricingProfileId}/UpdateMeteredResources";
            this.deletePricingProfileUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{locationName}/pricingProfiles/{pricingProfileId}/deletePricingProfile";
            this.linkBaseProfileQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/{pricingProfileId}/linkBaseProfile/{baseProfileId}";
            this.unlinkBaseProfileQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/{pricingProfileId}/unlinkBaseProfile/{baseProfileId}";
            this.updateProfileDetailsQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/{pricingProfileId}/UpdateDetails";
            this.cloneProfileEntityUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/{pricingProfileId}/cloneProfile";
            this.getAvailableIsoCurrencyListQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/getAvailableIsoCurrencyList";
            this.getPricingProfilesToServiceTypeDictUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/pricingProfiles/getPricingProfilesToServiceTypeDict";
            this.pricingProfilesQuery = new MsPortalFx.Data.QueryCache({
                entityTypeName: DataModels.PricingProfileModelType,
                sourceUri: this.pricingProfilesQueryUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
            this.mappedProfilesQuery = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.BasePricingProfileMappingDataModelType,
                sourceUri: this.mappedProfilesQueryUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
            this.eligibleBaseProfileEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.BasePricingProfileDataModelType,
                sourceUri: this.eligibleBaseProfileEntityUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
            this.pricingProfileEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.PricingProfileModelType,
                sourceUri: this.pricingProfileEntityUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: false
            });
        }
        PricingProfilesDataManager.prototype.uploadPricingProfile = function (subscriptionId, location, profileName, fileData) {
            var _this = this;
            var formData = new FormData();
            var blob = new Blob([fileData], { type: "application/json" });
            formData.append("file", blob);
            var uploadUri = this.importPricingProfileUriFormat({
                subscriptionId: subscriptionId,
                location: location,
                profileName: profileName,
            });
            return MsPortalFx.Base.Net2.ajax({
                uri: uploadUri,
                type: "POST",
                contentType: false,
                processData: false,
                data: formData,
                setAuthorizationHeader: true,
            }).then(function (content) {
                console.log("Successfully uploaded Pricing Profile");
                _this.pricingProfilesQuery.refreshAll();
            }).catch(function (error) {
                console.log("Failed to upload file. Error: " + error);
            });
        };
        PricingProfilesDataManager.prototype.editPricingProfile = function (subscriptionId, location, pricingProfileId, profileName, fileData) {
            var _this = this;
            var formData = new FormData();
            var blob = new Blob([fileData], { type: "application/json" });
            formData.append("file", blob);
            var uploadUri = this.editPricingProfileUriFormat({
                subscriptionId: subscriptionId,
                location: location,
                pricingProfileId: pricingProfileId,
                profileName: profileName,
            });
            return MsPortalFx.Base.Net2.ajax({
                uri: uploadUri,
                type: "POST",
                contentType: false,
                processData: false,
                data: formData,
                setAuthorizationHeader: true,
            }).then(function (content) {
                console.log("Successfully updated Pricing Profile");
                _this.pricingProfilesQuery.refreshAll();
                _this.pricingProfileEntity.refreshAll();
            }).catch(function (error) {
                console.log("Failed to upload file. Error: " + error);
            });
        };
        PricingProfilesDataManager.prototype.deletePricingProfile = function (subscriptionId, locationName, pricingProfileId) {
            var _this = this;
            var uri = MsPortalFx.Data.uriFormatter(this.deletePricingProfileUriFormat, false)({
                subscriptionId: subscriptionId,
                locationName: locationName,
                pricingProfileId: pricingProfileId
            });
            var urlSegmentWithApiVersion = uri + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "DELETE");
            var notificationSettings = {
                success: {
                    title: "Successfully deleted the pricing profile",
                    description: "Success"
                },
                inProgress: {
                    title: "Deleting pricing profile",
                    description: "..."
                },
                error: {
                    title: "Failure deleting pricing profile",
                    description: "Failure"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Pricing Profile");
            return promise.then(function () {
                return _this.pricingProfilesQuery.refreshAll();
            });
        };
        PricingProfilesDataManager.prototype.linkBaseProfileQuery = function (subscriptionId, location, pricingProfileId, baseProfileId) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                pricingProfileId: pricingProfileId,
                baseProfileId: baseProfileId
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.linkBaseProfileQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "PUT");
            var notificationSettings = {
                success: {
                    title: "Successfully linked Base Profile",
                    description: "Success"
                },
                inProgress: {
                    title: "Linking Base Profile...",
                    description: "..."
                },
                error: {
                    title: "Failure linking Base Profile",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Base Profile Mapping");
            return promise.then(function () {
                return _this.mappedProfilesQuery.refreshAll();
            });
        };
        PricingProfilesDataManager.prototype.unlinkBaseProfileQuery = function (subscriptionId, location, pricingProfileId, baseProfileId) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                pricingProfileId: pricingProfileId,
                baseProfileId: baseProfileId
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.unlinkBaseProfileQueryUriFormat, false)(argsToUri);
            var urlSegmentWithApiVersion = uriSegment + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "PUT");
            var notificationSettings = {
                success: {
                    title: "Successfully unlinked Base Profile",
                    description: "Success"
                },
                inProgress: {
                    title: "Unlinking Base Profile...",
                    description: "..."
                },
                error: {
                    title: "Failure unlinking Base Profile",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Base Profile Mapping");
            return promise.then(function () {
                return _this.mappedProfilesQuery.refreshAll();
            });
        };
        PricingProfilesDataManager.prototype.updateProfileDetailsQuery = function (subscriptionId, location, pricingProfileId, pricingData) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location,
                pricingProfileId: pricingProfileId,
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateProfileDetailsQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(pricingData);
            var promise = Helpers.callArm(uriSegment, "PUT", billingRpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Pricing Profile",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Pricing Profile...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Pricing Profile",
                    description: "Error!"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Pricing Profile");
            return promise.then(function () {
                _this.pricingProfileEntity.refreshAll();
                _this.pricingProfilesQuery.refreshAll();
            });
        };
        PricingProfilesDataManager.prototype.clonePricingProfile = function (subscriptionId, locationName, pricingProfileId) {
            var _this = this;
            var uri = MsPortalFx.Data.uriFormatter(this.cloneProfileEntityUriFormat, false)({
                subscriptionId: subscriptionId,
                locationName: locationName,
                pricingProfileId: pricingProfileId
            });
            var urlSegmentWithApiVersion = uri + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            var notificationSettings = {
                success: {
                    title: "Successfully cloned the pricing profile",
                    description: "Success"
                },
                inProgress: {
                    title: "Cloning pricing profile",
                    description: "..."
                },
                error: {
                    title: "Failure cloning pricing profile",
                    description: "Failure"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Pricing Profile");
            return promise.then(function () {
                return _this.pricingProfilesQuery.refreshAll();
            });
        };
        PricingProfilesDataManager.prototype.updateMeteredResources = function (subscriptionId, location, pricingProfileId, meteredResourcesList) {
            var updateMrpUri = MsPortalFx.Data.uriFormatter(this.UpdateMeteredResourcesUriFormat, false)({
                subscriptionId: subscriptionId,
                location: location,
                pricingProfileId: pricingProfileId,
            });
            var postData = ko.toJSON(meteredResourcesList);
            var promise = Helpers.callArm(updateMrpUri, "POST", billingRpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Metered Resources",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Metered Resources...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Metered Resources",
                    description: "Error!"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Metered Resource");
            return promise;
        };
        PricingProfilesDataManager.prototype.getAvailableIsoCurrencyList = function (subscriptionId, locationName) {
            var uri = MsPortalFx.Data.uriFormatter(this.getAvailableIsoCurrencyListQueryUriFormat, false)({
                subscriptionId: subscriptionId,
                location: locationName
            });
            var urlSegmentWithApiVersion = uri + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return promise;
        };
        PricingProfilesDataManager.prototype.getAvailablePricingProfilesDict = function (subscriptionId, locationName) {
            var uri = MsPortalFx.Data.uriFormatter(this.getPricingProfilesToServiceTypeDictUriFormat, false)({
                subscriptionId: subscriptionId,
                location: locationName
            });
            var urlSegmentWithApiVersion = uri + "?api-version=" + billingRpApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return promise;
        };
        return PricingProfilesDataManager;
    }());
    exports.PricingProfilesDataManager = PricingProfilesDataManager;
});
