define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    var DataModels = BillingExtension.DataModels;
    var ArmHelpers = Common.Helpers;
    var fxEnv = window.fx.environment;
    var rpApiVersion = window.fx.environment.billingRpApiVersion;
    "use strict";
    var SettingsDataManager = (function () {
        function SettingsDataManager() {
            this.settingsGroupQueryUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/adminSettingsGroup", fxEnv.billingRpApiVersion);
            this.updateProductFeaturesSettingsQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/updateProductFeaturesSettings";
            this.updateInvoicePdfSettingsQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/updateInvoicePdfSettings";
            this.updateCspSettingsQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/updateCspSettings";
            this.updateEmailNotificationSettingsQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/updateEmailNotificationSettings";
            this.updateStripeSettingsQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/updateStripeSettings";
            this.updateAzureStackUsageCollectorSettingsQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/updateAzureStackUsageCollectorSettings";
            this.updateDomainUserSettingsQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/updateDomainUserSettings";
            this.updateMiscSettingsQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{location}/updateMiscSettings";
            this.settingsGroupQuery = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.AdminSettingsGroupModelType,
                sourceUri: this.settingsGroupQueryUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
        }
        SettingsDataManager.prototype.updateProductFeaturesSettingsQuery = function (subscriptionId, location, productFeaturesSettings) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateProductFeaturesSettingsQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(productFeaturesSettings);
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Product Features Settings",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Product Features Settings...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Product Features Settings",
                    description: "Error: {errorMsg}"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Product Features Settings");
            return promise.then(function () {
                return _this.settingsGroupQuery.refreshAll();
            });
        };
        SettingsDataManager.prototype.updateInvoicePdfSettingsQuery = function (subscriptionId, location, invoiceSettings) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateInvoicePdfSettingsQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(invoiceSettings);
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Invoice Settings",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Invoice Settings...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Invoice Settings",
                    description: "Error: {errorMsg}"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Invoice Settings");
            return promise.then(function () {
                return _this.settingsGroupQuery.refreshAll();
            });
        };
        SettingsDataManager.prototype.updateCspSettingsQuery = function (subscriptionId, location, cspSettings) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateCspSettingsQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(cspSettings);
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated CSP Settings",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating CSP Settings...",
                    description: "..."
                },
                error: {
                    title: "Failure updating CSP Settings",
                    description: "Error: {errorMsg}"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "CSP Settings");
            return promise.then(function () {
                return _this.settingsGroupQuery.refreshAll();
            });
        };
        SettingsDataManager.prototype.updateEmailNotificationSettingsQuery = function (subscriptionId, location, emailNotificationSettings) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateEmailNotificationSettingsQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(emailNotificationSettings);
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Email Notification Settings",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Email Notification Settings...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Email Notification Settings",
                    description: "Error: {errorMsg}"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Email Notification Settings");
            return promise.then(function () {
                return _this.settingsGroupQuery.refreshAll();
            });
        };
        SettingsDataManager.prototype.updateStripeSettingsQuery = function (subscriptionId, location, stripeSettings) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateStripeSettingsQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(stripeSettings);
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Stripe Settings",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Stripe Settings...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Stripe Settings",
                    description: "Error: {errorMsg}"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Stripe Settings");
            return promise.then(function () {
                return _this.settingsGroupQuery.refreshAll();
            });
        };
        SettingsDataManager.prototype.updateAzureStackUsageCollectorSettingsQuery = function (subscriptionId, location, azureStackUsageCollectorSettings) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateAzureStackUsageCollectorSettingsQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(azureStackUsageCollectorSettings);
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Azure Stack Usage Collector Settings",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Azure Stack Usage Collector Settings...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Azure Stack Usage Collector Settings",
                    description: "Error"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Azure Stack Usage Collector Settings");
            return promise.then(function () {
                return _this.settingsGroupQuery.refreshAll();
            });
        };
        SettingsDataManager.prototype.updateDomainUserSettingsQuery = function (subscriptionId, location, domainUserSettings) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateDomainUserSettingsQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(domainUserSettings);
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Domain User Settings",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Domain User Settings...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Domain User Settings",
                    description: "Error"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Domain User Settings");
            return promise.then(function () {
                return _this.settingsGroupQuery.refreshAll();
            });
        };
        SettingsDataManager.prototype.updateMiscSettingsQuery = function (subscriptionId, location, miscSettings) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                location: location
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateMiscSettingsQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(miscSettings);
            var promise = Helpers.callArm(uriSegment, "PUT", rpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated Misc Settings",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating Misc Settings...",
                    description: "..."
                },
                error: {
                    title: "Failure updating Misc Settings",
                    description: "Error"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "Misc Settings");
            return promise.then(function () {
                return _this.settingsGroupQuery.refreshAll();
            });
        };
        return SettingsDataManager;
    }());
    exports.SettingsDataManager = SettingsDataManager;
});
