define(["require", "exports"], function (require, exports) {
    "use strict";
    var ArmHelpers = Common.Helpers;
    "use strict";
    var SubscriptionsManager = (function () {
        function SubscriptionsManager() {
            this.adminSubscriptionsPromise = this.getSubscriptionsForRp('CloudAssert.Billing.Admin');
        }
        SubscriptionsManager.prototype.getSubscriptionsForRp = function (rpNamespace) {
            var deferred = Q.defer();
            var subscriptionsResult = [];
            MsPortalFx.Azure.getAllSubscriptions().then(function (subscriptions) {
                var promises = [];
                subscriptions.forEach(function (subscription) {
                    var urlSegment = MsPortalFx.Data.uriFormatter('subscriptions/{subscriptionId}/providers', false)({
                        subscriptionId: subscription.subscriptionId,
                    });
                    var urlSegmentWithApiVersion = urlSegment + "?api-version=" + window.fx.environment.armApiVersion;
                    var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET").then(function (providersResponse) {
                        var providers = providersResponse.value;
                        var billingRp = providers.first(function (p) { return p.namespace === rpNamespace; });
                        if (billingRp && billingRp.registrationState === "Registered") {
                            subscriptionsResult.push(subscription);
                        }
                    });
                    promises.push(promise);
                });
                return Q.all(promises).then(function () {
                    deferred.resolve(subscriptionsResult);
                }, function (reason) {
                    deferred.reject(reason);
                });
            });
            return deferred.promise;
        };
        SubscriptionsManager.prototype.getRpManifests = function (adminSubscriptionId) {
            var uriFormat = 'subscriptions/{subscriptionId}/providers/Microsoft.Subscriptions.Providers/manifests';
            var urlSegment = MsPortalFx.Data.uriFormatter(uriFormat, false)({
                subscriptionId: adminSubscriptionId,
            });
            var urlSegmentWithApiVersion = urlSegment + "?api-version=" + window.fx.environment.armApiVersion;
            var promise = ArmHelpers.callArmUri(urlSegmentWithApiVersion, "GET");
            return promise;
        };
        SubscriptionsManager.prototype.getRpManifestForNamespace = function (adminSubscriptionId, rpNamespace) {
            var deferred = Q.defer();
            var promise = this.getRpManifests(adminSubscriptionId).then(function (manifestsResponse) {
                var manifestDefs = manifestsResponse.value;
                var billingRpAdminManifest = manifestDefs.first(function (p) { return p.properties && p.properties.namespace === rpNamespace; });
                if (billingRpAdminManifest) {
                    deferred.resolve(billingRpAdminManifest);
                }
                else {
                    deferred.reject('Manifest not found');
                }
            }, function (reason) {
                deferred.reject(reason);
            });
            return deferred.promise;
        };
        return SubscriptionsManager;
    }());
    exports.SubscriptionsManager = SubscriptionsManager;
});
