define(["require", "exports", "../Helpers"], function (require, exports, Helpers) {
    "use strict";
    var DataModels = BillingExtension.DataModels;
    var ArmHelpers = Common.Helpers;
    var fxEnv = window.fx.environment;
    var billingRpApiVersion = fxEnv.billingRpApiVersion;
    "use strict";
    var UserCreditsDataManager = (function () {
        function UserCreditsDataManager() {
            this.updateUserCreditsQueryUriFormat = "/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{locationName}/userCredits/UpdateUserCredits";
            this.userCreditEntityUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{locationName}/usercredits/{userId}/currencySymbol/{isoCurrencySymbol}/ListUserCredits", billingRpApiVersion);
            this.listUserCreditsQueryUriFormat = ArmHelpers.getArmUriFormatter("/subscriptions/{subscriptionId}/providers/CloudAssert.Billing.Admin/locations/{locationName}/userCredits", billingRpApiVersion);
            this.userCreditEntity = new MsPortalFx.Data.EntityCache({
                entityTypeName: DataModels.UserCreditModelType,
                sourceUri: this.userCreditEntityUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                poll: false
            });
            this.listUserCreditsQuery = new MsPortalFx.Data.QueryCache({
                entityTypeName: DataModels.UserCreditModelType,
                sourceUri: this.listUserCreditsQueryUriFormat,
                supplyData: ArmHelpers.getArmDataSupplier(),
                processServerResponse: function (data) { return { data: data }; },
                poll: false
            });
        }
        UserCreditsDataManager.prototype.updateUserCreditsQuery = function (subscriptionId, location, UserCreditsIn) {
            var _this = this;
            var argsToUri = {
                subscriptionId: subscriptionId,
                locationName: location,
            };
            var uriSegment = MsPortalFx.Data.uriFormatter(this.updateUserCreditsQueryUriFormat, false)(argsToUri);
            var postData = ko.toJSON(UserCreditsIn);
            var promise = Helpers.callArm(uriSegment, "PUT", billingRpApiVersion, postData);
            var notificationSettings = {
                success: {
                    title: "Successfully updated User Credits",
                    description: "Success"
                },
                inProgress: {
                    title: "Updating User Credits...",
                    description: "..."
                },
                error: {
                    title: "Failure updating User Credits",
                    description: "Request Failed"
                }
            };
            Helpers.trackOperation(promise, notificationSettings, "User Credits");
            return promise.then(function () {
                return _this.listUserCreditsQuery.refreshAll();
            });
        };
        return UserCreditsDataManager;
    }());
    exports.UserCreditsDataManager = UserCreditsDataManager;
});
