define(["require", "exports"], function (require, exports) {
    "use strict";
    function getArmUriFormatter(format, apiVersion) {
        if (format === void 0) { format = "{id}"; }
        var armEndpointUri = window.fx.environment.armEndpointUri;
        var uriFormat = "{0}{1}?api-version={2}".format(armEndpointUri, format, apiVersion);
        return MsPortalFx.Data.uriFormatter(uriFormat, false);
    }
    exports.getArmUriFormatter = getArmUriFormatter;
    function getArmDataSupplier(getBody) {
        return function (httpMethod, uri, headers, data, params) {
            return MsPortalFx.Base.Net.ajax({
                uri: uri,
                type: httpMethod,
                dataType: "json",
                contentType: "application/json",
                data: params && getBody ? getBody(params) : undefined,
                setAuthorizationHeader: true
            });
        };
    }
    exports.getArmDataSupplier = getArmDataSupplier;
    function callArm(uri, httpMethod, apiVersion, data) {
        if (httpMethod === void 0) { httpMethod = "GET"; }
        return MsPortalFx.Base.Net.ajax({
            uri: getArmUriFormatter("{id}", apiVersion)(uri),
            type: httpMethod,
            contentType: "application/json",
            data: data,
            setAuthorizationHeader: true
        });
    }
    exports.callArm = callArm;
    function getArmProxyUri(uri, proxyAction, queryParams) {
        if (proxyAction != null && proxyAction.length > 0) {
            uri = uri + "/" + proxyAction;
        }
        var proxyUrl = getArmUriFormatter("{id}", "2015-11-01")(uri);
        if (queryParams != null && queryParams.length > 0) {
            proxyUrl = proxyUrl + "&" + queryParams;
        }
        return proxyUrl;
    }
    exports.getArmProxyUri = getArmProxyUri;
    function callArmProxy(uri, proxyAction, httpMethod, data, queryParams) {
        if (httpMethod === void 0) { httpMethod = "GET"; }
        var callUrl = getArmProxyUri(uri, proxyAction, queryParams);
        return MsPortalFx.Base.Net.ajax({
            uri: callUrl,
            type: httpMethod,
            contentType: "application/json",
            data: data,
            setAuthorizationHeader: true
        });
    }
    exports.callArmProxy = callArmProxy;
    function callExtensionController(uri, httpMethod, data, queryParams) {
        if (httpMethod === void 0) { httpMethod = "GET"; }
        var fullUri = uri;
        if (queryParams != null && queryParams.length > 0) {
            fullUri = fullUri + "?" + queryParams;
        }
        return MsPortalFx.Base.Net.ajax({
            uri: fullUri,
            type: httpMethod,
            contentType: "application/json",
            data: data,
            setAuthorizationHeader: true
        });
    }
    exports.callExtensionController = callExtensionController;
    function getSubscriptionDetails(subscriptionId) {
        var uri = "{0}/subscriptions/{1}?api-version={2}&includeDetails=true"
            .format(window.fx.environment.armEndpointUri, subscriptionId, "2015-01-01");
        return MsPortalFx.Base.Net.ajax({
            uri: uri,
            type: "GET",
            contentType: "application/json",
            setAuthorizationHeader: true
        });
    }
    exports.getSubscriptionDetails = getSubscriptionDetails;
    function getProviders(subscriptionId) {
        return MsPortalFx.Base.Net.ajax({
            uri: "{0}/subscriptions/{1}/providers?api-version={2}".format(window.fx.environment.armEndpointUri, subscriptionId, "2015-01-01"),
            type: "GET",
            contentType: "application/json",
            setAuthorizationHeader: true
        });
    }
    exports.getProviders = getProviders;
    function getArmLocation(subscriptionId) {
        return getProviders(subscriptionId).then(function (providers) {
            return providers.value.first(function (provider) { return provider.namespace === "Microsoft.Resources"; }).resourceTypes.first(function (resourceType) { return resourceType.resourceType === "resourceGroups"; }).locations.first();
        });
    }
    exports.getArmLocation = getArmLocation;
    function getPaymentType(paymentType) {
        if (paymentType === "true") {
            return "Offline";
        }
        return "Credit Card";
    }
    exports.getPaymentType = getPaymentType;
    function trackOperation(operationPromise, settings, resourceName) {
        var formatArgs = {
            resourceName: resourceName
        };
        var notification = new MsPortalFx.Hubs.Notifications.ClientNotification({
            title: settings.inProgress.title.format(formatArgs),
            description: settings.inProgress.title.format(formatArgs),
            status: MsPortalFx.Hubs.Notifications.NotificationStatus.InProgress
        });
        notification.publish();
        operationPromise
            .done(function () {
            notification.title = settings.success.title.format(formatArgs);
            notification.description = settings.success.description.format(formatArgs);
            notification.status = MsPortalFx.Hubs.Notifications.NotificationStatus.Success;
            notification.publish();
        })
            .progress(function () {
            notification.title = settings.inProgress.title.format(formatArgs);
            notification.description = settings.inProgress.description.format(formatArgs);
            notification.status = MsPortalFx.Hubs.Notifications.NotificationStatus.InProgress;
            notification.publish();
        })
            .fail(function (data) {
            var errorMsg = data.responseJSON && data.responseJSON.error && data.responseJSON.error.message
                ? data.responseJSON.error.message
                : data.responseJSON;
            errorMsg = (typeof errorMsg === "object") ? errorMsg.Message : errorMsg;
            notification.title = settings.error.title.format(formatArgs);
            notification.description = settings.error.description.format({ resourceName: resourceName, errorMsg: errorMsg });
            notification.status = MsPortalFx.Hubs.Notifications.NotificationStatus.Error;
            notification.publish();
        });
    }
    exports.trackOperation = trackOperation;
    function makeObservable(obj) {
        if (typeof obj !== "object") {
            throw "makeObservable: Not an object";
        }
        for (var property in obj) {
            var val = obj[property];
            if (Array.isArray(val)) {
                makeObservable(val);
                obj[property] = ko.observableArray(val);
            }
            else {
                var typeofVal = typeof val;
                if (typeofVal === "object") {
                    makeObservable(val);
                }
                else if (typeofVal !== "function") {
                    obj[property] = ko.observable(val);
                }
            }
        }
        return ko.observable(obj);
    }
    exports.makeObservable = makeObservable;
    function getTimeFormat(IsUseUtcTimeZone, IsUse24HrTimeFormat, IsTimeOnly) {
        if (IsTimeOnly === void 0) { IsTimeOnly = false; }
        var dateFormat;
        dateFormat = {
            hour: "numeric",
            minute: "numeric",
            second: "numeric",
            hour12: !IsUse24HrTimeFormat,
        };
        if (!IsTimeOnly) {
            dateFormat.year = "numeric";
            dateFormat.month = "numeric";
            dateFormat.day = "numeric";
        }
        if (IsUseUtcTimeZone) {
            dateFormat.timeZone = "UTC";
        }
        return dateFormat;
    }
    exports.getTimeFormat = getTimeFormat;
    function getGridNameActivatableTemplate() {
        return "<div>" +
            "<span style='text-decoration: underline' data-bind='text: value'></span" +
            "</div>";
        ;
    }
    exports.getGridNameActivatableTemplate = getGridNameActivatableTemplate;
});
