define(["require", "exports"], function (require, exports) {
    "use strict";
    var FxViewModels = MsPortalFx.ViewModels;
    var FxFileUpload = FxViewModels.FileUpload;
    var StreamUploader = (function () {
        function StreamUploader(lifetime, uploadTask, showUploadContent, streamingUploadContent, callback) {
            var _this = this;
            this._lifetime = lifetime;
            this._uploadTask = uploadTask;
            this._showUploadContent = showUploadContent;
            this._streamingUploadContent = streamingUploadContent;
            this._onReadCallback = callback;
            uploadTask.uploadInfo.status.subscribe(this._lifetime, function (status) {
                _this._handleUploadStatusUpdates();
            });
        }
        StreamUploader.prototype.start = function (resumeContext) {
            var status = this._uploadTask.uploadInfo.status();
            if (status === 1 || status === 3) {
                return this._uploadTask.resume(resumeContext);
            }
            Q.reject("asyncFileUploadUnexpectedState");
        };
        StreamUploader.prototype.upload = function () {
            if (this._uploadTask.uploadInfo.status() === 2) {
                this._processChunk();
            }
        };
        StreamUploader.prototype._handleUploadStatusUpdates = function () {
            switch (this._uploadTask.uploadInfo.status()) {
                case 1:
                    break;
                case 3:
                    break;
                case 2:
                    this._processChunk();
                    break;
                case 0:
                case 5:
                case 6:
                case 4:
                    break;
            }
        };
        StreamUploader.prototype._processChunk = function () {
            var _this = this;
            this._uploadTask.getNextChunk().then(function (result) {
                _this._ajaxSend(result).then(function () {
                    if (result.endByte !== _this._uploadTask.uploadInfo.size) {
                        _this._processChunk();
                    }
                    else {
                        _this._uploadTask.complete();
                    }
                });
            }, function () {
            });
        };
        StreamUploader.prototype._ajaxSend = function (result) {
            var _this = this;
            switch (result.contentType) {
                case 1:
                case 3:
                    this._updateStreamingContent(result.content);
                    break;
                case 0:
                case 2:
                default:
                    var reader = new FileReader();
                    reader.onload = function (event) {
                        _this._updateStreamingContent((event.target).result);
                    };
                    reader.readAsText(new Blob([result.content], { type: "application/octet-stream" }));
                    break;
            }
            return Q();
        };
        StreamUploader.prototype._updateStreamingContent = function (fileData) {
            if (this._showUploadContent() && this._streamingUploadContent) {
                this._streamingUploadContent.value(fileData);
            }
            this._onReadCallback(fileData);
        };
        return StreamUploader;
    }());
    exports.StreamUploader = StreamUploader;
});
