var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports"], function (require, exports) {
    "use strict";
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var FxDropDown = MsPortalFx.ViewModels.Obsolete.Forms.DropDown;
    var FxControls = MsPortalFx.ViewModels.Controls;
    var FileDownload = MsPortalFx.ViewModels.Controls.FileDownload;
    var FileDownloadButton = MsPortalFx.ViewModels.Controls.FileDownloadButton;
    "use strict";
    var UsageAndQuotaSnapInBladeViewModel = (function (_super) {
        __extends(UsageAndQuotaSnapInBladeViewModel, _super);
        function UsageAndQuotaSnapInBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionIdIn = ko.observable();
            this.subscriptionIdList = ko.observableArray([]);
            this.periodList = ko.observableArray([]);
            this.usersList = ko.observableArray([]);
            this.allProviderList = ko.observableArray([]);
            this.allResourceList = ko.observableArray([]);
            this.selectedPeriod = ko.observable();
            this.selectedProvider = ko.observable();
            this.selectedResource = ko.observable();
            this.selectedSubscriptionId = ko.observable("local");
            this.selectedUser = ko.observable("");
            this.totalBillableCost = ko.observable(0);
            this.downloadUri = ko.observable();
            this.inputData = ko.observable();
            this.billingIcon = MsPortalFx.Base.Images.Polychromatic.BillingHub();
            this.title = ko.observable("Monthly Summary");
            this.icon = ko.observable(MsPortalFx.Base.Images.Clock());
            this._container = container;
            this._dataContext = dataContext;
            this._initFiltersAndButtonsSection(container);
            var gridExtensions = FxGridExtensions.Filterable | FxGridExtensions.SortableColumn | FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                filterable: {
                    searchBoxCloseButtonVisible: ko.observable(false),
                    searchBoxPlaceholder: ko.observable("Search to filter items..."),
                    searchBoxVisible: ko.observable(true),
                    searchableColumns: ko.observableArray(["QuotaResourceDisplayName", "QuotaProvider", "ConsumptionPercentage"])
                },
                selectableRow: {
                    selectionMode: 1
                }
            };
            this.quotaUsageGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "QuotaResourceDisplayName",
                    name: ko.observable("Quota Resource"),
                    activatable: ko.observable(false)
                },
                {
                    itemKey: "QuotaProvider",
                    name: ko.observable("Provider"),
                    activatable: ko.observable(true)
                },
                {
                    itemKey: "ConsumptionPercentage",
                    name: ko.observable("Consumption Percentage"),
                    format: FxGrid.Format.PercentageBar,
                    formatOptions: {
                        percentageBar: {
                            barColorKey: "i0t1",
                            backgroundColor: "paletteLightGray",
                            textLocation: 1
                        },
                    }
                },
                {
                    itemKey: "QuotaUsageString",
                    name: ko.observable("Quota Usage"),
                },
            ];
            this.quotaUsageGrid.columns = ko.observableArray(basicColumns);
            this.quotaUsageGrid.showHeader = true;
            this.quotaUsageGrid.summary = ko.observable("Summary");
            this.quotaUsageGrid.noRowsMessage("No items found");
            this.quotaUsageGrid.selectableData.selectableItems.subscribe(container, function () {
                _this.downloadAzSQuotaSummaryButton = _this._createDownloadButtonViewModel();
            });
        }
        UsageAndQuotaSnapInBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            var _this = this;
            this.subscriptionIdIn(inputs.subscriptionId);
            var q1 = this._dataContext.usageAndQuotaDataManager.getAzSQuotaFilters(this.subscriptionIdIn()).then(function (filters) {
                var resourceList = [];
                var providers = Object.keys(filters.ResourcesDict);
                _this.allProviderList(providers);
                var providerDropdownValues = providers.map(function (provider) {
                    return {
                        text: ko.observable(provider),
                        value: provider,
                        disabled: ko.observable(false)
                    };
                });
                providerDropdownValues.unshift({
                    text: ko.observable("All Providers"),
                    value: "-1",
                    disabled: ko.observable(false)
                });
                _this.providerDropDown.options(providerDropdownValues);
                _this.providerDropDown.value("-1");
                _this.providerDropDown.disabled(false);
                Object.keys(filters.ResourcesDict).forEach(function (key) {
                    resourceList = resourceList.concat(filters.ResourcesDict[key]);
                });
                _this.allResourceList(resourceList);
                var resourcesDropdownValues = resourceList.map(function (resource) {
                    return {
                        text: ko.observable(resource),
                        value: resource,
                        disabled: ko.observable(false)
                    };
                });
                resourcesDropdownValues.unshift({
                    text: ko.observable("All Quota Resources"),
                    value: "-1",
                    disabled: ko.observable(false)
                });
                _this.resourcesDropDown.options(resourcesDropdownValues);
                _this.resourcesDropDown.value("-1");
                _this.resourcesDropDown.disabled(false);
                var periodDropdownValues = filters.BillingCyclePeriods.map(function (period) {
                    _this.periodList.push(period);
                    return {
                        text: ko.observable(period.Label),
                        value: period,
                        disabled: ko.observable(false)
                    };
                });
                periodDropdownValues.unshift({
                    text: ko.observable("Please select a period..."),
                    value: null,
                    disabled: ko.observable(false)
                });
                _this.periodDropDown.options(periodDropdownValues);
                _this.periodDropDown.value(filters.BillingCyclePeriods.first(function (p) { return p.IsCurrent; }));
                _this.periodDropDown.disabled(false);
                var usersDropdownValues = filters.Users.map(function (user) {
                    _this.usersList.push(user);
                    return {
                        text: ko.observable(user),
                        value: user,
                        disabled: ko.observable(false)
                    };
                });
                usersDropdownValues.unshift({
                    text: ko.observable("Please select a user..."),
                    value: null,
                    disabled: ko.observable(false)
                });
                _this.usersDropDown.options(usersDropdownValues);
                var currentUserId = filters.Users.first();
                _this.usersDropDown.value(currentUserId);
                _this.usersDropDown.disabled(false);
                _this.subscriptionIdList(Object.keys(filters.SubscriptionsDict));
                var subscriptionDropdownValues = _this.subscriptionIdList().map(function (id) {
                    return {
                        text: ko.observable(filters.SubscriptionsDict[id]),
                        value: id,
                        disabled: ko.observable(false)
                    };
                });
                subscriptionDropdownValues.unshift({
                    text: ko.observable("Please select a subscription..."),
                    value: null,
                    disabled: ko.observable(false)
                });
                _this.subscriptionsDropDown.options(subscriptionDropdownValues);
                _this.subscriptionsDropDown.value(_this.subscriptionIdList().first());
                _this.subscriptionsDropDown.disabled(false);
            });
            return Q.all([q1]).then(function () {
                _this._onApplyButtonClicked();
            });
        };
        UsageAndQuotaSnapInBladeViewModel.prototype._initFiltersAndButtonsSection = function (container) {
            var _this = this;
            var userDropDownOptions = {
                label: ko.observable("User"),
                labelPosition: ko.observable(FxForms.LabelPosition.Left),
                infoBalloonContent: ko.observable("Choose a user"),
                options: ko.observableArray([{ text: ko.observable("Loading.."), value: "" }])
            };
            this.usersDropDown = new FxDropDown.ViewModel(container, userDropDownOptions);
            this.usersDropDown.value.subscribe(container, function (newUser) {
                _this.selectedUser(newUser);
                _this._dataContext.usageAndQuotaDataManager.getSubscriptionsForUser(_this.subscriptionIdIn(), newUser)
                    .then(function (subDict) {
                    _this.subscriptionIdList(Object.keys(subDict));
                    var subscriptionDropdownValues = _this.subscriptionIdList().map(function (id) {
                        return {
                            text: ko.observable(subDict[id]),
                            value: id,
                            disabled: ko.observable(false)
                        };
                    });
                    subscriptionDropdownValues.unshift({
                        text: ko.observable("Please select a subscription..."),
                        value: null,
                        disabled: ko.observable(false)
                    });
                    _this.subscriptionsDropDown.options(subscriptionDropdownValues);
                    _this.subscriptionsDropDown.value(_this.subscriptionIdList().first());
                    _this.subscriptionsDropDown.disabled(false);
                });
            });
            var subscriptionDropDownOptions = {
                label: ko.observable("Subscription"),
                labelPosition: ko.observable(FxForms.LabelPosition.Left),
                infoBalloonContent: ko.observable("Choose a Subscription"),
                options: ko.observableArray([{ text: ko.observable("Loading.."), value: "" }])
            };
            this.subscriptionsDropDown = new FxDropDown.ViewModel(container, subscriptionDropDownOptions);
            this.subscriptionsDropDown.value.subscribe(container, function (newSubscriptionId) {
                _this.selectedSubscriptionId(newSubscriptionId);
            });
            var quotaResourceDropDownOptions = {
                label: ko.observable("Quota Resource"),
                labelPosition: ko.observable(FxForms.LabelPosition.Left),
                infoBalloonContent: ko.observable("Choose the Resource"),
                options: ko.observableArray([{ text: ko.observable("Loading.."), value: "" }])
            };
            this.resourcesDropDown = new FxDropDown.ViewModel(container, quotaResourceDropDownOptions);
            this.resourcesDropDown.value.subscribe(container, function (resource) {
                _this.selectedResource(resource);
            });
            var quotaProviderDropDownOptions = {
                label: ko.observable("Quota Provider"),
                labelPosition: ko.observable(FxForms.LabelPosition.Left),
                infoBalloonContent: ko.observable("Choose a Provider"),
                options: ko.observableArray([{ text: ko.observable("Loading.."), value: "" }])
            };
            this.providerDropDown = new FxDropDown.ViewModel(container, quotaProviderDropDownOptions);
            this.providerDropDown.value.subscribe(container, function (resource) {
                _this.selectedProvider(resource);
            });
            var periodDropDownOptions = {
                label: ko.observable("Period"),
                labelPosition: ko.observable(FxForms.LabelPosition.Left),
                infoBalloonContent: ko.observable("Choose a Period"),
                options: ko.observableArray([{ text: ko.observable("Loading.."), value: "" }])
            };
            this.periodDropDown = new FxDropDown.ViewModel(container, periodDropDownOptions);
            this.periodDropDown.value.subscribe(container, function (period) {
                _this.selectedPeriod(period);
            });
            this.applyFiltersButton = new FxControls.SimpleButton.ViewModel(container, {
                onClick: this._onApplyButtonClicked.bind(this),
                text: "Apply",
                primary: true,
            });
            this.downloadAzSQuotaSummaryButton = this._createDownloadButtonViewModel();
            var column1 = new MsPortalFx.ViewModels.Forms.Section.ViewModel(container, {
                style: ko.observable(0),
                children: ko.observableArray([
                    this.periodDropDown,
                    this.providerDropDown,
                ])
            });
            var column2 = new MsPortalFx.ViewModels.Forms.Section.ViewModel(container, {
                style: ko.observable(0),
                children: ko.observableArray([
                    this.usersDropDown,
                    this.resourcesDropDown,
                ])
            });
            var column3 = new MsPortalFx.ViewModels.Forms.Section.ViewModel(container, {
                style: ko.observable(0),
                children: ko.observableArray([
                    this.subscriptionsDropDown,
                ])
            });
            this.filtersSection = new MsPortalFx.ViewModels.Forms.Section.ViewModel(container, {
                style: ko.observable(3),
                children: ko.observableArray([
                    column1, column2, column3
                ])
            });
        };
        UsageAndQuotaSnapInBladeViewModel.prototype._onApplyButtonClicked = function () {
            var _this = this;
            this.quotaUsageGrid.loading(true);
            var subId = this.selectedSubscriptionId();
            var input = this._getInputParameter(subId);
            this._dataContext.usageAndQuotaDataManager.getAzSSnapInView(this.subscriptionIdIn(), input).then(function (quotaRecords) {
                if (quotaRecords.length > 0) {
                    _this.quotaUsageGrid.items(quotaRecords.first().AzureStackQuotaResources);
                    _this.quotaUsageGrid.loading(false);
                }
            });
        };
        UsageAndQuotaSnapInBladeViewModel.prototype._getInputParameter = function (subId) {
            var provider = [];
            var resource = [];
            var subIdList = [];
            if (this.selectedPeriod() == undefined) {
                this.selectedPeriod(this.periodList().first());
            }
            if (this.selectedProvider() == "-1") {
                provider = this.allProviderList();
            }
            else {
                provider.push(this.selectedProvider());
            }
            if (this.selectedResource() == "-1") {
                resource = this.allResourceList();
            }
            else {
                resource.push(this.selectedResource());
            }
            subIdList.push(subId);
            var input = {
                SubscriptionIds: subIdList,
                QuotaProviderList: provider,
                QuotaResourceNames: resource,
                QuotaPeriod: { StartDate: this.selectedPeriod().StartDate, EndDate: this.selectedPeriod().EndDate, IsCurrent: this.selectedPeriod().IsCurrent },
            };
            return input;
        };
        UsageAndQuotaSnapInBladeViewModel.prototype._createDownloadButtonViewModel = function () {
            var subId = this.selectedSubscriptionId();
            var input;
            if (this.selectedPeriod() != undefined) {
                input = this._getInputParameter(subId);
            }
            var postData = ko.toJSON(input);
            this.inputData(postData);
            var args = {
                subscriptionId: this.subscriptionIdIn(),
                location: "local",
            };
            this.downloadUri(this._dataContext.usageAndQuotaDataManager.downloadAzSQuotaSummaryUri(args));
            var azsQuotaSummaryDownloadContext = new FileDownload.Context({
                targetUri: this.downloadUri,
                httpMethod: ko.observable("POST"),
                httpRequestContent: this.inputData,
                httpRequestContentType: ko.observable("application/json"),
                downloadType: ko.observable(2),
                addDefaultAuthorizationToken: true,
                showDownloadProgressDialog: ko.observable(true)
            });
            var downloadButtonViewModel = new FileDownloadButton.ViewModel(this._container, {
                context: ko.observable(azsQuotaSummaryDownloadContext),
                label: ko.observable("Download"),
                disabled: ko.observable(false),
            });
            return downloadButtonViewModel;
        };
        return UsageAndQuotaSnapInBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.UsageAndQuotaSnapInBladeViewModel = UsageAndQuotaSnapInBladeViewModel;
});
