var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports"], function (require, exports) {
    "use strict";
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var FxDropDown = MsPortalFx.ViewModels.Obsolete.Forms.DropDown;
    var UsageHistoryGridBladeViewModel = (function (_super) {
        __extends(UsageHistoryGridBladeViewModel, _super);
        function UsageHistoryGridBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.subscriptionId = ko.observable();
            this.location = ko.observable();
            this.selectedUsageHistory = ko.pureComputed(function () {
                return _this.usageHistoryGrid.selectableData.selectedItems().first();
            });
            this.selectedBillingPeriod = ko.observable();
            this.title("Usage History");
            this._container = container;
            this._dataContext = dataContext;
            this._dataQueryView = dataContext.usageHistoryManager.usageHistoryQuery.createView(container, {
                interceptNotFound: false
            });
            var billingPeriodDropDownOptions = {
                label: ko.observable("Billing Period"),
                labelPosition: ko.observable(FxForms.LabelPosition.Left),
                infoBalloonContent: ko.observable("Choose the Billing Period to list Subscription Summary"),
                options: ko.observableArray([{ text: ko.observable("Loading.."), value: "" }])
            };
            this.billingPeriodsDropDown = new FxDropDown.ViewModel(container, billingPeriodDropDownOptions);
            this.billingPeriodsDropDown.value.subscribe(container, function (newPeriod) {
                _this.selectedBillingPeriod(newPeriod);
            });
            this.formSection = new FxForms.Section.ViewModel(container, {
                style: ko.observable(3),
                children: ko.observableArray([
                    this.billingPeriodsDropDown
                ])
            });
            var gridExtensions = FxGridExtensions.Filterable | FxGridExtensions.SortableColumn | FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                filterable: {
                    searchBoxCloseButtonVisible: ko.observable(false),
                    searchBoxPlaceholder: ko.observable("Search to filter items..."),
                    searchBoxVisible: ko.observable(true),
                    searchableColumns: ko.observableArray(["UserId", "SubscriptionId", "SubscriptionName"])
                },
                selectableRow: {
                    selectionMode: 1
                }
            };
            this.usageHistoryGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "UserId",
                    name: ko.observable("User Id"),
                },
                {
                    itemKey: "SubscriptionId",
                    name: ko.observable("Subscription Id"),
                },
                {
                    itemKey: "SubscriptionName",
                    name: ko.observable("Subscription Name")
                },
                {
                    itemKey: "TotalCostString",
                    name: ko.observable("Total Cost"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
                {
                    itemKey: "TotalIncludedOfferCreditsString",
                    name: ko.observable("Offer Credits"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
                {
                    itemKey: "TaxAmountString",
                    name: ko.observable("Tax Amount"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
                {
                    itemKey: "BillableCostString",
                    name: ko.observable("Billable Cost"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
                {
                    itemKey: "CreditBalance",
                    name: ko.observable("User Credits"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
                {
                    itemKey: "CurrentBillAmountString",
                    name: ko.observable("Bill Amount"),
                    cssClass: "ext-ca-billing-grid-col-align-right",
                },
            ];
            this.usageHistoryGrid.columns = ko.observableArray(basicColumns);
            this.usageHistoryGrid.showHeader = true;
            this.usageHistoryGrid.summary = ko.observable("Summary");
            this.usageHistoryGrid.noRowsMessage("No items found");
            this.billingPeriodsDropDown.value.subscribe(container, function (_selectedPeriod) {
                if (!_selectedPeriod) {
                    _this.usageHistoryGrid.items([]);
                    return;
                }
                _this._dataQueryView.fetch({
                    subscriptionId: _this.subscriptionId(),
                    location: _this.location(),
                    startDate: _selectedPeriod.StartDate,
                });
            });
            this.usageHistoryGrid.selectableData.selectedItems.subscribe(container, function (selectedItems) {
                if (!selectedItems || selectedItems.length === 0) {
                    return;
                }
                _this._downloadSelectedUsageButton.disabled(false);
            });
            this._dataQueryView.items.subscribe(container, function (usageHistory) {
                var transformedUsageHistory = usageHistory.map(function (c) {
                    return $.extend({}, c, {
                        CreditBalance: "{0} {1}".format(c.CurrencySymbol(), c.CreditBalance().toFixed(2))
                    });
                });
                _this.usageHistoryGrid.items(transformedUsageHistory);
            });
            this._dataQueryView.loading.subscribe(container, function (isLoading) {
                _this.usageHistoryGrid.loading(isLoading);
            });
            this._setupCommandBar();
        }
        UsageHistoryGridBladeViewModel.prototype._setupCommandBar = function () {
            this._downloadAllUsageButton = this._createDownloadAllUsageButton();
            this._downloadSelectedUsageButton = this._createDownloadSelectedUsageButton();
            this._exportGridButton = this._createExportGridButton();
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([
                this._downloadAllUsageButton,
                this._downloadSelectedUsageButton,
                this._exportGridButton,
            ]);
        };
        UsageHistoryGridBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            var _this = this;
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            return this._dataContext.sharedContext.billingOverviewManager.getBillingPeriods(inputs.subscriptionId, inputs.location).then(function (billingPeriods) {
                var billingPeriodDropdownValues = billingPeriods.map(function (bp) {
                    return {
                        text: ko.observable(bp.Label),
                        value: bp,
                        disabled: ko.observable(false),
                    };
                });
                billingPeriodDropdownValues.push({
                    text: ko.observable("Please select a Billing Period"),
                    value: null,
                    disabled: ko.observable(false)
                });
                _this.billingPeriodsDropDown.options(billingPeriodDropdownValues);
                var currentBP = billingPeriods.first(function (bp) { return bp.IsCurrent; });
                _this.billingPeriodsDropDown.value(currentBP);
                _this.billingPeriodsDropDown.disabled(false);
                _this._downloadSelectedUsageButton.disabled(true);
            });
        };
        UsageHistoryGridBladeViewModel.prototype._createDownloadAllUsageButton = function () {
            var _this = this;
            var downloadAllUsageButton = new MsPortalFx.ViewModels.Toolbars.FileDownloadButton({
                label: "Download All Usage",
                targetUriCallback: ko.observable(function () {
                    var args = _this._getDownloadCSVArgs({ _selectedSubscriptionId: _this.subscriptionId(), _isOverallUsage: false, _isOverallDetailedUsage: true });
                    var downloadUri = _this._dataContext.usageHistoryManager.downloadUsageQueryUriFormat(args);
                    return Q(downloadUri);
                }),
                addDefaultAuthorizationToken: true,
            });
            return downloadAllUsageButton;
        };
        UsageHistoryGridBladeViewModel.prototype._createDownloadSelectedUsageButton = function () {
            var _this = this;
            var downloadSelectedUsageButton = new MsPortalFx.ViewModels.Toolbars.FileDownloadButton({
                label: "Download Usage",
                targetUriCallback: ko.observable(function () {
                    var args = _this._getDownloadCSVArgs({ _selectedSubscriptionId: _this.selectedUsageHistory().SubscriptionId(), _isOverallUsage: false, _isOverallDetailedUsage: false });
                    var downloadUri = _this._dataContext.usageHistoryManager.downloadUsageQueryUriFormat(args);
                    return Q(downloadUri);
                }),
                addDefaultAuthorizationToken: true,
            });
            return downloadSelectedUsageButton;
        };
        UsageHistoryGridBladeViewModel.prototype._createExportGridButton = function () {
            var _this = this;
            var exportGridButton = new MsPortalFx.ViewModels.Toolbars.FileDownloadButton({
                label: "Export Grid",
                targetUriCallback: ko.observable(function () {
                    var args = _this._getDownloadCSVArgs({ _selectedSubscriptionId: _this.subscriptionId(), _isOverallUsage: true, _isOverallDetailedUsage: false });
                    var downloadUri = _this._dataContext.usageHistoryManager.downloadUsageQueryUriFormat(args);
                    return Q(downloadUri);
                }),
                addDefaultAuthorizationToken: true,
            });
            return exportGridButton;
        };
        UsageHistoryGridBladeViewModel.prototype._getDownloadCSVArgs = function (_a) {
            var _selectedSubscriptionId = _a._selectedSubscriptionId, _isOverallUsage = _a._isOverallUsage, _isOverallDetailedUsage = _a._isOverallDetailedUsage;
            return {
                subscriptionId: this.subscriptionId(),
                selectedSubscriptionId: _selectedSubscriptionId,
                location: this.location(),
                startDate: this.selectedBillingPeriod().StartDate,
                isOverallUsage: _isOverallUsage,
                isOverallDetailedUsage: _isOverallDetailedUsage,
            };
        };
        return UsageHistoryGridBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.UsageHistoryGridBladeViewModel = UsageHistoryGridBladeViewModel;
});
