var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "../../Shared/Helpers"], function (require, exports, Helpers) {
    "use strict";
    var FxForms = MsPortalFx.ViewModels.Forms;
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var ArmHelpers = Common.Helpers;
    var UserCreditsCollectionBladeViewModel = (function (_super) {
        __extends(UserCreditsCollectionBladeViewModel, _super);
        function UserCreditsCollectionBladeViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.adminSubscriptionId = ko.observable();
            this.location = ko.observable("local");
            this.selectedUserCredits = ko.pureComputed(function () {
                return _this.userCreditsGrid.selectableData.selectedItems().first();
            });
            this.title("User Credits");
            this._container = container;
            this._dataContext = dataContext;
            this._dataQueryView = dataContext.userCreditsManager.listUserCreditsQuery.createView(container, {
                interceptNotFound: false
            });
            this.formSection = new FxForms.Section.ViewModel(container, {
                style: ko.observable(3),
                children: ko.observableArray([])
            });
            var gridExtensions = FxGridExtensions.Filterable | FxGridExtensions.SortableColumn | FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                filterable: {
                    searchBoxCloseButtonVisible: ko.observable(false),
                    searchBoxPlaceholder: ko.observable("Search to filter items..."),
                    searchBoxVisible: ko.observable(true),
                    searchableColumns: ko.observableArray(["UserId", "ISOCurrencySymbol"])
                },
                selectableRow: {
                    selectionMode: 1,
                    activateOnSelected: ko.observable(false)
                }
            };
            this.userCreditsGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "UserId",
                    name: ko.observable("User Id"),
                    width: ko.observable("50px"),
                    activatable: ko.observable(true),
                    format: FxGrid.Format.HtmlBindings,
                    formatOptions: {
                        htmlBindingsTemplate: Helpers.getGridNameActivatableTemplate(),
                        htmlBindingsType: FxGrid.HtmlBindingsType.Default
                    }
                },
                {
                    itemKey: "ISOCurrencySymbol",
                    name: ko.observable("Currency"),
                    width: ko.observable("50px"),
                },
                {
                    itemKey: "CreditBalance",
                    name: ko.observable("Credits"),
                    width: ko.observable("50px"),
                },
                {
                    itemKey: "RemainingCredits",
                    name: ko.observable("Remaining User Credits"),
                    width: ko.observable("50px"),
                },
            ];
            this.userCreditsGrid.columns = ko.observableArray(basicColumns);
            this.userCreditsGrid.showHeader = true;
            this.userCreditsGrid.summary = ko.observable("Summary");
            this.userCreditsGrid.noRowsMessage("No items found");
            this._dataQueryView.items.subscribe(container, function (userCredits) {
                var transformedUserCredits = userCredits.map(function (c) {
                    return $.extend({}, c, {
                        CreditBalance: c.CreditBalance().toFixed(2),
                        RemainingCredits: c.RemainingCredits().toFixed(2)
                    });
                });
                _this.userCreditsGrid.items(transformedUserCredits);
            });
            this._dataQueryView.loading.subscribe(container, function (isLoading) {
                _this.userCreditsGrid.loading(isLoading);
            });
        }
        UserCreditsCollectionBladeViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.adminSubscriptionId(inputs.adminSubscriptionId);
            this.location(inputs.location);
            return this._dataQueryView.fetch({
                subscriptionId: this.adminSubscriptionId(),
                locationName: this.location(),
            });
        };
        return UserCreditsCollectionBladeViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.UserCreditsCollectionBladeViewModel = UserCreditsCollectionBladeViewModel;
});
