var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", "ClientResources"], function (require, exports, ClientResources) {
    "use strict";
    var FxGrid = MsPortalFx.ViewModels.Controls.Lists.Grid;
    var FxGridExtensions = FxGrid.Extensions;
    var FxToolbars = MsPortalFx.ViewModels.Toolbars;
    var Dialogs = MsPortalFx.ViewModels.Dialogs;
    var Images = MsPortalFx.Base.Images;
    var FxForms = MsPortalFx.ViewModels.Forms;
    var UserRequestsViewModel = (function (_super) {
        __extends(UserRequestsViewModel, _super);
        function UserRequestsViewModel(container, initialState, dataContext) {
            var _this = this;
            _super.call(this);
            this.selectedUserProfile = ko.pureComputed(function () {
                return _this.userProfilesGrid.selectableData.selectedItems().first();
            });
            this.subscriptionId = ko.observable("");
            this.location = ko.observable("");
            this.userProfileId = ko.observable("");
            this.title("User Requests");
            this.description("User Requests");
            this.icon(Images.Customize());
            this._container = container;
            this._dataContext = dataContext;
            this._userRequestsEntityView = dataContext.userProfileManager.userProfileQuery.createView(container);
            this.formSection = new FxForms.Section.ViewModel(container, {
                style: ko.observable(3),
                children: ko.observableArray([])
            });
            var gridExtensions = FxGridExtensions.SelectableRow;
            var gridExtensionOptions = {
                selectableRow: {
                    selectionMode: 1,
                    activateOnSelected: ko.observable(false)
                }
            };
            this.userProfilesGrid = new FxGrid.ViewModel(container, ko.observableArray([]), gridExtensions, gridExtensionOptions);
            var basicColumns = [
                {
                    itemKey: "Id",
                    name: ko.observable("Id"),
                    activatable: ko.observable(true),
                },
                {
                    itemKey: "UserId",
                    name: ko.observable("User Id"),
                    activatable: ko.observable(true),
                },
                {
                    itemKey: "BillingFirstName",
                    name: ko.observable("First Name"),
                },
                {
                    itemKey: "BillingLastName",
                    name: ko.observable("Last Name"),
                },
                {
                    itemKey: "BillingCompany",
                    name: ko.observable("Company"),
                },
                {
                    itemKey: "SignupStateString",
                    name: ko.observable("Approval Status"),
                },
            ];
            this.userProfilesGrid.columns = ko.observableArray(basicColumns);
            this.userProfilesGrid.showHeader = true;
            this.userProfilesGrid.summary = ko.observable("Summary");
            this.userProfilesGrid.noRowsMessage("No User profiles found");
            this._userRequestsEntityView.item.subscribe(container, function (userProfiles) {
                var transformedItems = userProfiles.map(function (userProfile) {
                    return $.extend({}, userProfile, {});
                });
                _this.userProfilesGrid.items(transformedItems);
            });
            this._userRequestsEntityView.loading.subscribe(container, function (isLoading) {
                _this.userProfilesGrid.loading(isLoading);
            });
            this._setupCommandBar();
        }
        UserRequestsViewModel.prototype._setupCommandBar = function () {
            this._approveUserProfileButton = this._createApproveProfileButton();
            this._rejectUserProfileButton = this._createRejectProfileButton();
            this._deleteUserProfileButton = this._createDeleteProfileButton();
            this.commandBar = new MsPortalFx.ViewModels.Toolbars.Toolbar(this._container);
            this.commandBar.setItems([
                this._approveUserProfileButton,
                this._rejectUserProfileButton,
                this._deleteUserProfileButton,
            ]);
        };
        UserRequestsViewModel.prototype._createApproveProfileButton = function () {
            var _this = this;
            var approveButton = new FxToolbars.DialogButton({
                label: "Approve",
                icon: MsPortalFx.Base.Images.Commit(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to approve the selected user profile ?", 4),
            });
            approveButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedUserProfile() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.userProfileManager.approveUserProfileQuery(_this.subscriptionId(), _this.location(), _this.selectedUserProfile().Id());
                    }
                    return null;
                }
            };
            return approveButton;
        };
        UserRequestsViewModel.prototype._createRejectProfileButton = function () {
            var _this = this;
            var rejectButton = new FxToolbars.DialogButton({
                label: "Reject",
                icon: MsPortalFx.Base.Images.Discard(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to reject the selected user profile ?", 4),
            });
            rejectButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedUserProfile() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.userProfileManager.rejectUserProfileQuery(_this.subscriptionId(), _this.location(), _this.selectedUserProfile().Id());
                    }
                    return null;
                }
            };
            return rejectButton;
        };
        UserRequestsViewModel.prototype._createDeleteProfileButton = function () {
            var _this = this;
            var deleteButton = new FxToolbars.DialogButton({
                label: ClientResources.Commands.delete,
                icon: MsPortalFx.Base.Images.Delete(),
                dialogOptions: new Dialogs.MessageBox("", "Are you sure you want to delete the selected user profile ?", 4),
            });
            deleteButton.command = {
                canExecute: ko.computed(this._container, function () {
                    return _this.selectedUserProfile() != null;
                }),
                execute: function (result) {
                    if (result === 6) {
                        _this._dataContext.userProfileManager.deleteUserProfileQuery(_this.subscriptionId(), _this.location(), _this.selectedUserProfile().Id());
                    }
                    return null;
                }
            };
            return deleteButton;
        };
        UserRequestsViewModel.prototype.onInputsSet = function (inputs, settings) {
            this.subscriptionId(inputs.subscriptionId);
            this.location(inputs.location);
            var args = {
                subscriptionId: this.subscriptionId(),
                location: this.location(),
            };
            return this._userRequestsEntityView.fetch({
                subscriptionId: inputs.subscriptionId,
                location: inputs.location,
            });
        };
        return UserRequestsViewModel;
    }(MsPortalFx.ViewModels.Blade));
    exports.UserRequestsViewModel = UserRequestsViewModel;
});
